'use strict';

var web3_js = require('@solana/web3.js');
var testHelpers = require('@tensor-foundation/test-helpers');

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
var AuthorityType = /* @__PURE__ */ ((AuthorityType2) => {
  AuthorityType2[AuthorityType2["None"] = 0] = "None";
  AuthorityType2[AuthorityType2["Metadata"] = 1] = "Metadata";
  AuthorityType2[AuthorityType2["Holder"] = 2] = "Holder";
  AuthorityType2[AuthorityType2["MetadataDelegate"] = 3] = "MetadataDelegate";
  AuthorityType2[AuthorityType2["TokenDelegate"] = 4] = "TokenDelegate";
  return AuthorityType2;
})(AuthorityType || {});
function getAuthorityTypeEncoder() {
  return web3_js.getEnumEncoder(AuthorityType);
}
function getAuthorityTypeDecoder() {
  return web3_js.getEnumDecoder(AuthorityType);
}
function getAuthorityTypeCodec() {
  return web3_js.combineCodec(getAuthorityTypeEncoder(), getAuthorityTypeDecoder());
}
function getAuthorizationDataEncoder() {
  return web3_js.getStructEncoder([["payload", getPayloadEncoder()]]);
}
function getAuthorizationDataDecoder() {
  return web3_js.getStructDecoder([["payload", getPayloadDecoder()]]);
}
function getAuthorizationDataCodec() {
  return web3_js.combineCodec(
    getAuthorizationDataEncoder(),
    getAuthorizationDataDecoder()
  );
}
function getBurnArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["V1", web3_js.getStructEncoder([["amount", web3_js.getU64Encoder()]])]
  ]);
}
function getBurnArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["V1", web3_js.getStructDecoder([["amount", web3_js.getU64Decoder()]])]
  ]);
}
function getBurnArgsCodec() {
  return web3_js.combineCodec(getBurnArgsEncoder(), getBurnArgsDecoder());
}
function burnArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isBurnArgs(kind, value) {
  return value.__kind === kind;
}
function getCollectionEncoder() {
  return web3_js.getStructEncoder([
    ["verified", web3_js.getBooleanEncoder()],
    ["key", web3_js.getAddressEncoder()]
  ]);
}
function getCollectionDecoder() {
  return web3_js.getStructDecoder([
    ["verified", web3_js.getBooleanDecoder()],
    ["key", web3_js.getAddressDecoder()]
  ]);
}
function getCollectionCodec() {
  return web3_js.combineCodec(getCollectionEncoder(), getCollectionDecoder());
}
function getCollectionDetailsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["V1", web3_js.getStructEncoder([["size", web3_js.getU64Encoder()]])],
    [
      "V2",
      web3_js.getStructEncoder([
        ["padding", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 8 })]
      ])
    ]
  ]);
}
function getCollectionDetailsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["V1", web3_js.getStructDecoder([["size", web3_js.getU64Decoder()]])],
    [
      "V2",
      web3_js.getStructDecoder([
        ["padding", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 8 })]
      ])
    ]
  ]);
}
function getCollectionDetailsCodec() {
  return web3_js.combineCodec(
    getCollectionDetailsEncoder(),
    getCollectionDetailsDecoder()
  );
}
function collectionDetails(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCollectionDetails(kind, value) {
  return value.__kind === kind;
}
function getCollectionDetailsToggleEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    ["Clear", web3_js.getUnitEncoder()],
    [
      "Set",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getCollectionDetailsEncoder()])]
      ])
    ]
  ]);
}
function getCollectionDetailsToggleDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    ["Clear", web3_js.getUnitDecoder()],
    [
      "Set",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getCollectionDetailsDecoder()])]
      ])
    ]
  ]);
}
function getCollectionDetailsToggleCodec() {
  return web3_js.combineCodec(
    getCollectionDetailsToggleEncoder(),
    getCollectionDetailsToggleDecoder()
  );
}
function collectionDetailsToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCollectionDetailsToggle(kind, value) {
  return value.__kind === kind;
}
function getCollectionToggleEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    ["Clear", web3_js.getUnitEncoder()],
    [
      "Set",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getCollectionEncoder()])]])
    ]
  ]);
}
function getCollectionToggleDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    ["Clear", web3_js.getUnitDecoder()],
    [
      "Set",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getCollectionDecoder()])]])
    ]
  ]);
}
function getCollectionToggleCodec() {
  return web3_js.combineCodec(
    getCollectionToggleEncoder(),
    getCollectionToggleDecoder()
  );
}
function collectionToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCollectionToggle(kind, value) {
  return value.__kind === kind;
}
function getCreateArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
        ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
        ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
        ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
        ["creators", web3_js.getOptionEncoder(web3_js.getArrayEncoder(getCreatorEncoder()))],
        ["primarySaleHappened", web3_js.getBooleanEncoder()],
        ["isMutable", web3_js.getBooleanEncoder()],
        ["tokenStandard", getTokenStandardEncoder()],
        ["collection", web3_js.getOptionEncoder(getCollectionEncoder())],
        ["uses", web3_js.getOptionEncoder(getUsesEncoder())],
        ["collectionDetails", web3_js.getOptionEncoder(getCollectionDetailsEncoder())],
        ["ruleSet", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
        ["decimals", web3_js.getOptionEncoder(web3_js.getU8Encoder())],
        ["printSupply", web3_js.getOptionEncoder(getPrintSupplyEncoder())]
      ])
    ]
  ]);
}
function getCreateArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
        ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
        ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
        ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
        ["creators", web3_js.getOptionDecoder(web3_js.getArrayDecoder(getCreatorDecoder()))],
        ["primarySaleHappened", web3_js.getBooleanDecoder()],
        ["isMutable", web3_js.getBooleanDecoder()],
        ["tokenStandard", getTokenStandardDecoder()],
        ["collection", web3_js.getOptionDecoder(getCollectionDecoder())],
        ["uses", web3_js.getOptionDecoder(getUsesDecoder())],
        ["collectionDetails", web3_js.getOptionDecoder(getCollectionDetailsDecoder())],
        ["ruleSet", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
        ["decimals", web3_js.getOptionDecoder(web3_js.getU8Decoder())],
        ["printSupply", web3_js.getOptionDecoder(getPrintSupplyDecoder())]
      ])
    ]
  ]);
}
function getCreateArgsCodec() {
  return web3_js.combineCodec(getCreateArgsEncoder(), getCreateArgsDecoder());
}
function createArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isCreateArgs(kind, value) {
  return value.__kind === kind;
}
function getCreatorEncoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["verified", web3_js.getBooleanEncoder()],
    ["share", web3_js.getU8Encoder()]
  ]);
}
function getCreatorDecoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["verified", web3_js.getBooleanDecoder()],
    ["share", web3_js.getU8Decoder()]
  ]);
}
function getCreatorCodec() {
  return web3_js.combineCodec(getCreatorEncoder(), getCreatorDecoder());
}
function getDataEncoder() {
  return web3_js.getStructEncoder([
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
    ["creators", web3_js.getOptionEncoder(web3_js.getArrayEncoder(getCreatorEncoder()))]
  ]);
}
function getDataDecoder() {
  return web3_js.getStructDecoder([
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["creators", web3_js.getOptionDecoder(web3_js.getArrayDecoder(getCreatorDecoder()))]
  ]);
}
function getDataCodec() {
  return web3_js.combineCodec(getDataEncoder(), getDataDecoder());
}
function getDataV2Encoder() {
  return web3_js.getStructEncoder([
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
    ["creators", web3_js.getOptionEncoder(web3_js.getArrayEncoder(getCreatorEncoder()))],
    ["collection", web3_js.getOptionEncoder(getCollectionEncoder())],
    ["uses", web3_js.getOptionEncoder(getUsesEncoder())]
  ]);
}
function getDataV2Decoder() {
  return web3_js.getStructDecoder([
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["creators", web3_js.getOptionDecoder(web3_js.getArrayDecoder(getCreatorDecoder()))],
    ["collection", web3_js.getOptionDecoder(getCollectionDecoder())],
    ["uses", web3_js.getOptionDecoder(getUsesDecoder())]
  ]);
}
function getDataV2Codec() {
  return web3_js.combineCodec(getDataV2Encoder(), getDataV2Decoder());
}
function getDelegateArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "CollectionV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "SaleV1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "TransferV1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "DataV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "UtilityV1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "StakingV1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    ["StandardV1", web3_js.getStructEncoder([["amount", web3_js.getU64Encoder()]])],
    [
      "LockedTransferV1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["lockedAddress", web3_js.getAddressEncoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "ProgrammableConfigV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AuthorityItemV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "DataItemV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "CollectionItemV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "ProgrammableConfigItemV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "PrintDelegateV1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getDelegateArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "CollectionV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "SaleV1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "TransferV1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "DataV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "UtilityV1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "StakingV1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    ["StandardV1", web3_js.getStructDecoder([["amount", web3_js.getU64Decoder()]])],
    [
      "LockedTransferV1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["lockedAddress", web3_js.getAddressDecoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "ProgrammableConfigV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AuthorityItemV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "DataItemV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "CollectionItemV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "ProgrammableConfigItemV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "PrintDelegateV1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getDelegateArgsCodec() {
  return web3_js.combineCodec(getDelegateArgsEncoder(), getDelegateArgsDecoder());
}
function delegateArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isDelegateArgs(kind, value) {
  return value.__kind === kind;
}
function getEscrowAuthorityEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["TokenOwner", web3_js.getUnitEncoder()],
    [
      "Creator",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ]
  ]);
}
function getEscrowAuthorityDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["TokenOwner", web3_js.getUnitDecoder()],
    [
      "Creator",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ]
  ]);
}
function getEscrowAuthorityCodec() {
  return web3_js.combineCodec(getEscrowAuthorityEncoder(), getEscrowAuthorityDecoder());
}
function escrowAuthority(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isEscrowAuthority(kind, value) {
  return value.__kind === kind;
}
var HolderDelegateRole = /* @__PURE__ */ ((HolderDelegateRole2) => {
  HolderDelegateRole2[HolderDelegateRole2["PrintDelegate"] = 0] = "PrintDelegate";
  return HolderDelegateRole2;
})(HolderDelegateRole || {});
function getHolderDelegateRoleEncoder() {
  return web3_js.getEnumEncoder(HolderDelegateRole);
}
function getHolderDelegateRoleDecoder() {
  return web3_js.getEnumDecoder(HolderDelegateRole);
}
function getHolderDelegateRoleCodec() {
  return web3_js.combineCodec(
    getHolderDelegateRoleEncoder(),
    getHolderDelegateRoleDecoder()
  );
}
var Key = /* @__PURE__ */ ((Key16) => {
  Key16[Key16["Uninitialized"] = 0] = "Uninitialized";
  Key16[Key16["EditionV1"] = 1] = "EditionV1";
  Key16[Key16["MasterEditionV1"] = 2] = "MasterEditionV1";
  Key16[Key16["ReservationListV1"] = 3] = "ReservationListV1";
  Key16[Key16["MetadataV1"] = 4] = "MetadataV1";
  Key16[Key16["ReservationListV2"] = 5] = "ReservationListV2";
  Key16[Key16["MasterEditionV2"] = 6] = "MasterEditionV2";
  Key16[Key16["EditionMarker"] = 7] = "EditionMarker";
  Key16[Key16["UseAuthorityRecord"] = 8] = "UseAuthorityRecord";
  Key16[Key16["CollectionAuthorityRecord"] = 9] = "CollectionAuthorityRecord";
  Key16[Key16["TokenOwnedEscrow"] = 10] = "TokenOwnedEscrow";
  Key16[Key16["TokenRecord"] = 11] = "TokenRecord";
  Key16[Key16["MetadataDelegate"] = 12] = "MetadataDelegate";
  Key16[Key16["EditionMarkerV2"] = 13] = "EditionMarkerV2";
  Key16[Key16["HolderDelegate"] = 14] = "HolderDelegate";
  return Key16;
})(Key || {});
function getKeyEncoder() {
  return web3_js.getEnumEncoder(Key);
}
function getKeyDecoder() {
  return web3_js.getEnumDecoder(Key);
}
function getKeyCodec() {
  return web3_js.combineCodec(getKeyEncoder(), getKeyDecoder());
}
function getLockArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getLockArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getLockArgsCodec() {
  return web3_js.combineCodec(getLockArgsEncoder(), getLockArgsDecoder());
}
function lockArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isLockArgs(kind, value) {
  return value.__kind === kind;
}
var MetadataDelegateRole = /* @__PURE__ */ ((MetadataDelegateRole2) => {
  MetadataDelegateRole2[MetadataDelegateRole2["AuthorityItem"] = 0] = "AuthorityItem";
  MetadataDelegateRole2[MetadataDelegateRole2["Collection"] = 1] = "Collection";
  MetadataDelegateRole2[MetadataDelegateRole2["Use"] = 2] = "Use";
  MetadataDelegateRole2[MetadataDelegateRole2["Data"] = 3] = "Data";
  MetadataDelegateRole2[MetadataDelegateRole2["ProgrammableConfig"] = 4] = "ProgrammableConfig";
  MetadataDelegateRole2[MetadataDelegateRole2["DataItem"] = 5] = "DataItem";
  MetadataDelegateRole2[MetadataDelegateRole2["CollectionItem"] = 6] = "CollectionItem";
  MetadataDelegateRole2[MetadataDelegateRole2["ProgrammableConfigItem"] = 7] = "ProgrammableConfigItem";
  return MetadataDelegateRole2;
})(MetadataDelegateRole || {});
function getMetadataDelegateRoleEncoder() {
  return web3_js.getEnumEncoder(MetadataDelegateRole);
}
function getMetadataDelegateRoleDecoder() {
  return web3_js.getEnumDecoder(MetadataDelegateRole);
}
function getMetadataDelegateRoleCodec() {
  return web3_js.combineCodec(
    getMetadataDelegateRoleEncoder(),
    getMetadataDelegateRoleDecoder()
  );
}
var MigrationType = /* @__PURE__ */ ((MigrationType2) => {
  MigrationType2[MigrationType2["CollectionV1"] = 0] = "CollectionV1";
  MigrationType2[MigrationType2["ProgrammableV1"] = 1] = "ProgrammableV1";
  return MigrationType2;
})(MigrationType || {});
function getMigrationTypeEncoder() {
  return web3_js.getEnumEncoder(MigrationType);
}
function getMigrationTypeDecoder() {
  return web3_js.getEnumDecoder(MigrationType);
}
function getMigrationTypeCodec() {
  return web3_js.combineCodec(getMigrationTypeEncoder(), getMigrationTypeDecoder());
}
function getMintArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getMintArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getMintArgsCodec() {
  return web3_js.combineCodec(getMintArgsEncoder(), getMintArgsDecoder());
}
function mintArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isMintArgs(kind, value) {
  return value.__kind === kind;
}
function getMintNewEditionFromMasterEditionViaTokenArgsEncoder() {
  return web3_js.getStructEncoder([["edition", web3_js.getU64Encoder()]]);
}
function getMintNewEditionFromMasterEditionViaTokenArgsDecoder() {
  return web3_js.getStructDecoder([["edition", web3_js.getU64Decoder()]]);
}
function getMintNewEditionFromMasterEditionViaTokenArgsCodec() {
  return web3_js.combineCodec(
    getMintNewEditionFromMasterEditionViaTokenArgsEncoder(),
    getMintNewEditionFromMasterEditionViaTokenArgsDecoder()
  );
}
function getPayloadEncoder() {
  return web3_js.getStructEncoder([
    [
      "map",
      web3_js.getMapEncoder(
        web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder()),
        getPayloadTypeEncoder()
      )
    ]
  ]);
}
function getPayloadDecoder() {
  return web3_js.getStructDecoder([
    [
      "map",
      web3_js.getMapDecoder(
        web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()),
        getPayloadTypeDecoder()
      )
    ]
  ]);
}
function getPayloadCodec() {
  return web3_js.combineCodec(getPayloadEncoder(), getPayloadDecoder());
}
var PayloadKey = /* @__PURE__ */ ((PayloadKey2) => {
  PayloadKey2[PayloadKey2["Amount"] = 0] = "Amount";
  PayloadKey2[PayloadKey2["Authority"] = 1] = "Authority";
  PayloadKey2[PayloadKey2["AuthoritySeeds"] = 2] = "AuthoritySeeds";
  PayloadKey2[PayloadKey2["Delegate"] = 3] = "Delegate";
  PayloadKey2[PayloadKey2["DelegateSeeds"] = 4] = "DelegateSeeds";
  PayloadKey2[PayloadKey2["Destination"] = 5] = "Destination";
  PayloadKey2[PayloadKey2["DestinationSeeds"] = 6] = "DestinationSeeds";
  PayloadKey2[PayloadKey2["Holder"] = 7] = "Holder";
  PayloadKey2[PayloadKey2["Source"] = 8] = "Source";
  PayloadKey2[PayloadKey2["SourceSeeds"] = 9] = "SourceSeeds";
  return PayloadKey2;
})(PayloadKey || {});
function getPayloadKeyEncoder() {
  return web3_js.getEnumEncoder(PayloadKey);
}
function getPayloadKeyDecoder() {
  return web3_js.getEnumDecoder(PayloadKey);
}
function getPayloadKeyCodec() {
  return web3_js.combineCodec(getPayloadKeyEncoder(), getPayloadKeyDecoder());
}
function getPayloadTypeEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Pubkey",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getSeedsVecEncoder()])]])
    ],
    [
      "MerkleProof",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getProofInfoEncoder()])]])
    ],
    [
      "Number",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getU64Encoder()])]])
    ]
  ]);
}
function getPayloadTypeDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Pubkey",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Seeds",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getSeedsVecDecoder()])]])
    ],
    [
      "MerkleProof",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getProofInfoDecoder()])]])
    ],
    [
      "Number",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getU64Decoder()])]])
    ]
  ]);
}
function getPayloadTypeCodec() {
  return web3_js.combineCodec(getPayloadTypeEncoder(), getPayloadTypeDecoder());
}
function payloadType(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPayloadType(kind, value) {
  return value.__kind === kind;
}
function getPrintArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["V1", web3_js.getStructEncoder([["edition", web3_js.getU64Encoder()]])],
    ["V2", web3_js.getStructEncoder([["edition", web3_js.getU64Encoder()]])]
  ]);
}
function getPrintArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["V1", web3_js.getStructDecoder([["edition", web3_js.getU64Decoder()]])],
    ["V2", web3_js.getStructDecoder([["edition", web3_js.getU64Decoder()]])]
  ]);
}
function getPrintArgsCodec() {
  return web3_js.combineCodec(getPrintArgsEncoder(), getPrintArgsDecoder());
}
function printArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPrintArgs(kind, value) {
  return value.__kind === kind;
}
function getPrintSupplyEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["Zero", web3_js.getUnitEncoder()],
    [
      "Limited",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getU64Encoder()])]])
    ],
    ["Unlimited", web3_js.getUnitEncoder()]
  ]);
}
function getPrintSupplyDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["Zero", web3_js.getUnitDecoder()],
    [
      "Limited",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getU64Decoder()])]])
    ],
    ["Unlimited", web3_js.getUnitDecoder()]
  ]);
}
function getPrintSupplyCodec() {
  return web3_js.combineCodec(getPrintSupplyEncoder(), getPrintSupplyDecoder());
}
function printSupply(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPrintSupply(kind, value) {
  return value.__kind === kind;
}
function getProgrammableConfigEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([["ruleSet", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]])
    ]
  ]);
}
function getProgrammableConfigDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([["ruleSet", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]])
    ]
  ]);
}
function getProgrammableConfigCodec() {
  return web3_js.combineCodec(
    getProgrammableConfigEncoder(),
    getProgrammableConfigDecoder()
  );
}
function programmableConfig(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isProgrammableConfig(kind, value) {
  return value.__kind === kind;
}
function getProofInfoEncoder() {
  return web3_js.getStructEncoder([
    ["proof", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
  ]);
}
function getProofInfoDecoder() {
  return web3_js.getStructDecoder([
    ["proof", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getProofInfoCodec() {
  return web3_js.combineCodec(getProofInfoEncoder(), getProofInfoDecoder());
}
function getReservationEncoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["spotsRemaining", web3_js.getU64Encoder()],
    ["totalSpots", web3_js.getU64Encoder()]
  ]);
}
function getReservationDecoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["spotsRemaining", web3_js.getU64Decoder()],
    ["totalSpots", web3_js.getU64Decoder()]
  ]);
}
function getReservationCodec() {
  return web3_js.combineCodec(getReservationEncoder(), getReservationDecoder());
}
function getReservationV1Encoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["spotsRemaining", web3_js.getU8Encoder()],
    ["totalSpots", web3_js.getU8Encoder()]
  ]);
}
function getReservationV1Decoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["spotsRemaining", web3_js.getU8Decoder()],
    ["totalSpots", web3_js.getU8Decoder()]
  ]);
}
function getReservationV1Codec() {
  return web3_js.combineCodec(getReservationV1Encoder(), getReservationV1Decoder());
}
var RevokeArgs = /* @__PURE__ */ ((RevokeArgs2) => {
  RevokeArgs2[RevokeArgs2["CollectionV1"] = 0] = "CollectionV1";
  RevokeArgs2[RevokeArgs2["SaleV1"] = 1] = "SaleV1";
  RevokeArgs2[RevokeArgs2["TransferV1"] = 2] = "TransferV1";
  RevokeArgs2[RevokeArgs2["DataV1"] = 3] = "DataV1";
  RevokeArgs2[RevokeArgs2["UtilityV1"] = 4] = "UtilityV1";
  RevokeArgs2[RevokeArgs2["StakingV1"] = 5] = "StakingV1";
  RevokeArgs2[RevokeArgs2["StandardV1"] = 6] = "StandardV1";
  RevokeArgs2[RevokeArgs2["LockedTransferV1"] = 7] = "LockedTransferV1";
  RevokeArgs2[RevokeArgs2["ProgrammableConfigV1"] = 8] = "ProgrammableConfigV1";
  RevokeArgs2[RevokeArgs2["MigrationV1"] = 9] = "MigrationV1";
  RevokeArgs2[RevokeArgs2["AuthorityItemV1"] = 10] = "AuthorityItemV1";
  RevokeArgs2[RevokeArgs2["DataItemV1"] = 11] = "DataItemV1";
  RevokeArgs2[RevokeArgs2["CollectionItemV1"] = 12] = "CollectionItemV1";
  RevokeArgs2[RevokeArgs2["ProgrammableConfigItemV1"] = 13] = "ProgrammableConfigItemV1";
  RevokeArgs2[RevokeArgs2["PrintDelegateV1"] = 14] = "PrintDelegateV1";
  return RevokeArgs2;
})(RevokeArgs || {});
function getRevokeArgsEncoder() {
  return web3_js.getEnumEncoder(RevokeArgs);
}
function getRevokeArgsDecoder() {
  return web3_js.getEnumDecoder(RevokeArgs);
}
function getRevokeArgsCodec() {
  return web3_js.combineCodec(getRevokeArgsEncoder(), getRevokeArgsDecoder());
}
function getRuleSetToggleEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    ["Clear", web3_js.getUnitEncoder()],
    [
      "Set",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ]
  ]);
}
function getRuleSetToggleDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    ["Clear", web3_js.getUnitDecoder()],
    [
      "Set",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ]
  ]);
}
function getRuleSetToggleCodec() {
  return web3_js.combineCodec(getRuleSetToggleEncoder(), getRuleSetToggleDecoder());
}
function ruleSetToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isRuleSetToggle(kind, value) {
  return value.__kind === kind;
}
function getSeedsVecEncoder() {
  return web3_js.getStructEncoder([
    [
      "seeds",
      web3_js.getArrayEncoder(web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder()))
    ]
  ]);
}
function getSeedsVecDecoder() {
  return web3_js.getStructDecoder([
    [
      "seeds",
      web3_js.getArrayDecoder(web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder()))
    ]
  ]);
}
function getSeedsVecCodec() {
  return web3_js.combineCodec(getSeedsVecEncoder(), getSeedsVecDecoder());
}
function getSetCollectionSizeArgsEncoder() {
  return web3_js.getStructEncoder([["size", web3_js.getU64Encoder()]]);
}
function getSetCollectionSizeArgsDecoder() {
  return web3_js.getStructDecoder([["size", web3_js.getU64Decoder()]]);
}
function getSetCollectionSizeArgsCodec() {
  return web3_js.combineCodec(
    getSetCollectionSizeArgsEncoder(),
    getSetCollectionSizeArgsDecoder()
  );
}
var TokenDelegateRole = /* @__PURE__ */ ((TokenDelegateRole3) => {
  TokenDelegateRole3[TokenDelegateRole3["Sale"] = 0] = "Sale";
  TokenDelegateRole3[TokenDelegateRole3["Transfer"] = 1] = "Transfer";
  TokenDelegateRole3[TokenDelegateRole3["Utility"] = 2] = "Utility";
  TokenDelegateRole3[TokenDelegateRole3["Staking"] = 3] = "Staking";
  TokenDelegateRole3[TokenDelegateRole3["Standard"] = 4] = "Standard";
  TokenDelegateRole3[TokenDelegateRole3["LockedTransfer"] = 5] = "LockedTransfer";
  TokenDelegateRole3[TokenDelegateRole3["Migration"] = 6] = "Migration";
  return TokenDelegateRole3;
})(TokenDelegateRole || {});
function getTokenDelegateRoleEncoder() {
  return web3_js.getEnumEncoder(TokenDelegateRole);
}
function getTokenDelegateRoleDecoder() {
  return web3_js.getEnumDecoder(TokenDelegateRole);
}
function getTokenDelegateRoleCodec() {
  return web3_js.combineCodec(
    getTokenDelegateRoleEncoder(),
    getTokenDelegateRoleDecoder()
  );
}
var TokenStandard2 = /* @__PURE__ */ ((TokenStandard6) => {
  TokenStandard6[TokenStandard6["NonFungible"] = 0] = "NonFungible";
  TokenStandard6[TokenStandard6["FungibleAsset"] = 1] = "FungibleAsset";
  TokenStandard6[TokenStandard6["Fungible"] = 2] = "Fungible";
  TokenStandard6[TokenStandard6["NonFungibleEdition"] = 3] = "NonFungibleEdition";
  TokenStandard6[TokenStandard6["ProgrammableNonFungible"] = 4] = "ProgrammableNonFungible";
  TokenStandard6[TokenStandard6["ProgrammableNonFungibleEdition"] = 5] = "ProgrammableNonFungibleEdition";
  return TokenStandard6;
})(TokenStandard2 || {});
function getTokenStandardEncoder() {
  return web3_js.getEnumEncoder(TokenStandard2);
}
function getTokenStandardDecoder() {
  return web3_js.getEnumDecoder(TokenStandard2);
}
function getTokenStandardCodec() {
  return web3_js.combineCodec(getTokenStandardEncoder(), getTokenStandardDecoder());
}
var TokenState = /* @__PURE__ */ ((TokenState3) => {
  TokenState3[TokenState3["Unlocked"] = 0] = "Unlocked";
  TokenState3[TokenState3["Locked"] = 1] = "Locked";
  TokenState3[TokenState3["Listed"] = 2] = "Listed";
  return TokenState3;
})(TokenState || {});
function getTokenStateEncoder() {
  return web3_js.getEnumEncoder(TokenState);
}
function getTokenStateDecoder() {
  return web3_js.getEnumDecoder(TokenState);
}
function getTokenStateCodec() {
  return web3_js.combineCodec(getTokenStateEncoder(), getTokenStateDecoder());
}
function getTransferArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["amount", web3_js.getU64Encoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getTransferArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["amount", web3_js.getU64Decoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getTransferArgsCodec() {
  return web3_js.combineCodec(getTransferArgsEncoder(), getTransferArgsDecoder());
}
function transferArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isTransferArgs(kind, value) {
  return value.__kind === kind;
}
function getUnlockArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getUnlockArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getUnlockArgsCodec() {
  return web3_js.combineCodec(getUnlockArgsEncoder(), getUnlockArgsDecoder());
}
function unlockArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUnlockArgs(kind, value) {
  return value.__kind === kind;
}
function getUpdateArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["newUpdateAuthority", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
        ["data", web3_js.getOptionEncoder(getDataEncoder())],
        ["primarySaleHappened", web3_js.getOptionEncoder(web3_js.getBooleanEncoder())],
        ["isMutable", web3_js.getOptionEncoder(web3_js.getBooleanEncoder())],
        ["collection", getCollectionToggleEncoder()],
        ["collectionDetails", getCollectionDetailsToggleEncoder()],
        ["uses", getUsesToggleEncoder()],
        ["ruleSet", getRuleSetToggleEncoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsUpdateAuthorityV2",
      web3_js.getStructEncoder([
        ["newUpdateAuthority", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
        ["data", web3_js.getOptionEncoder(getDataEncoder())],
        ["primarySaleHappened", web3_js.getOptionEncoder(web3_js.getBooleanEncoder())],
        ["isMutable", web3_js.getOptionEncoder(web3_js.getBooleanEncoder())],
        ["collection", getCollectionToggleEncoder()],
        ["collectionDetails", getCollectionDetailsToggleEncoder()],
        ["uses", getUsesToggleEncoder()],
        ["ruleSet", getRuleSetToggleEncoder()],
        ["tokenStandard", web3_js.getOptionEncoder(getTokenStandardEncoder())],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsAuthorityItemDelegateV2",
      web3_js.getStructEncoder([
        ["newUpdateAuthority", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
        ["primarySaleHappened", web3_js.getOptionEncoder(web3_js.getBooleanEncoder())],
        ["isMutable", web3_js.getOptionEncoder(web3_js.getBooleanEncoder())],
        ["tokenStandard", web3_js.getOptionEncoder(getTokenStandardEncoder())],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsCollectionDelegateV2",
      web3_js.getStructEncoder([
        ["collection", getCollectionToggleEncoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsDataDelegateV2",
      web3_js.getStructEncoder([
        ["data", web3_js.getOptionEncoder(getDataEncoder())],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsProgrammableConfigDelegateV2",
      web3_js.getStructEncoder([
        ["ruleSet", getRuleSetToggleEncoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsDataItemDelegateV2",
      web3_js.getStructEncoder([
        ["data", web3_js.getOptionEncoder(getDataEncoder())],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsCollectionItemDelegateV2",
      web3_js.getStructEncoder([
        ["collection", getCollectionToggleEncoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ],
    [
      "AsProgrammableConfigItemDelegateV2",
      web3_js.getStructEncoder([
        ["ruleSet", getRuleSetToggleEncoder()],
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getUpdateArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["newUpdateAuthority", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
        ["data", web3_js.getOptionDecoder(getDataDecoder())],
        ["primarySaleHappened", web3_js.getOptionDecoder(web3_js.getBooleanDecoder())],
        ["isMutable", web3_js.getOptionDecoder(web3_js.getBooleanDecoder())],
        ["collection", getCollectionToggleDecoder()],
        ["collectionDetails", getCollectionDetailsToggleDecoder()],
        ["uses", getUsesToggleDecoder()],
        ["ruleSet", getRuleSetToggleDecoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsUpdateAuthorityV2",
      web3_js.getStructDecoder([
        ["newUpdateAuthority", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
        ["data", web3_js.getOptionDecoder(getDataDecoder())],
        ["primarySaleHappened", web3_js.getOptionDecoder(web3_js.getBooleanDecoder())],
        ["isMutable", web3_js.getOptionDecoder(web3_js.getBooleanDecoder())],
        ["collection", getCollectionToggleDecoder()],
        ["collectionDetails", getCollectionDetailsToggleDecoder()],
        ["uses", getUsesToggleDecoder()],
        ["ruleSet", getRuleSetToggleDecoder()],
        ["tokenStandard", web3_js.getOptionDecoder(getTokenStandardDecoder())],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsAuthorityItemDelegateV2",
      web3_js.getStructDecoder([
        ["newUpdateAuthority", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
        ["primarySaleHappened", web3_js.getOptionDecoder(web3_js.getBooleanDecoder())],
        ["isMutable", web3_js.getOptionDecoder(web3_js.getBooleanDecoder())],
        ["tokenStandard", web3_js.getOptionDecoder(getTokenStandardDecoder())],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsCollectionDelegateV2",
      web3_js.getStructDecoder([
        ["collection", getCollectionToggleDecoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsDataDelegateV2",
      web3_js.getStructDecoder([
        ["data", web3_js.getOptionDecoder(getDataDecoder())],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsProgrammableConfigDelegateV2",
      web3_js.getStructDecoder([
        ["ruleSet", getRuleSetToggleDecoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsDataItemDelegateV2",
      web3_js.getStructDecoder([
        ["data", web3_js.getOptionDecoder(getDataDecoder())],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsCollectionItemDelegateV2",
      web3_js.getStructDecoder([
        ["collection", getCollectionToggleDecoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ],
    [
      "AsProgrammableConfigItemDelegateV2",
      web3_js.getStructDecoder([
        ["ruleSet", getRuleSetToggleDecoder()],
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getUpdateArgsCodec() {
  return web3_js.combineCodec(getUpdateArgsEncoder(), getUpdateArgsDecoder());
}
function updateArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUpdateArgs(kind, value) {
  return value.__kind === kind;
}
function getUseArgsEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "V1",
      web3_js.getStructEncoder([
        ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
      ])
    ]
  ]);
}
function getUseArgsDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "V1",
      web3_js.getStructDecoder([
        ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
      ])
    ]
  ]);
}
function getUseArgsCodec() {
  return web3_js.combineCodec(getUseArgsEncoder(), getUseArgsDecoder());
}
function useArgs(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUseArgs(kind, value) {
  return value.__kind === kind;
}
var UseMethod = /* @__PURE__ */ ((UseMethod3) => {
  UseMethod3[UseMethod3["Burn"] = 0] = "Burn";
  UseMethod3[UseMethod3["Multiple"] = 1] = "Multiple";
  UseMethod3[UseMethod3["Single"] = 2] = "Single";
  return UseMethod3;
})(UseMethod || {});
function getUseMethodEncoder() {
  return web3_js.getEnumEncoder(UseMethod);
}
function getUseMethodDecoder() {
  return web3_js.getEnumDecoder(UseMethod);
}
function getUseMethodCodec() {
  return web3_js.combineCodec(getUseMethodEncoder(), getUseMethodDecoder());
}
function getUsesEncoder() {
  return web3_js.getStructEncoder([
    ["useMethod", getUseMethodEncoder()],
    ["remaining", web3_js.getU64Encoder()],
    ["total", web3_js.getU64Encoder()]
  ]);
}
function getUsesDecoder() {
  return web3_js.getStructDecoder([
    ["useMethod", getUseMethodDecoder()],
    ["remaining", web3_js.getU64Decoder()],
    ["total", web3_js.getU64Decoder()]
  ]);
}
function getUsesCodec() {
  return web3_js.combineCodec(getUsesEncoder(), getUsesDecoder());
}
function getUsesToggleEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    ["Clear", web3_js.getUnitEncoder()],
    [
      "Set",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getUsesEncoder()])]])
    ]
  ]);
}
function getUsesToggleDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    ["Clear", web3_js.getUnitDecoder()],
    [
      "Set",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getUsesDecoder()])]])
    ]
  ]);
}
function getUsesToggleCodec() {
  return web3_js.combineCodec(getUsesToggleEncoder(), getUsesToggleDecoder());
}
function usesToggle(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUsesToggle(kind, value) {
  return value.__kind === kind;
}
var VerificationArgs = /* @__PURE__ */ ((VerificationArgs4) => {
  VerificationArgs4[VerificationArgs4["CreatorV1"] = 0] = "CreatorV1";
  VerificationArgs4[VerificationArgs4["CollectionV1"] = 1] = "CollectionV1";
  return VerificationArgs4;
})(VerificationArgs || {});
function getVerificationArgsEncoder() {
  return web3_js.getEnumEncoder(VerificationArgs);
}
function getVerificationArgsDecoder() {
  return web3_js.getEnumDecoder(VerificationArgs);
}
function getVerificationArgsCodec() {
  return web3_js.combineCodec(
    getVerificationArgsEncoder(),
    getVerificationArgsDecoder()
  );
}

// src/generated/accounts/collectionAuthorityRecord.ts
function getCollectionAuthorityRecordEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["bump", web3_js.getU8Encoder()],
    ["updateAuthority", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
  ]);
}
function getCollectionAuthorityRecordDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", web3_js.getU8Decoder()],
    ["updateAuthority", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getCollectionAuthorityRecordCodec() {
  return web3_js.combineCodec(
    getCollectionAuthorityRecordEncoder(),
    getCollectionAuthorityRecordDecoder()
  );
}
function decodeCollectionAuthorityRecord(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getCollectionAuthorityRecordDecoder()
  );
}
async function fetchCollectionAuthorityRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeCollectionAuthorityRecord(
    rpc,
    address,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeCollectionAuthorityRecord(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeCollectionAuthorityRecord(maybeAccount);
}
async function fetchAllCollectionAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeCollectionAuthorityRecord(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeCollectionAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeCollectionAuthorityRecord(maybeAccount)
  );
}
function getEditionEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["parent", web3_js.getAddressEncoder()],
    ["edition", web3_js.getU64Encoder()]
  ]);
}
function getEditionDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["parent", web3_js.getAddressDecoder()],
    ["edition", web3_js.getU64Decoder()]
  ]);
}
function getEditionCodec() {
  return web3_js.combineCodec(getEditionEncoder(), getEditionDecoder());
}
function decodeEdition(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getEditionDecoder()
  );
}
async function fetchEdition(rpc, address, config) {
  const maybeAccount = await fetchMaybeEdition(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEdition(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeEdition(maybeAccount);
}
async function fetchAllEdition(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeEdition(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeEdition(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeEdition(maybeAccount));
}
function getEditionSize() {
  return 41;
}
function getEditionMarkerEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["ledger", web3_js.getArrayEncoder(web3_js.getU8Encoder(), { size: 31 })]
  ]);
}
function getEditionMarkerDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["ledger", web3_js.getArrayDecoder(web3_js.getU8Decoder(), { size: 31 })]
  ]);
}
function getEditionMarkerCodec() {
  return web3_js.combineCodec(getEditionMarkerEncoder(), getEditionMarkerDecoder());
}
function decodeEditionMarker(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getEditionMarkerDecoder()
  );
}
async function fetchEditionMarker(rpc, address, config) {
  const maybeAccount = await fetchMaybeEditionMarker(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEditionMarker(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeEditionMarker(maybeAccount);
}
async function fetchAllEditionMarker(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeEditionMarker(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeEditionMarker(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeEditionMarker(maybeAccount));
}
function getEditionMarkerSize() {
  return 32;
}
function getEditionMarkerV2Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["ledger", web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())]
  ]);
}
function getEditionMarkerV2Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["ledger", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())]
  ]);
}
function getEditionMarkerV2Codec() {
  return web3_js.combineCodec(getEditionMarkerV2Encoder(), getEditionMarkerV2Decoder());
}
function decodeEditionMarkerV2(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getEditionMarkerV2Decoder()
  );
}
async function fetchEditionMarkerV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeEditionMarkerV2(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeEditionMarkerV2(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeEditionMarkerV2(maybeAccount);
}
async function fetchAllEditionMarkerV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeEditionMarkerV2(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeEditionMarkerV2(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeEditionMarkerV2(maybeAccount)
  );
}
function getHolderDelegateRecordEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["bump", web3_js.getU8Encoder()],
    ["mint", web3_js.getAddressEncoder()],
    ["delegate", web3_js.getAddressEncoder()],
    ["updateAuthority", web3_js.getAddressEncoder()]
  ]);
}
function getHolderDelegateRecordDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", web3_js.getU8Decoder()],
    ["mint", web3_js.getAddressDecoder()],
    ["delegate", web3_js.getAddressDecoder()],
    ["updateAuthority", web3_js.getAddressDecoder()]
  ]);
}
function getHolderDelegateRecordCodec() {
  return web3_js.combineCodec(
    getHolderDelegateRecordEncoder(),
    getHolderDelegateRecordDecoder()
  );
}
function decodeHolderDelegateRecord(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getHolderDelegateRecordDecoder()
  );
}
async function fetchHolderDelegateRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeHolderDelegateRecord(
    rpc,
    address,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeHolderDelegateRecord(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeHolderDelegateRecord(maybeAccount);
}
async function fetchAllHolderDelegateRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeHolderDelegateRecord(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeHolderDelegateRecord(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeHolderDelegateRecord(maybeAccount)
  );
}
function getHolderDelegateRecordSize() {
  return 98;
}
async function findMasterEditionPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getUtf8Encoder().encode("edition")
    ]
  });
}
async function findMetadataPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findTokenRecordPda(seeds, config = {}) {
  const {
    programAddress = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("metadata"),
      web3_js.getAddressEncoder().encode(programAddress),
      web3_js.getAddressEncoder().encode(seeds.mint),
      web3_js.getUtf8Encoder().encode("token_record"),
      web3_js.getAddressEncoder().encode(seeds.token)
    ]
  });
}

// src/generated/accounts/masterEdition.ts
function getMasterEditionEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["supply", web3_js.getU64Encoder()],
    ["maxSupply", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
  ]);
}
function getMasterEditionDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["supply", web3_js.getU64Decoder()],
    ["maxSupply", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getMasterEditionCodec() {
  return web3_js.combineCodec(getMasterEditionEncoder(), getMasterEditionDecoder());
}
function decodeMasterEdition(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getMasterEditionDecoder()
  );
}
async function fetchMasterEdition(rpc, address, config) {
  const maybeAccount = await fetchMaybeMasterEdition(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMasterEdition(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeMasterEdition(maybeAccount);
}
async function fetchAllMasterEdition(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMasterEdition(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMasterEdition(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMasterEdition(maybeAccount));
}
async function fetchMasterEditionFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMasterEditionFromSeeds(
    rpc,
    seeds,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMasterEditionFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMasterEditionPda(seeds, { programAddress });
  return await fetchMaybeMasterEdition(rpc, address, fetchConfig);
}
function getMasterEditionV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["supply", web3_js.getU64Encoder()],
    ["maxSupply", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["printingMint", web3_js.getAddressEncoder()],
    ["oneTimePrintingAuthorizationMint", web3_js.getAddressEncoder()]
  ]);
}
function getMasterEditionV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["supply", web3_js.getU64Decoder()],
    ["maxSupply", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["printingMint", web3_js.getAddressDecoder()],
    ["oneTimePrintingAuthorizationMint", web3_js.getAddressDecoder()]
  ]);
}
function getMasterEditionV1Codec() {
  return web3_js.combineCodec(getMasterEditionV1Encoder(), getMasterEditionV1Decoder());
}
function decodeMasterEditionV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getMasterEditionV1Decoder()
  );
}
async function fetchMasterEditionV1(rpc, address, config) {
  const maybeAccount = await fetchMaybeMasterEditionV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMasterEditionV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeMasterEditionV1(maybeAccount);
}
async function fetchAllMasterEditionV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMasterEditionV1(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMasterEditionV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeMasterEditionV1(maybeAccount)
  );
}
function getMetadataEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["updateAuthority", web3_js.getAddressEncoder()],
    ["mint", web3_js.getAddressEncoder()],
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
    ["creators", web3_js.getOptionEncoder(web3_js.getArrayEncoder(getCreatorEncoder()))],
    ["primarySaleHappened", web3_js.getBooleanEncoder()],
    ["isMutable", web3_js.getBooleanEncoder()],
    ["editionNonce", web3_js.getOptionEncoder(web3_js.getU8Encoder())],
    ["tokenStandard", web3_js.getOptionEncoder(getTokenStandardEncoder())],
    ["collection", web3_js.getOptionEncoder(getCollectionEncoder())],
    ["uses", web3_js.getOptionEncoder(getUsesEncoder())],
    ["collectionDetails", web3_js.getOptionEncoder(getCollectionDetailsEncoder())],
    ["programmableConfig", web3_js.getOptionEncoder(getProgrammableConfigEncoder())]
  ]);
}
function getMetadataDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["updateAuthority", web3_js.getAddressDecoder()],
    ["mint", web3_js.getAddressDecoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["creators", web3_js.getOptionDecoder(web3_js.getArrayDecoder(getCreatorDecoder()))],
    ["primarySaleHappened", web3_js.getBooleanDecoder()],
    ["isMutable", web3_js.getBooleanDecoder()],
    ["editionNonce", web3_js.getOptionDecoder(web3_js.getU8Decoder())],
    ["tokenStandard", web3_js.getOptionDecoder(getTokenStandardDecoder())],
    ["collection", web3_js.getOptionDecoder(getCollectionDecoder())],
    ["uses", web3_js.getOptionDecoder(getUsesDecoder())],
    ["collectionDetails", web3_js.getOptionDecoder(getCollectionDetailsDecoder())],
    ["programmableConfig", web3_js.getOptionDecoder(getProgrammableConfigDecoder())]
  ]);
}
function getMetadataCodec() {
  return web3_js.combineCodec(getMetadataEncoder(), getMetadataDecoder());
}
function decodeMetadata(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getMetadataDecoder()
  );
}
async function fetchMetadata(rpc, address, config) {
  const maybeAccount = await fetchMaybeMetadata(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMetadata(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeMetadata(maybeAccount);
}
async function fetchAllMetadata(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMetadata(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMetadata(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMetadata(maybeAccount));
}
async function fetchMetadataFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMetadataFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMetadataFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMetadataPda(seeds, { programAddress });
  return await fetchMaybeMetadata(rpc, address, fetchConfig);
}
function getMetadataDelegateRecordEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["bump", web3_js.getU8Encoder()],
    ["mint", web3_js.getAddressEncoder()],
    ["delegate", web3_js.getAddressEncoder()],
    ["updateAuthority", web3_js.getAddressEncoder()]
  ]);
}
function getMetadataDelegateRecordDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", web3_js.getU8Decoder()],
    ["mint", web3_js.getAddressDecoder()],
    ["delegate", web3_js.getAddressDecoder()],
    ["updateAuthority", web3_js.getAddressDecoder()]
  ]);
}
function getMetadataDelegateRecordCodec() {
  return web3_js.combineCodec(
    getMetadataDelegateRecordEncoder(),
    getMetadataDelegateRecordDecoder()
  );
}
function decodeMetadataDelegateRecord(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getMetadataDelegateRecordDecoder()
  );
}
async function fetchMetadataDelegateRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeMetadataDelegateRecord(
    rpc,
    address,
    config
  );
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMetadataDelegateRecord(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeMetadataDelegateRecord(maybeAccount);
}
async function fetchAllMetadataDelegateRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMetadataDelegateRecord(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMetadataDelegateRecord(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeMetadataDelegateRecord(maybeAccount)
  );
}
function getMetadataDelegateRecordSize() {
  return 98;
}
function getReservationListV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["masterEdition", web3_js.getAddressEncoder()],
    ["supplySnapshot", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["reservations", web3_js.getArrayEncoder(getReservationV1Encoder())]
  ]);
}
function getReservationListV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["masterEdition", web3_js.getAddressDecoder()],
    ["supplySnapshot", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["reservations", web3_js.getArrayDecoder(getReservationV1Decoder())]
  ]);
}
function getReservationListV1Codec() {
  return web3_js.combineCodec(
    getReservationListV1Encoder(),
    getReservationListV1Decoder()
  );
}
function decodeReservationListV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getReservationListV1Decoder()
  );
}
async function fetchReservationListV1(rpc, address, config) {
  const maybeAccount = await fetchMaybeReservationListV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeReservationListV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeReservationListV1(maybeAccount);
}
async function fetchAllReservationListV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeReservationListV1(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeReservationListV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeReservationListV1(maybeAccount)
  );
}
function getReservationListV2Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["masterEdition", web3_js.getAddressEncoder()],
    ["supplySnapshot", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["reservations", web3_js.getArrayEncoder(getReservationEncoder())],
    ["totalReservationSpots", web3_js.getU64Encoder()],
    ["currentReservationSpots", web3_js.getU64Encoder()]
  ]);
}
function getReservationListV2Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["masterEdition", web3_js.getAddressDecoder()],
    ["supplySnapshot", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["reservations", web3_js.getArrayDecoder(getReservationDecoder())],
    ["totalReservationSpots", web3_js.getU64Decoder()],
    ["currentReservationSpots", web3_js.getU64Decoder()]
  ]);
}
function getReservationListV2Codec() {
  return web3_js.combineCodec(
    getReservationListV2Encoder(),
    getReservationListV2Decoder()
  );
}
function decodeReservationListV2(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getReservationListV2Decoder()
  );
}
async function fetchReservationListV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeReservationListV2(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeReservationListV2(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeReservationListV2(maybeAccount);
}
async function fetchAllReservationListV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeReservationListV2(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeReservationListV2(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeReservationListV2(maybeAccount)
  );
}
function getTokenOwnedEscrowEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["baseToken", web3_js.getAddressEncoder()],
    ["authority", getEscrowAuthorityEncoder()],
    ["bump", web3_js.getU8Encoder()]
  ]);
}
function getTokenOwnedEscrowDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["baseToken", web3_js.getAddressDecoder()],
    ["authority", getEscrowAuthorityDecoder()],
    ["bump", web3_js.getU8Decoder()]
  ]);
}
function getTokenOwnedEscrowCodec() {
  return web3_js.combineCodec(
    getTokenOwnedEscrowEncoder(),
    getTokenOwnedEscrowDecoder()
  );
}
function decodeTokenOwnedEscrow(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getTokenOwnedEscrowDecoder()
  );
}
async function fetchTokenOwnedEscrow(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenOwnedEscrow(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenOwnedEscrow(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeTokenOwnedEscrow(maybeAccount);
}
async function fetchAllTokenOwnedEscrow(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenOwnedEscrow(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenOwnedEscrow(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeTokenOwnedEscrow(maybeAccount)
  );
}
function getTokenRecordEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["bump", web3_js.getU8Encoder()],
    ["state", getTokenStateEncoder()],
    ["ruleSetRevision", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["delegate", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
    ["delegateRole", web3_js.getOptionEncoder(getTokenDelegateRoleEncoder())],
    ["lockedTransfer", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
  ]);
}
function getTokenRecordDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["bump", web3_js.getU8Decoder()],
    ["state", getTokenStateDecoder()],
    ["ruleSetRevision", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["delegate", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["delegateRole", web3_js.getOptionDecoder(getTokenDelegateRoleDecoder())],
    ["lockedTransfer", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getTokenRecordCodec() {
  return web3_js.combineCodec(getTokenRecordEncoder(), getTokenRecordDecoder());
}
function decodeTokenRecord(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getTokenRecordDecoder()
  );
}
async function fetchTokenRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenRecord(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenRecord(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeTokenRecord(maybeAccount);
}
async function fetchAllTokenRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenRecord(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenRecord(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeTokenRecord(maybeAccount));
}
async function fetchTokenRecordFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeTokenRecordFromSeeds(rpc, seeds, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenRecordFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findTokenRecordPda(seeds, { programAddress });
  return await fetchMaybeTokenRecord(rpc, address, fetchConfig);
}
function getUseAuthorityRecordEncoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["allowedUses", web3_js.getU64Encoder()],
    ["bump", web3_js.getU8Encoder()]
  ]);
}
function getUseAuthorityRecordDecoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["allowedUses", web3_js.getU64Decoder()],
    ["bump", web3_js.getU8Decoder()]
  ]);
}
function getUseAuthorityRecordCodec() {
  return web3_js.combineCodec(
    getUseAuthorityRecordEncoder(),
    getUseAuthorityRecordDecoder()
  );
}
function decodeUseAuthorityRecord(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getUseAuthorityRecordDecoder()
  );
}
async function fetchUseAuthorityRecord(rpc, address, config) {
  const maybeAccount = await fetchMaybeUseAuthorityRecord(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeUseAuthorityRecord(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeUseAuthorityRecord(maybeAccount);
}
async function fetchAllUseAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeUseAuthorityRecord(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeUseAuthorityRecord(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeUseAuthorityRecord(maybeAccount)
  );
}
function getUseAuthorityRecordSize() {
  return 10;
}

// src/generated/errors/tokenMetadata.ts
var TOKEN_METADATA_ERROR__INSTRUCTION_UNPACK_ERROR = 0;
var TOKEN_METADATA_ERROR__INSTRUCTION_PACK_ERROR = 1;
var TOKEN_METADATA_ERROR__NOT_RENT_EXEMPT = 2;
var TOKEN_METADATA_ERROR__ALREADY_INITIALIZED = 3;
var TOKEN_METADATA_ERROR__UNINITIALIZED = 4;
var TOKEN_METADATA_ERROR__INVALID_METADATA_KEY = 5;
var TOKEN_METADATA_ERROR__INVALID_EDITION_KEY = 6;
var TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_INCORRECT = 7;
var TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_IS_NOT_SIGNER = 8;
var TOKEN_METADATA_ERROR__NOT_MINT_AUTHORITY = 9;
var TOKEN_METADATA_ERROR__INVALID_MINT_AUTHORITY = 10;
var TOKEN_METADATA_ERROR__NAME_TOO_LONG = 11;
var TOKEN_METADATA_ERROR__SYMBOL_TOO_LONG = 12;
var TOKEN_METADATA_ERROR__URI_TOO_LONG = 13;
var TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER = 14;
var TOKEN_METADATA_ERROR__MINT_MISMATCH = 15;
var TOKEN_METADATA_ERROR__EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN = 16;
var TOKEN_METADATA_ERROR__MAX_EDITIONS_MINTED_ALREADY = 17;
var TOKEN_METADATA_ERROR__TOKEN_MINT_TO_FAILED = 18;
var TOKEN_METADATA_ERROR__MASTER_RECORD_MISMATCH = 19;
var TOKEN_METADATA_ERROR__DESTINATION_MINT_MISMATCH = 20;
var TOKEN_METADATA_ERROR__EDITION_ALREADY_MINTED = 21;
var TOKEN_METADATA_ERROR__PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO = 22;
var TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO = 23;
var TOKEN_METADATA_ERROR__EDITION_MINT_DECIMALS_SHOULD_BE_ZERO = 24;
var TOKEN_METADATA_ERROR__TOKEN_BURN_FAILED = 25;
var TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH = 26;
var TOKEN_METADATA_ERROR__DERIVED_KEY_INVALID = 27;
var TOKEN_METADATA_ERROR__PRINTING_MINT_MISMATCH = 28;
var TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTH_MINT_MISMATCH = 29;
var TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH = 30;
var TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH_V2 = 31;
var TOKEN_METADATA_ERROR__NOT_ENOUGH_TOKENS = 32;
var TOKEN_METADATA_ERROR__PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH = 33;
var TOKEN_METADATA_ERROR__AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH = 34;
var TOKEN_METADATA_ERROR__DISABLED = 35;
var TOKEN_METADATA_ERROR__CREATORS_TOO_LONG = 36;
var TOKEN_METADATA_ERROR__CREATORS_MUST_BE_ATLEAST_ONE = 37;
var TOKEN_METADATA_ERROR__MUST_BE_ONE_OF_CREATORS = 38;
var TOKEN_METADATA_ERROR__NO_CREATORS_PRESENT_ON_METADATA = 39;
var TOKEN_METADATA_ERROR__CREATOR_NOT_FOUND = 40;
var TOKEN_METADATA_ERROR__INVALID_BASIS_POINTS = 41;
var TOKEN_METADATA_ERROR__PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE = 42;
var TOKEN_METADATA_ERROR__OWNER_MISMATCH = 43;
var TOKEN_METADATA_ERROR__NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION = 44;
var TOKEN_METADATA_ERROR__SHARE_TOTAL_MUST_BE100 = 45;
var TOKEN_METADATA_ERROR__RESERVATION_EXISTS = 46;
var TOKEN_METADATA_ERROR__RESERVATION_DOES_NOT_EXIST = 47;
var TOKEN_METADATA_ERROR__RESERVATION_NOT_SET = 48;
var TOKEN_METADATA_ERROR__RESERVATION_ALREADY_MADE = 49;
var TOKEN_METADATA_ERROR__BEYOND_MAX_ADDRESS_SIZE = 50;
var TOKEN_METADATA_ERROR__NUMERICAL_OVERFLOW_ERROR = 51;
var TOKEN_METADATA_ERROR__RESERVATION_BREACHES_MAXIMUM_SUPPLY = 52;
var TOKEN_METADATA_ERROR__ADDRESS_NOT_IN_RESERVATION = 53;
var TOKEN_METADATA_ERROR__CANNOT_VERIFY_ANOTHER_CREATOR = 54;
var TOKEN_METADATA_ERROR__CANNOT_UNVERIFY_ANOTHER_CREATOR = 55;
var TOKEN_METADATA_ERROR__SPOT_MISMATCH = 56;
var TOKEN_METADATA_ERROR__INCORRECT_OWNER = 57;
var TOKEN_METADATA_ERROR__PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY = 58;
var TOKEN_METADATA_ERROR__DATA_IS_IMMUTABLE = 59;
var TOKEN_METADATA_ERROR__DUPLICATE_CREATOR_ADDRESS = 60;
var TOKEN_METADATA_ERROR__RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START = 61;
var TOKEN_METADATA_ERROR__INVALID_TOKEN_PROGRAM = 62;
var TOKEN_METADATA_ERROR__DATA_TYPE_MISMATCH = 63;
var TOKEN_METADATA_ERROR__BEYOND_ALOTTED_ADDRESS_SIZE = 64;
var TOKEN_METADATA_ERROR__RESERVATION_NOT_COMPLETE = 65;
var TOKEN_METADATA_ERROR__TRIED_TO_REPLACE_AN_EXISTING_RESERVATION = 66;
var TOKEN_METADATA_ERROR__INVALID_OPERATION = 67;
var TOKEN_METADATA_ERROR__INVALID_OWNER = 68;
var TOKEN_METADATA_ERROR__PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION = 69;
var TOKEN_METADATA_ERROR__ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION = 70;
var TOKEN_METADATA_ERROR__INVALID_EDITION_INDEX = 71;
var TOKEN_METADATA_ERROR__RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE = 72;
var TOKEN_METADATA_ERROR__IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE = 73;
var TOKEN_METADATA_ERROR__COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION = 74;
var TOKEN_METADATA_ERROR__REMOVED = 75;
var TOKEN_METADATA_ERROR__MUST_BE_BURNED = 76;
var TOKEN_METADATA_ERROR__INVALID_USE_METHOD = 77;
var TOKEN_METADATA_ERROR__CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE = 78;
var TOKEN_METADATA_ERROR__CANNOT_CHANGE_USES_AFTER_FIRST_USE = 79;
var TOKEN_METADATA_ERROR__COLLECTION_NOT_FOUND = 80;
var TOKEN_METADATA_ERROR__INVALID_COLLECTION_UPDATE_AUTHORITY = 81;
var TOKEN_METADATA_ERROR__COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION = 82;
var TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_EXISTS = 83;
var TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_REVOKED = 84;
var TOKEN_METADATA_ERROR__UNUSABLE = 85;
var TOKEN_METADATA_ERROR__NOT_ENOUGH_USES = 86;
var TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS = 87;
var TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_DOES_NOT_EXIST = 88;
var TOKEN_METADATA_ERROR__INVALID_USE_AUTHORITY_RECORD = 89;
var TOKEN_METADATA_ERROR__INVALID_COLLECTION_AUTHORITY_RECORD = 90;
var TOKEN_METADATA_ERROR__INVALID_FREEZE_AUTHORITY = 91;
var TOKEN_METADATA_ERROR__INVALID_DELEGATE = 92;
var TOKEN_METADATA_ERROR__CANNOT_ADJUST_VERIFIED_CREATOR = 93;
var TOKEN_METADATA_ERROR__CANNOT_REMOVE_VERIFIED_CREATOR = 94;
var TOKEN_METADATA_ERROR__CANNOT_WIPE_VERIFIED_CREATORS = 95;
var TOKEN_METADATA_ERROR__NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS = 96;
var TOKEN_METADATA_ERROR__EDITION_OVERRIDE_CANNOT_BE_ZERO = 97;
var TOKEN_METADATA_ERROR__INVALID_USER = 98;
var TOKEN_METADATA_ERROR__REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT = 99;
var TOKEN_METADATA_ERROR__TOKEN_CLOSE_FAILED = 100;
var TOKEN_METADATA_ERROR__UNSIZED_COLLECTION = 101;
var TOKEN_METADATA_ERROR__SIZED_COLLECTION = 102;
var TOKEN_METADATA_ERROR__MISSING_COLLECTION_METADATA = 103;
var TOKEN_METADATA_ERROR__NOT_A_MEMBER_OF_COLLECTION = 104;
var TOKEN_METADATA_ERROR__NOT_VERIFIED_MEMBER_OF_COLLECTION = 105;
var TOKEN_METADATA_ERROR__NOT_A_COLLECTION_PARENT = 106;
var TOKEN_METADATA_ERROR__COULD_NOT_DETERMINE_TOKEN_STANDARD = 107;
var TOKEN_METADATA_ERROR__MISSING_EDITION_ACCOUNT = 108;
var TOKEN_METADATA_ERROR__NOT_A_MASTER_EDITION = 109;
var TOKEN_METADATA_ERROR__MASTER_EDITION_HAS_PRINTS = 110;
var TOKEN_METADATA_ERROR__BORSH_DESERIALIZATION_ERROR = 111;
var TOKEN_METADATA_ERROR__CANNOT_UPDATE_VERIFIED_COLLECTION = 112;
var TOKEN_METADATA_ERROR__COLLECTION_MASTER_EDITION_ACCOUNT_INVALID = 113;
var TOKEN_METADATA_ERROR__ALREADY_VERIFIED = 114;
var TOKEN_METADATA_ERROR__ALREADY_UNVERIFIED = 115;
var TOKEN_METADATA_ERROR__NOT_A_PRINT_EDITION = 116;
var TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION = 117;
var TOKEN_METADATA_ERROR__INVALID_PRINT_EDITION = 118;
var TOKEN_METADATA_ERROR__INVALID_EDITION_MARKER = 119;
var TOKEN_METADATA_ERROR__RESERVATION_LIST_DEPRECATED = 120;
var TOKEN_METADATA_ERROR__PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION = 121;
var TOKEN_METADATA_ERROR__EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY = 122;
var TOKEN_METADATA_ERROR__MUST_UNVERIFY = 123;
var TOKEN_METADATA_ERROR__INVALID_ESCROW_BUMP_SEED = 124;
var TOKEN_METADATA_ERROR__MUST_BE_ESCROW_AUTHORITY = 125;
var TOKEN_METADATA_ERROR__INVALID_SYSTEM_PROGRAM = 126;
var TOKEN_METADATA_ERROR__MUST_BE_NON_FUNGIBLE = 127;
var TOKEN_METADATA_ERROR__INSUFFICIENT_TOKENS = 128;
var TOKEN_METADATA_ERROR__BORSH_SERIALIZATION_ERROR = 129;
var TOKEN_METADATA_ERROR__NO_FREEZE_AUTHORITY_SET = 130;
var TOKEN_METADATA_ERROR__INVALID_COLLECTION_SIZE_CHANGE = 131;
var TOKEN_METADATA_ERROR__INVALID_BUBBLEGUM_SIGNER = 132;
var TOKEN_METADATA_ERROR__ESCROW_PARENT_HAS_DELEGATE = 133;
var TOKEN_METADATA_ERROR__MINT_IS_NOT_SIGNER = 134;
var TOKEN_METADATA_ERROR__INVALID_TOKEN_STANDARD = 135;
var TOKEN_METADATA_ERROR__INVALID_MINT_FOR_TOKEN_STANDARD = 136;
var TOKEN_METADATA_ERROR__INVALID_AUTHORIZATION_RULES = 137;
var TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES = 138;
var TOKEN_METADATA_ERROR__MISSING_PROGRAMMABLE_CONFIG = 139;
var TOKEN_METADATA_ERROR__INVALID_PROGRAMMABLE_CONFIG = 140;
var TOKEN_METADATA_ERROR__DELEGATE_ALREADY_EXISTS = 141;
var TOKEN_METADATA_ERROR__DELEGATE_NOT_FOUND = 142;
var TOKEN_METADATA_ERROR__MISSING_ACCOUNT_IN_BUILDER = 143;
var TOKEN_METADATA_ERROR__MISSING_ARGUMENT_IN_BUILDER = 144;
var TOKEN_METADATA_ERROR__FEATURE_NOT_SUPPORTED = 145;
var TOKEN_METADATA_ERROR__INVALID_SYSTEM_WALLET = 146;
var TOKEN_METADATA_ERROR__ONLY_SALE_DELEGATE_CAN_TRANSFER = 147;
var TOKEN_METADATA_ERROR__MISSING_TOKEN_ACCOUNT = 148;
var TOKEN_METADATA_ERROR__MISSING_SPL_TOKEN_PROGRAM = 149;
var TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES_PROGRAM = 150;
var TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE_FOR_TRANSFER = 151;
var TOKEN_METADATA_ERROR__INVALID_TRANSFER_AUTHORITY = 152;
var TOKEN_METADATA_ERROR__INSTRUCTION_NOT_SUPPORTED = 153;
var TOKEN_METADATA_ERROR__KEY_MISMATCH = 154;
var TOKEN_METADATA_ERROR__LOCKED_TOKEN = 155;
var TOKEN_METADATA_ERROR__UNLOCKED_TOKEN = 156;
var TOKEN_METADATA_ERROR__MISSING_DELEGATE_ROLE = 157;
var TOKEN_METADATA_ERROR__INVALID_AUTHORITY_TYPE = 158;
var TOKEN_METADATA_ERROR__MISSING_TOKEN_RECORD = 159;
var TOKEN_METADATA_ERROR__MINT_SUPPLY_MUST_BE_ZERO = 160;
var TOKEN_METADATA_ERROR__DATA_IS_EMPTY_OR_ZEROED = 161;
var TOKEN_METADATA_ERROR__MISSING_TOKEN_OWNER_ACCOUNT = 162;
var TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION_ACCOUNT_LENGTH = 163;
var TOKEN_METADATA_ERROR__INCORRECT_TOKEN_STATE = 164;
var TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE = 165;
var TOKEN_METADATA_ERROR__MISSING_PRINT_SUPPLY = 166;
var TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_ACCOUNT = 167;
var TOKEN_METADATA_ERROR__AMOUNT_MUST_BE_GREATER_THAN_ZERO = 168;
var TOKEN_METADATA_ERROR__INVALID_DELEGATE_ARGS = 169;
var TOKEN_METADATA_ERROR__MISSING_LOCKED_TRANSFER_ADDRESS = 170;
var TOKEN_METADATA_ERROR__INVALID_LOCKED_TRANSFER_ADDRESS = 171;
var TOKEN_METADATA_ERROR__DATA_INCREMENT_LIMIT_EXCEEDED = 172;
var TOKEN_METADATA_ERROR__CANNOT_UPDATE_ASSET_WITH_DELEGATE = 173;
var TOKEN_METADATA_ERROR__INVALID_AMOUNT = 174;
var TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_MINT_ACCOUNT = 175;
var TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_TOKEN_ACCOUNT = 176;
var TOKEN_METADATA_ERROR__MISSING_EDITION_MARKER_ACCOUNT = 177;
var TOKEN_METADATA_ERROR__CANNOT_BURN_WITH_DELEGATE = 178;
var TOKEN_METADATA_ERROR__MISSING_EDITION = 179;
var TOKEN_METADATA_ERROR__INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM = 180;
var TOKEN_METADATA_ERROR__INVALID_INSTRUCTIONS_SYSVAR = 181;
var TOKEN_METADATA_ERROR__INVALID_PARENT_ACCOUNTS = 182;
var TOKEN_METADATA_ERROR__INVALID_UPDATE_ARGS = 183;
var TOKEN_METADATA_ERROR__INSUFFICIENT_TOKEN_BALANCE = 184;
var TOKEN_METADATA_ERROR__MISSING_COLLECTION_MINT = 185;
var TOKEN_METADATA_ERROR__MISSING_COLLECTION_MASTER_EDITION = 186;
var TOKEN_METADATA_ERROR__INVALID_TOKEN_RECORD = 187;
var TOKEN_METADATA_ERROR__INVALID_CLOSE_AUTHORITY = 188;
var TOKEN_METADATA_ERROR__INVALID_INSTRUCTION = 189;
var TOKEN_METADATA_ERROR__MISSING_DELEGATE_RECORD = 190;
var TOKEN_METADATA_ERROR__INVALID_FEE_ACCOUNT = 191;
var TOKEN_METADATA_ERROR__INVALID_METADATA_FLAGS = 192;
var TOKEN_METADATA_ERROR__CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE = 193;
var TOKEN_METADATA_ERROR__INVALID_MINT_EXTENSION_TYPE = 194;
var TOKEN_METADATA_ERROR__INVALID_MINT_CLOSE_AUTHORITY = 195;
var TOKEN_METADATA_ERROR__INVALID_METADATA_POINTER = 196;
var TOKEN_METADATA_ERROR__INVALID_TOKEN_EXTENSION_TYPE = 197;
var TOKEN_METADATA_ERROR__MISSING_IMMUTABLE_OWNER_EXTENSION = 198;
var tokenMetadataErrorMessages;
if (__DEV__) {
  tokenMetadataErrorMessages = {
    [TOKEN_METADATA_ERROR__ADDRESS_NOT_IN_RESERVATION]: ``,
    [TOKEN_METADATA_ERROR__ALREADY_INITIALIZED]: `Already initialized`,
    [TOKEN_METADATA_ERROR__ALREADY_UNVERIFIED]: ``,
    [TOKEN_METADATA_ERROR__ALREADY_VERIFIED]: `Item is already verified.`,
    [TOKEN_METADATA_ERROR__AMOUNT_MUST_BE_GREATER_THAN_ZERO]: `Amount must be greater than zero`,
    [TOKEN_METADATA_ERROR__AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH]: ``,
    [TOKEN_METADATA_ERROR__BEYOND_ALOTTED_ADDRESS_SIZE]: ``,
    [TOKEN_METADATA_ERROR__BEYOND_MAX_ADDRESS_SIZE]: ``,
    [TOKEN_METADATA_ERROR__BORSH_DESERIALIZATION_ERROR]: ``,
    [TOKEN_METADATA_ERROR__BORSH_SERIALIZATION_ERROR]: `Borsh Serialization Error`,
    [TOKEN_METADATA_ERROR__CANNOT_ADJUST_VERIFIED_CREATOR]: ``,
    [TOKEN_METADATA_ERROR__CANNOT_BURN_WITH_DELEGATE]: `Cannot burn while persistent delegate is set`,
    [TOKEN_METADATA_ERROR__CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE]: `Cannot change the update authority with a delegate`,
    [TOKEN_METADATA_ERROR__CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE]: `Cannot Change Use Method after the first use`,
    [TOKEN_METADATA_ERROR__CANNOT_CHANGE_USES_AFTER_FIRST_USE]: `Cannot Change Remaining or Available uses after the first use`,
    [TOKEN_METADATA_ERROR__CANNOT_REMOVE_VERIFIED_CREATOR]: `Verified creators cannot be removed.`,
    [TOKEN_METADATA_ERROR__CANNOT_UNVERIFY_ANOTHER_CREATOR]: `You cannot unilaterally unverify another creator`,
    [TOKEN_METADATA_ERROR__CANNOT_UPDATE_ASSET_WITH_DELEGATE]: `Cannot update the rule set of a programmable asset that has a delegate`,
    [TOKEN_METADATA_ERROR__CANNOT_UPDATE_VERIFIED_COLLECTION]: `Cannot update a verified collection in this command`,
    [TOKEN_METADATA_ERROR__CANNOT_VERIFY_ANOTHER_CREATOR]: `You cannot unilaterally verify another creator, they must sign`,
    [TOKEN_METADATA_ERROR__CANNOT_WIPE_VERIFIED_CREATORS]: ``,
    [TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_DOES_NOT_EXIST]: `This Collection Authority Record Does Not Exist.`,
    [TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS]: `This Collection Authority Record Already Exists.`,
    [TOKEN_METADATA_ERROR__COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION]: `Collection cannot be verified in this instruction`,
    [TOKEN_METADATA_ERROR__COLLECTION_MASTER_EDITION_ACCOUNT_INVALID]: `Edition account doesnt match collection `,
    [TOKEN_METADATA_ERROR__COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION]: `Collection Must Be a Unique Master Edition v2`,
    [TOKEN_METADATA_ERROR__COLLECTION_NOT_FOUND]: `Collection Not Found on Metadata`,
    [TOKEN_METADATA_ERROR__COULD_NOT_DETERMINE_TOKEN_STANDARD]: `Could not determine a TokenStandard type.`,
    [TOKEN_METADATA_ERROR__CREATOR_NOT_FOUND]: `This creator address was not found`,
    [TOKEN_METADATA_ERROR__CREATORS_MUST_BE_ATLEAST_ONE]: `Creators must be at least one if set`,
    [TOKEN_METADATA_ERROR__CREATORS_TOO_LONG]: `Creators list too long`,
    [TOKEN_METADATA_ERROR__DATA_INCREMENT_LIMIT_EXCEEDED]: `Exceeded account realloc increase limit`,
    [TOKEN_METADATA_ERROR__DATA_IS_EMPTY_OR_ZEROED]: `Data is empty or zeroed`,
    [TOKEN_METADATA_ERROR__DATA_IS_IMMUTABLE]: `Data is immutable`,
    [TOKEN_METADATA_ERROR__DATA_TYPE_MISMATCH]: `Data type mismatch`,
    [TOKEN_METADATA_ERROR__DELEGATE_ALREADY_EXISTS]: `Delegate already exists`,
    [TOKEN_METADATA_ERROR__DELEGATE_NOT_FOUND]: `Delegate not found`,
    [TOKEN_METADATA_ERROR__DERIVED_KEY_INVALID]: `Derived key invalid`,
    [TOKEN_METADATA_ERROR__DESTINATION_MINT_MISMATCH]: ``,
    [TOKEN_METADATA_ERROR__DISABLED]: ``,
    [TOKEN_METADATA_ERROR__DUPLICATE_CREATOR_ADDRESS]: `No duplicate creator addresses`,
    [TOKEN_METADATA_ERROR__EDITION_ALREADY_MINTED]: ``,
    [TOKEN_METADATA_ERROR__EDITION_MINT_DECIMALS_SHOULD_BE_ZERO]: `EditionMintDecimalsShouldBeZero`,
    [TOKEN_METADATA_ERROR__EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY]: `Edition Number greater than max supply`,
    [TOKEN_METADATA_ERROR__EDITION_OVERRIDE_CANNOT_BE_ZERO]: `Edition override cannot be zero`,
    [TOKEN_METADATA_ERROR__EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN]: `Editions must have exactly one token`,
    [TOKEN_METADATA_ERROR__ESCROW_PARENT_HAS_DELEGATE]: `Escrow parent cannot have a delegate`,
    [TOKEN_METADATA_ERROR__FEATURE_NOT_SUPPORTED]: `Feature not supported currently`,
    [TOKEN_METADATA_ERROR__INCORRECT_OWNER]: `Incorrect account owner`,
    [TOKEN_METADATA_ERROR__INCORRECT_TOKEN_STATE]: `Incorrect token state`,
    [TOKEN_METADATA_ERROR__INSTRUCTION_NOT_SUPPORTED]: `Instruction not supported for ProgrammableNonFungible assets`,
    [TOKEN_METADATA_ERROR__INSTRUCTION_PACK_ERROR]: ``,
    [TOKEN_METADATA_ERROR__INSTRUCTION_UNPACK_ERROR]: ``,
    [TOKEN_METADATA_ERROR__INSUFFICIENT_TOKEN_BALANCE]: `Token account does not have enough tokens`,
    [TOKEN_METADATA_ERROR__INSUFFICIENT_TOKENS]: `Insufficient tokens for transfer`,
    [TOKEN_METADATA_ERROR__INVALID_AMOUNT]: `Invalid token amount for this operation or token standard`,
    [TOKEN_METADATA_ERROR__INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM]: `Invalid Associated Token Account Program`,
    [TOKEN_METADATA_ERROR__INVALID_AUTHORITY_TYPE]: `Invalid authority type`,
    [TOKEN_METADATA_ERROR__INVALID_AUTHORIZATION_RULES]: `Invalid authorization rules account`,
    [TOKEN_METADATA_ERROR__INVALID_BASIS_POINTS]: `Basis points cannot be more than 10000`,
    [TOKEN_METADATA_ERROR__INVALID_BUBBLEGUM_SIGNER]: `Invalid bubblegum signer`,
    [TOKEN_METADATA_ERROR__INVALID_CLOSE_AUTHORITY]: `The close authority needs to be revoked by the Utility Delegate`,
    [TOKEN_METADATA_ERROR__INVALID_COLLECTION_AUTHORITY_RECORD]: ``,
    [TOKEN_METADATA_ERROR__INVALID_COLLECTION_SIZE_CHANGE]: `Invalid collection size change`,
    [TOKEN_METADATA_ERROR__INVALID_COLLECTION_UPDATE_AUTHORITY]: `Collection Update Authority is invalid`,
    [TOKEN_METADATA_ERROR__INVALID_DELEGATE]: `All tokens in this account have not been delegated to this user.`,
    [TOKEN_METADATA_ERROR__INVALID_DELEGATE_ARGS]: `Invalid delegate args`,
    [TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE]: `Invalid delegate role`,
    [TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE_FOR_TRANSFER]: `Invalid delegate role for transfer`,
    [TOKEN_METADATA_ERROR__INVALID_EDITION_INDEX]: `You tried to insert one edition too many into an edition mark pda`,
    [TOKEN_METADATA_ERROR__INVALID_EDITION_KEY]: `Edition's key must match seed of ['metadata', program id, name, 'edition'] provided`,
    [TOKEN_METADATA_ERROR__INVALID_EDITION_MARKER]: `Invalid Edition Marker`,
    [TOKEN_METADATA_ERROR__INVALID_ESCROW_BUMP_SEED]: `Invalid Escrow Account Bump Seed`,
    [TOKEN_METADATA_ERROR__INVALID_FEE_ACCOUNT]: ``,
    [TOKEN_METADATA_ERROR__INVALID_FREEZE_AUTHORITY]: `Metadata does not match the freeze authority on the mint`,
    [TOKEN_METADATA_ERROR__INVALID_INSTRUCTION]: `Invalid or removed instruction`,
    [TOKEN_METADATA_ERROR__INVALID_INSTRUCTIONS_SYSVAR]: `Invalid InstructionsSysvar`,
    [TOKEN_METADATA_ERROR__INVALID_LOCKED_TRANSFER_ADDRESS]: `Invalid destination address for locked transfer`,
    [TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION]: `Invalid Master Edition`,
    [TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION_ACCOUNT_LENGTH]: `Master edition account has an invalid length`,
    [TOKEN_METADATA_ERROR__INVALID_METADATA_FLAGS]: ``,
    [TOKEN_METADATA_ERROR__INVALID_METADATA_KEY]: ` Metadata's key must match seed of ['metadata', program id, mint] provided`,
    [TOKEN_METADATA_ERROR__INVALID_METADATA_POINTER]: `Invalid metadata pointer`,
    [TOKEN_METADATA_ERROR__INVALID_MINT_AUTHORITY]: `Mint authority provided does not match the authority on the mint`,
    [TOKEN_METADATA_ERROR__INVALID_MINT_CLOSE_AUTHORITY]: `Invalid mint close authority`,
    [TOKEN_METADATA_ERROR__INVALID_MINT_EXTENSION_TYPE]: `Invalid mint extension type`,
    [TOKEN_METADATA_ERROR__INVALID_MINT_FOR_TOKEN_STANDARD]: `Invalid mint account for specified token standard`,
    [TOKEN_METADATA_ERROR__INVALID_OPERATION]: `Invalid operation`,
    [TOKEN_METADATA_ERROR__INVALID_OWNER]: `Invalid Owner`,
    [TOKEN_METADATA_ERROR__INVALID_PARENT_ACCOUNTS]: `Invalid or Unneeded parent accounts`,
    [TOKEN_METADATA_ERROR__INVALID_PRINT_EDITION]: `Invalid Print Edition`,
    [TOKEN_METADATA_ERROR__INVALID_PROGRAMMABLE_CONFIG]: `Invalid programmable configuration`,
    [TOKEN_METADATA_ERROR__INVALID_SYSTEM_PROGRAM]: `Invalid System Program`,
    [TOKEN_METADATA_ERROR__INVALID_SYSTEM_WALLET]: `Invalid system wallet`,
    [TOKEN_METADATA_ERROR__INVALID_TOKEN_EXTENSION_TYPE]: `Invalid token extension type`,
    [TOKEN_METADATA_ERROR__INVALID_TOKEN_PROGRAM]: `Invalid token program`,
    [TOKEN_METADATA_ERROR__INVALID_TOKEN_RECORD]: `Invalid token record account`,
    [TOKEN_METADATA_ERROR__INVALID_TOKEN_STANDARD]: `Invalid token standard`,
    [TOKEN_METADATA_ERROR__INVALID_TRANSFER_AUTHORITY]: `Invalid transfer authority`,
    [TOKEN_METADATA_ERROR__INVALID_UPDATE_ARGS]: `Authority cannot apply all update args`,
    [TOKEN_METADATA_ERROR__INVALID_USE_AUTHORITY_RECORD]: `This Use Authority Record is invalid.`,
    [TOKEN_METADATA_ERROR__INVALID_USE_METHOD]: `This use method is invalid`,
    [TOKEN_METADATA_ERROR__INVALID_USER]: `Invalid User`,
    [TOKEN_METADATA_ERROR__IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE]: `Is Mutable can only be flipped to false`,
    [TOKEN_METADATA_ERROR__KEY_MISMATCH]: `Public key does not match expected value`,
    [TOKEN_METADATA_ERROR__LOCKED_TOKEN]: `Token is locked`,
    [TOKEN_METADATA_ERROR__MASTER_EDITION_HAS_PRINTS]: `This Master Edition has existing prints`,
    [TOKEN_METADATA_ERROR__MASTER_RECORD_MISMATCH]: ``,
    [TOKEN_METADATA_ERROR__MAX_EDITIONS_MINTED_ALREADY]: ``,
    [TOKEN_METADATA_ERROR__MINT_IS_NOT_SIGNER]: `Mint needs to be signer to initialize the account`,
    [TOKEN_METADATA_ERROR__MINT_MISMATCH]: `Mint given does not match mint on Metadata`,
    [TOKEN_METADATA_ERROR__MINT_SUPPLY_MUST_BE_ZERO]: `Mint supply must be zero for programmable assets`,
    [TOKEN_METADATA_ERROR__MISSING_ACCOUNT_IN_BUILDER]: `Required account not set in instruction builder`,
    [TOKEN_METADATA_ERROR__MISSING_ARGUMENT_IN_BUILDER]: `Required argument not set in instruction builder`,
    [TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES]: `Missing authorization rules account`,
    [TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES_PROGRAM]: `Missing authorization rules program`,
    [TOKEN_METADATA_ERROR__MISSING_COLLECTION_MASTER_EDITION]: `Missing collection master edition account`,
    [TOKEN_METADATA_ERROR__MISSING_COLLECTION_METADATA]: `Missing collection metadata account`,
    [TOKEN_METADATA_ERROR__MISSING_COLLECTION_MINT]: `Missing collection account`,
    [TOKEN_METADATA_ERROR__MISSING_DELEGATE_RECORD]: `Missing delegate record`,
    [TOKEN_METADATA_ERROR__MISSING_DELEGATE_ROLE]: `Missing delegate role`,
    [TOKEN_METADATA_ERROR__MISSING_EDITION]: `Missing edition account`,
    [TOKEN_METADATA_ERROR__MISSING_EDITION_ACCOUNT]: `This mint account has an edition but none was provided.`,
    [TOKEN_METADATA_ERROR__MISSING_EDITION_MARKER_ACCOUNT]: `Missing edition marker account`,
    [TOKEN_METADATA_ERROR__MISSING_IMMUTABLE_OWNER_EXTENSION]: `Missing immutable owner extension`,
    [TOKEN_METADATA_ERROR__MISSING_LOCKED_TRANSFER_ADDRESS]: `Missing address for locked transfer`,
    [TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_ACCOUNT]: `Missing master edition account`,
    [TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_MINT_ACCOUNT]: `Missing master edition mint account`,
    [TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_TOKEN_ACCOUNT]: `Missing master edition token account`,
    [TOKEN_METADATA_ERROR__MISSING_PRINT_SUPPLY]: `Print supply is required for non-fungibles`,
    [TOKEN_METADATA_ERROR__MISSING_PROGRAMMABLE_CONFIG]: `Missing programmable configuration`,
    [TOKEN_METADATA_ERROR__MISSING_SPL_TOKEN_PROGRAM]: `Missing SPL token program`,
    [TOKEN_METADATA_ERROR__MISSING_TOKEN_ACCOUNT]: `Missing token account`,
    [TOKEN_METADATA_ERROR__MISSING_TOKEN_OWNER_ACCOUNT]: `Missing token owner`,
    [TOKEN_METADATA_ERROR__MISSING_TOKEN_RECORD]: `Missing token record account`,
    [TOKEN_METADATA_ERROR__MUST_BE_BURNED]: ``,
    [TOKEN_METADATA_ERROR__MUST_BE_ESCROW_AUTHORITY]: `Must Escrow Authority`,
    [TOKEN_METADATA_ERROR__MUST_BE_NON_FUNGIBLE]: `Must be a Non Fungible Token`,
    [TOKEN_METADATA_ERROR__MUST_BE_ONE_OF_CREATORS]: ``,
    [TOKEN_METADATA_ERROR__MUST_UNVERIFY]: `Must unverify before migrating collections.`,
    [TOKEN_METADATA_ERROR__NAME_TOO_LONG]: `Name too long`,
    [TOKEN_METADATA_ERROR__NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION]: `This account has no tokens to be used for authorization`,
    [TOKEN_METADATA_ERROR__NO_CREATORS_PRESENT_ON_METADATA]: `This metadata does not have creators`,
    [TOKEN_METADATA_ERROR__NO_FREEZE_AUTHORITY_SET]: `Cannot create NFT with no Freeze Authority.`,
    [TOKEN_METADATA_ERROR__NOT_A_COLLECTION_PARENT]: `This NFT is not a collection parent NFT.`,
    [TOKEN_METADATA_ERROR__NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS]: ``,
    [TOKEN_METADATA_ERROR__NOT_A_MASTER_EDITION]: `This edition is not a Master Edition`,
    [TOKEN_METADATA_ERROR__NOT_A_MEMBER_OF_COLLECTION]: `This NFT is not a member of the specified collection.`,
    [TOKEN_METADATA_ERROR__NOT_A_PRINT_EDITION]: `This edition is not a Print Edition`,
    [TOKEN_METADATA_ERROR__NOT_ENOUGH_TOKENS]: `Not enough tokens to mint a limited edition`,
    [TOKEN_METADATA_ERROR__NOT_ENOUGH_USES]: `There are not enough Uses left on this token.`,
    [TOKEN_METADATA_ERROR__NOT_MINT_AUTHORITY]: `You must be the mint authority and signer on this transaction`,
    [TOKEN_METADATA_ERROR__NOT_RENT_EXEMPT]: `Lamport balance below rent-exempt threshold`,
    [TOKEN_METADATA_ERROR__NOT_VERIFIED_MEMBER_OF_COLLECTION]: `This NFT is not a verified member of the specified collection.`,
    [TOKEN_METADATA_ERROR__NUMERICAL_OVERFLOW_ERROR]: `NumericalOverflowError`,
    [TOKEN_METADATA_ERROR__ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION]: `One Time Auth mint supply must be zero for conversion`,
    [TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTH_MINT_MISMATCH]: `The One Time Printing Auth mint does not match that on the master edition!`,
    [TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO]: ``,
    [TOKEN_METADATA_ERROR__ONLY_SALE_DELEGATE_CAN_TRANSFER]: `Only the sale delegate can transfer while its set`,
    [TOKEN_METADATA_ERROR__OWNER_MISMATCH]: `Owner does not match that on the account given`,
    [TOKEN_METADATA_ERROR__PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE]: `Primary sale can only be flipped to true and is immutable`,
    [TOKEN_METADATA_ERROR__PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION]: `Print Edition does not match Master Edition`,
    [TOKEN_METADATA_ERROR__PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH]: ``,
    [TOKEN_METADATA_ERROR__PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO]: ``,
    [TOKEN_METADATA_ERROR__PRINTING_MINT_MISMATCH]: `The Printing mint does not match that on the master edition!`,
    [TOKEN_METADATA_ERROR__PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION]: `Printing mint supply must be zero for conversion`,
    [TOKEN_METADATA_ERROR__PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY]: ``,
    [TOKEN_METADATA_ERROR__REMOVED]: `This instruction was deprecated in a previous release and is now removed`,
    [TOKEN_METADATA_ERROR__RESERVATION_ALREADY_MADE]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_BREACHES_MAXIMUM_SUPPLY]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_DOES_NOT_EXIST]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_EXISTS]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_LIST_DEPRECATED]: `Reservation List is Deprecated`,
    [TOKEN_METADATA_ERROR__RESERVATION_NOT_COMPLETE]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_NOT_SET]: ``,
    [TOKEN_METADATA_ERROR__RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START]: ``,
    [TOKEN_METADATA_ERROR__REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT]: `Revoke Collection Authority signer is incorrect`,
    [TOKEN_METADATA_ERROR__SHARE_TOTAL_MUST_BE100]: `Share total must equal 100 for creator array`,
    [TOKEN_METADATA_ERROR__SIZED_COLLECTION]: `Can't use this function on a sized collection`,
    [TOKEN_METADATA_ERROR__SPOT_MISMATCH]: ``,
    [TOKEN_METADATA_ERROR__SYMBOL_TOO_LONG]: `Symbol too long`,
    [TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH]: `The mint of the token account does not match the Printing mint!`,
    [TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH_V2]: `The mint of the token account does not match the master metadata mint!`,
    [TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH]: ``,
    [TOKEN_METADATA_ERROR__TOKEN_BURN_FAILED]: ``,
    [TOKEN_METADATA_ERROR__TOKEN_CLOSE_FAILED]: ``,
    [TOKEN_METADATA_ERROR__TOKEN_MINT_TO_FAILED]: ``,
    [TOKEN_METADATA_ERROR__TRIED_TO_REPLACE_AN_EXISTING_RESERVATION]: ``,
    [TOKEN_METADATA_ERROR__UNINITIALIZED]: `Uninitialized`,
    [TOKEN_METADATA_ERROR__UNLOCKED_TOKEN]: `Token is unlocked`,
    [TOKEN_METADATA_ERROR__UNSIZED_COLLECTION]: `Can't use this function on unsized collection`,
    [TOKEN_METADATA_ERROR__UNUSABLE]: `This token has no uses`,
    [TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_INCORRECT]: `Update Authority given does not match`,
    [TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_IS_NOT_SIGNER]: `Update Authority needs to be signer to update metadata`,
    [TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER]: ``,
    [TOKEN_METADATA_ERROR__URI_TOO_LONG]: `URI too long`,
    [TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_EXISTS]: `The Use Authority Record Already Exists, to modify it Revoke, then Approve`,
    [TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_REVOKED]: `The Use Authority Record is empty or already revoked`
  };
}
function getTokenMetadataErrorMessage(code) {
  if (__DEV__) {
    return tokenMetadataErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
var TOKEN_METADATA_PROGRAM_ADDRESS = "metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s";
var TokenMetadataAccount = /* @__PURE__ */ ((TokenMetadataAccount2) => {
  TokenMetadataAccount2[TokenMetadataAccount2["CollectionAuthorityRecord"] = 0] = "CollectionAuthorityRecord";
  TokenMetadataAccount2[TokenMetadataAccount2["MetadataDelegateRecord"] = 1] = "MetadataDelegateRecord";
  TokenMetadataAccount2[TokenMetadataAccount2["HolderDelegateRecord"] = 2] = "HolderDelegateRecord";
  TokenMetadataAccount2[TokenMetadataAccount2["Edition"] = 3] = "Edition";
  TokenMetadataAccount2[TokenMetadataAccount2["EditionMarker"] = 4] = "EditionMarker";
  TokenMetadataAccount2[TokenMetadataAccount2["EditionMarkerV2"] = 5] = "EditionMarkerV2";
  TokenMetadataAccount2[TokenMetadataAccount2["TokenOwnedEscrow"] = 6] = "TokenOwnedEscrow";
  TokenMetadataAccount2[TokenMetadataAccount2["MasterEdition"] = 7] = "MasterEdition";
  TokenMetadataAccount2[TokenMetadataAccount2["MasterEditionV1"] = 8] = "MasterEditionV1";
  TokenMetadataAccount2[TokenMetadataAccount2["Metadata"] = 9] = "Metadata";
  TokenMetadataAccount2[TokenMetadataAccount2["TokenRecord"] = 10] = "TokenRecord";
  TokenMetadataAccount2[TokenMetadataAccount2["ReservationListV2"] = 11] = "ReservationListV2";
  TokenMetadataAccount2[TokenMetadataAccount2["ReservationListV1"] = 12] = "ReservationListV1";
  TokenMetadataAccount2[TokenMetadataAccount2["UseAuthorityRecord"] = 13] = "UseAuthorityRecord";
  return TokenMetadataAccount2;
})(TokenMetadataAccount || {});
var TokenMetadataInstruction = /* @__PURE__ */ ((TokenMetadataInstruction2) => {
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateMetadataAccount"] = 0] = "CreateMetadataAccount";
  TokenMetadataInstruction2[TokenMetadataInstruction2["DeprecatedCreateMasterEdition"] = 1] = "DeprecatedCreateMasterEdition";
  TokenMetadataInstruction2[TokenMetadataInstruction2["DeprecatedMintNewEditionFromMasterEditionViaPrintingToken"] = 2] = "DeprecatedMintNewEditionFromMasterEditionViaPrintingToken";
  TokenMetadataInstruction2[TokenMetadataInstruction2["DeprecatedSetReservationList"] = 3] = "DeprecatedSetReservationList";
  TokenMetadataInstruction2[TokenMetadataInstruction2["DeprecatedCreateReservationList"] = 4] = "DeprecatedCreateReservationList";
  TokenMetadataInstruction2[TokenMetadataInstruction2["SignMetadata"] = 5] = "SignMetadata";
  TokenMetadataInstruction2[TokenMetadataInstruction2["DeprecatedMintPrintingTokensViaToken"] = 6] = "DeprecatedMintPrintingTokensViaToken";
  TokenMetadataInstruction2[TokenMetadataInstruction2["DeprecatedMintPrintingTokens"] = 7] = "DeprecatedMintPrintingTokens";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateMasterEdition"] = 8] = "CreateMasterEdition";
  TokenMetadataInstruction2[TokenMetadataInstruction2["MintNewEditionFromMasterEditionViaToken"] = 9] = "MintNewEditionFromMasterEditionViaToken";
  TokenMetadataInstruction2[TokenMetadataInstruction2["ConvertMasterEditionV1ToV2"] = 10] = "ConvertMasterEditionV1ToV2";
  TokenMetadataInstruction2[TokenMetadataInstruction2["MintNewEditionFromMasterEditionViaVaultProxy"] = 11] = "MintNewEditionFromMasterEditionViaVaultProxy";
  TokenMetadataInstruction2[TokenMetadataInstruction2["PuffMetadata"] = 12] = "PuffMetadata";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateMetadataAccountV2"] = 13] = "CreateMetadataAccountV2";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateMasterEditionV3"] = 14] = "CreateMasterEditionV3";
  TokenMetadataInstruction2[TokenMetadataInstruction2["VerifyCollection"] = 15] = "VerifyCollection";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Utilize"] = 16] = "Utilize";
  TokenMetadataInstruction2[TokenMetadataInstruction2["ApproveUseAuthority"] = 17] = "ApproveUseAuthority";
  TokenMetadataInstruction2[TokenMetadataInstruction2["UnverifyCollection"] = 18] = "UnverifyCollection";
  TokenMetadataInstruction2[TokenMetadataInstruction2["ApproveCollectionAuthority"] = 19] = "ApproveCollectionAuthority";
  TokenMetadataInstruction2[TokenMetadataInstruction2["SetAndVerifyCollection"] = 20] = "SetAndVerifyCollection";
  TokenMetadataInstruction2[TokenMetadataInstruction2["FreezeDelegatedAccount"] = 21] = "FreezeDelegatedAccount";
  TokenMetadataInstruction2[TokenMetadataInstruction2["ThawDelegatedAccount"] = 22] = "ThawDelegatedAccount";
  TokenMetadataInstruction2[TokenMetadataInstruction2["RemoveCreatorVerification"] = 23] = "RemoveCreatorVerification";
  TokenMetadataInstruction2[TokenMetadataInstruction2["BurnNft"] = 24] = "BurnNft";
  TokenMetadataInstruction2[TokenMetadataInstruction2["VerifySizedCollectionItem"] = 25] = "VerifySizedCollectionItem";
  TokenMetadataInstruction2[TokenMetadataInstruction2["UnverifySizedCollectionItem"] = 26] = "UnverifySizedCollectionItem";
  TokenMetadataInstruction2[TokenMetadataInstruction2["SetAndVerifySizedCollectionItem"] = 27] = "SetAndVerifySizedCollectionItem";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateMetadataAccountV3"] = 28] = "CreateMetadataAccountV3";
  TokenMetadataInstruction2[TokenMetadataInstruction2["SetCollectionSize"] = 29] = "SetCollectionSize";
  TokenMetadataInstruction2[TokenMetadataInstruction2["SetTokenStandard"] = 30] = "SetTokenStandard";
  TokenMetadataInstruction2[TokenMetadataInstruction2["BubblegumSetCollectionSize"] = 31] = "BubblegumSetCollectionSize";
  TokenMetadataInstruction2[TokenMetadataInstruction2["BurnEditionNft"] = 32] = "BurnEditionNft";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateEscrowAccount"] = 33] = "CreateEscrowAccount";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CloseEscrowAccount"] = 34] = "CloseEscrowAccount";
  TokenMetadataInstruction2[TokenMetadataInstruction2["TransferOutOfEscrow"] = 35] = "TransferOutOfEscrow";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Burn"] = 36] = "Burn";
  TokenMetadataInstruction2[TokenMetadataInstruction2["CreateV1"] = 37] = "CreateV1";
  TokenMetadataInstruction2[TokenMetadataInstruction2["MintV1"] = 38] = "MintV1";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Lock"] = 39] = "Lock";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Unlock"] = 40] = "Unlock";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Migrate"] = 41] = "Migrate";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Transfer"] = 42] = "Transfer";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Use"] = 43] = "Use";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Verify"] = 44] = "Verify";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Unverify"] = 45] = "Unverify";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Collect"] = 46] = "Collect";
  TokenMetadataInstruction2[TokenMetadataInstruction2["Print"] = 47] = "Print";
  return TokenMetadataInstruction2;
})(TokenMetadataInstruction || {});
function identifyTokenMetadataInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(0), 0)) {
    return 0 /* CreateMetadataAccount */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(2), 0)) {
    return 1 /* DeprecatedCreateMasterEdition */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(3), 0)) {
    return 2 /* DeprecatedMintNewEditionFromMasterEditionViaPrintingToken */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(5), 0)) {
    return 3 /* DeprecatedSetReservationList */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(6), 0)) {
    return 4 /* DeprecatedCreateReservationList */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(7), 0)) {
    return 5 /* SignMetadata */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(8), 0)) {
    return 6 /* DeprecatedMintPrintingTokensViaToken */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(9), 0)) {
    return 7 /* DeprecatedMintPrintingTokens */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(10), 0)) {
    return 8 /* CreateMasterEdition */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(11), 0)) {
    return 9 /* MintNewEditionFromMasterEditionViaToken */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(12), 0)) {
    return 10 /* ConvertMasterEditionV1ToV2 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(13), 0)) {
    return 11 /* MintNewEditionFromMasterEditionViaVaultProxy */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(14), 0)) {
    return 12 /* PuffMetadata */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(16), 0)) {
    return 13 /* CreateMetadataAccountV2 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(17), 0)) {
    return 14 /* CreateMasterEditionV3 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(18), 0)) {
    return 15 /* VerifyCollection */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(19), 0)) {
    return 16 /* Utilize */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(20), 0)) {
    return 17 /* ApproveUseAuthority */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(22), 0)) {
    return 18 /* UnverifyCollection */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(23), 0)) {
    return 19 /* ApproveCollectionAuthority */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(25), 0)) {
    return 20 /* SetAndVerifyCollection */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(26), 0)) {
    return 21 /* FreezeDelegatedAccount */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(27), 0)) {
    return 22 /* ThawDelegatedAccount */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(28), 0)) {
    return 23 /* RemoveCreatorVerification */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(29), 0)) {
    return 24 /* BurnNft */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(30), 0)) {
    return 25 /* VerifySizedCollectionItem */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(31), 0)) {
    return 26 /* UnverifySizedCollectionItem */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(32), 0)) {
    return 27 /* SetAndVerifySizedCollectionItem */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(33), 0)) {
    return 28 /* CreateMetadataAccountV3 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(34), 0)) {
    return 29 /* SetCollectionSize */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(35), 0)) {
    return 30 /* SetTokenStandard */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(36), 0)) {
    return 31 /* BubblegumSetCollectionSize */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(37), 0)) {
    return 32 /* BurnEditionNft */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(38), 0)) {
    return 33 /* CreateEscrowAccount */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(39), 0)) {
    return 34 /* CloseEscrowAccount */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(40), 0)) {
    return 35 /* TransferOutOfEscrow */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(41), 0)) {
    return 36 /* Burn */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(42), 0)) {
    return 37 /* CreateV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(43), 0)) {
    return 38 /* MintV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(46), 0)) {
    return 39 /* Lock */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(47), 0)) {
    return 40 /* Unlock */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(48), 0)) {
    return 41 /* Migrate */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(49), 0)) {
    return 42 /* Transfer */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(51), 0)) {
    return 43 /* Use */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(52), 0)) {
    return 44 /* Verify */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(53), 0)) {
    return 45 /* Unverify */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(54), 0)) {
    return 46 /* Collect */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(55), 0)) {
    return 47 /* Print */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tokenMetadata instruction."
  );
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      if (optionalAccountStrategy === "omitted") return;
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/generated/instructions/approveCollectionAuthority.ts
function getApproveCollectionAuthorityInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 23 })
  );
}
function getApproveCollectionAuthorityInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getApproveCollectionAuthorityInstructionDataCodec() {
  return web3_js.combineCodec(
    getApproveCollectionAuthorityInstructionDataEncoder(),
    getApproveCollectionAuthorityInstructionDataDecoder()
  );
}
function getApproveCollectionAuthorityInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: true
    },
    newCollectionAuthority: {
      value: input.newCollectionAuthority ?? null,
      isWritable: false
    },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collectionAuthorityRecord),
      getAccountMeta(accounts.newCollectionAuthority),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getApproveCollectionAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseApproveCollectionAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 7;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collectionAuthorityRecord: getNextAccount(),
      newCollectionAuthority: getNextAccount(),
      updateAuthority: getNextAccount(),
      payer: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getApproveCollectionAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getApproveUseAuthorityInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["numberOfUses", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 20 })
  );
}
function getApproveUseAuthorityInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["numberOfUses", web3_js.getU64Decoder()]
  ]);
}
function getApproveUseAuthorityInstructionDataCodec() {
  return web3_js.combineCodec(
    getApproveUseAuthorityInstructionDataEncoder(),
    getApproveUseAuthorityInstructionDataDecoder()
  );
}
function getApproveUseAuthorityInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    useAuthorityRecord: {
      value: input.useAuthorityRecord ?? null,
      isWritable: true
    },
    owner: { value: input.owner ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: false },
    ownerTokenAccount: {
      value: input.ownerTokenAccount ?? null,
      isWritable: true
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    burner: { value: input.burner ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.useAuthorityRecord),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.ownerTokenAccount),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.burner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getApproveUseAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseApproveUseAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 10;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      useAuthorityRecord: getNextAccount(),
      owner: getNextAccount(),
      payer: getNextAccount(),
      user: getNextAccount(),
      ownerTokenAccount: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      burner: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getApproveUseAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getBubblegumSetCollectionSizeInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["setCollectionSizeArgs", getSetCollectionSizeArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 36 })
  );
}
function getBubblegumSetCollectionSizeInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["setCollectionSizeArgs", getSetCollectionSizeArgsDecoder()]
  ]);
}
function getBubblegumSetCollectionSizeInstructionDataCodec() {
  return web3_js.combineCodec(
    getBubblegumSetCollectionSizeInstructionDataEncoder(),
    getBubblegumSetCollectionSizeInstructionDataDecoder()
  );
}
function getBubblegumSetCollectionSizeInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    bubblegumSigner: {
      value: input.bubblegumSigner ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collectionMetadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.bubblegumSigner),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getBubblegumSetCollectionSizeInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBubblegumSetCollectionSizeInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 4;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collectionMetadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      bubblegumSigner: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getBubblegumSetCollectionSizeInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getBurnInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["burnArgs", getBurnArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 41 })
  );
}
function getBurnInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["burnArgs", getBurnArgsDecoder()]
  ]);
}
function getBurnInstructionDataCodec() {
  return web3_js.combineCodec(
    getBurnInstructionDataEncoder(),
    getBurnInstructionDataDecoder()
  );
}
function getBurnInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: true },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    masterEditionMint: {
      value: input.masterEditionMint ?? null,
      isWritable: false
    },
    masterEditionToken: {
      value: input.masterEditionToken ?? null,
      isWritable: false
    },
    editionMarker: { value: input.editionMarker ?? null, isWritable: true },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.collectionMetadata),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.masterEditionMint),
      getAccountMeta(accounts.masterEditionToken),
      getAccountMeta(accounts.editionMarker),
      getAccountMeta(accounts.tokenRecord),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram)
    ],
    programAddress,
    data: getBurnInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBurnInstruction(instruction) {
  if (instruction.accounts.length < 14) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      collectionMetadata: getNextOptionalAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      mint: getNextAccount(),
      token: getNextAccount(),
      masterEdition: getNextOptionalAccount(),
      masterEditionMint: getNextOptionalAccount(),
      masterEditionToken: getNextOptionalAccount(),
      editionMarker: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount()
    },
    data: getBurnInstructionDataDecoder().decode(instruction.data)
  };
}
function getBurnEditionNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 37 })
  );
}
function getBurnEditionNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getBurnEditionNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getBurnEditionNftInstructionDataEncoder(),
    getBurnEditionNftInstructionDataDecoder()
  );
}
function getBurnEditionNftInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    printEditionMint: {
      value: input.printEditionMint ?? null,
      isWritable: true
    },
    masterEditionMint: {
      value: input.masterEditionMint ?? null,
      isWritable: false
    },
    printEditionTokenAccount: {
      value: input.printEditionTokenAccount ?? null,
      isWritable: true
    },
    masterEditionTokenAccount: {
      value: input.masterEditionTokenAccount ?? null,
      isWritable: false
    },
    masterEditionAccount: {
      value: input.masterEditionAccount ?? null,
      isWritable: true
    },
    printEditionAccount: {
      value: input.printEditionAccount ?? null,
      isWritable: true
    },
    editionMarkerAccount: {
      value: input.editionMarkerAccount ?? null,
      isWritable: true
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.printEditionMint),
      getAccountMeta(accounts.masterEditionMint),
      getAccountMeta(accounts.printEditionTokenAccount),
      getAccountMeta(accounts.masterEditionTokenAccount),
      getAccountMeta(accounts.masterEditionAccount),
      getAccountMeta(accounts.printEditionAccount),
      getAccountMeta(accounts.editionMarkerAccount),
      getAccountMeta(accounts.splTokenProgram)
    ],
    programAddress,
    data: getBurnEditionNftInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseBurnEditionNftInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      owner: getNextAccount(),
      printEditionMint: getNextAccount(),
      masterEditionMint: getNextAccount(),
      printEditionTokenAccount: getNextAccount(),
      masterEditionTokenAccount: getNextAccount(),
      masterEditionAccount: getNextAccount(),
      printEditionAccount: getNextAccount(),
      editionMarkerAccount: getNextAccount(),
      splTokenProgram: getNextAccount()
    },
    data: getBurnEditionNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getBurnNftInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 29 })
  );
}
function getBurnNftInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getBurnNftInstructionDataCodec() {
  return web3_js.combineCodec(
    getBurnNftInstructionDataEncoder(),
    getBurnNftInstructionDataDecoder()
  );
}
function getBurnNftInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    masterEditionAccount: {
      value: input.masterEditionAccount ?? null,
      isWritable: true
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    }
  };
  const accounts = originalAccounts;
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.masterEditionAccount),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.collectionMetadata)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getBurnNftInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseBurnNftInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      owner: getNextAccount(),
      mint: getNextAccount(),
      tokenAccount: getNextAccount(),
      masterEditionAccount: getNextAccount(),
      splTokenProgram: getNextAccount(),
      collectionMetadata: getNextOptionalAccount()
    },
    data: getBurnNftInstructionDataDecoder().decode(instruction.data)
  };
}
function getCloseEscrowAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 39 })
  );
}
function getCloseEscrowAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCloseEscrowAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getCloseEscrowAccountInstructionDataEncoder(),
    getCloseEscrowAccountInstructionDataDecoder()
  );
}
function getCloseEscrowAccountInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    escrow: { value: input.escrow ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.escrow),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getCloseEscrowAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseEscrowAccountInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      escrow: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getCloseEscrowAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCollectInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 54 })
  );
}
function getCollectInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCollectInstructionDataCodec() {
  return web3_js.combineCodec(
    getCollectInstructionDataEncoder(),
    getCollectInstructionDataDecoder()
  );
}
function getCollectInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    recipient: { value: input.recipient ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.recipient)
    ],
    programAddress,
    data: getCollectInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCollectInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      recipient: getNextAccount()
    },
    data: getCollectInstructionDataDecoder().decode(instruction.data)
  };
}
function getConvertMasterEditionV1ToV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 12 })
  );
}
function getConvertMasterEditionV1ToV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getConvertMasterEditionV1ToV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getConvertMasterEditionV1ToV2InstructionDataEncoder(),
    getConvertMasterEditionV1ToV2InstructionDataDecoder()
  );
}
function getConvertMasterEditionV1ToV2Instruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    oneTimeAuth: { value: input.oneTimeAuth ?? null, isWritable: true },
    printingMint: { value: input.printingMint ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.oneTimeAuth),
      getAccountMeta(accounts.printingMint)
    ],
    programAddress,
    data: getConvertMasterEditionV1ToV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseConvertMasterEditionV1ToV2Instruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      masterEdition: getNextAccount(),
      oneTimeAuth: getNextAccount(),
      printingMint: getNextAccount()
    },
    data: getConvertMasterEditionV1ToV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateEscrowAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 38 })
  );
}
function getCreateEscrowAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCreateEscrowAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateEscrowAccountInstructionDataEncoder(),
    getCreateEscrowAccountInstructionDataDecoder()
  );
}
function getCreateEscrowAccountInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    escrow: { value: input.escrow ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authority: { value: input.authority ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.escrow),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authority)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getCreateEscrowAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCreateEscrowAccountInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 8;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      escrow: getNextAccount(),
      metadata: getNextAccount(),
      mint: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      authority: getNextOptionalAccount()
    },
    data: getCreateEscrowAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMasterEditionInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 10 })
  );
}
function getCreateMasterEditionInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCreateMasterEditionInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateMasterEditionInstructionDataEncoder(),
    getCreateMasterEditionInstructionDataDecoder()
  );
}
function getCreateMasterEditionInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ],
    programAddress,
    data: getCreateMasterEditionInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCreateMasterEditionInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      edition: getNextAccount(),
      mint: getNextAccount(),
      updateAuthority: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount()
    },
    data: getCreateMasterEditionInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMasterEditionV3InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["maxSupply", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
    ]),
    (value) => ({ ...value, discriminator: 17 })
  );
}
function getCreateMasterEditionV3InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["maxSupply", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getCreateMasterEditionV3InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateMasterEditionV3InstructionDataEncoder(),
    getCreateMasterEditionV3InstructionDataDecoder()
  );
}
function getCreateMasterEditionV3Instruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    metadata: { value: input.metadata ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getCreateMasterEditionV3InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateMasterEditionV3Instruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 8;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      edition: getNextAccount(),
      mint: getNextAccount(),
      updateAuthority: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getCreateMasterEditionV3InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMetadataAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 0 })
  );
}
function getCreateMetadataAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCreateMetadataAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateMetadataAccountInstructionDataEncoder(),
    getCreateMetadataAccountInstructionDataDecoder()
  );
}
function getCreateMetadataAccountInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ],
    programAddress,
    data: getCreateMetadataAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCreateMetadataAccountInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      mint: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount()
    },
    data: getCreateMetadataAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMetadataAccountV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 16 })
  );
}
function getCreateMetadataAccountV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCreateMetadataAccountV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateMetadataAccountV2InstructionDataEncoder(),
    getCreateMetadataAccountV2InstructionDataDecoder()
  );
}
function getCreateMetadataAccountV2Instruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getCreateMetadataAccountV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCreateMetadataAccountV2Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      mint: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getCreateMetadataAccountV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMetadataAccountV3InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["data", getDataV2Encoder()],
      ["isMutable", web3_js.getBooleanEncoder()],
      ["collectionDetails", web3_js.getOptionEncoder(getCollectionDetailsEncoder())]
    ]),
    (value) => ({ ...value, discriminator: 33 })
  );
}
function getCreateMetadataAccountV3InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["data", getDataV2Decoder()],
    ["isMutable", web3_js.getBooleanDecoder()],
    ["collectionDetails", web3_js.getOptionDecoder(getCollectionDetailsDecoder())]
  ]);
}
function getCreateMetadataAccountV3InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateMetadataAccountV3InstructionDataEncoder(),
    getCreateMetadataAccountV3InstructionDataDecoder()
  );
}
function getCreateMetadataAccountV3Instruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getCreateMetadataAccountV3InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateMetadataAccountV3Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      mint: getNextAccount(),
      mintAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getCreateMetadataAccountV3InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["createV1Discriminator", web3_js.getU8Encoder()],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["sellerFeeBasisPoints", web3_js.getU16Encoder()],
      ["creators", web3_js.getOptionEncoder(web3_js.getArrayEncoder(getCreatorEncoder()))],
      ["primarySaleHappened", web3_js.getBooleanEncoder()],
      ["isMutable", web3_js.getBooleanEncoder()],
      ["tokenStandard", getTokenStandardEncoder()],
      ["collection", web3_js.getOptionEncoder(getCollectionEncoder())],
      ["uses", web3_js.getOptionEncoder(getUsesEncoder())],
      ["collectionDetails", web3_js.getOptionEncoder(getCollectionDetailsEncoder())],
      ["ruleSet", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
      ["decimals", web3_js.getOptionEncoder(web3_js.getU8Encoder())],
      ["printSupply", web3_js.getOptionEncoder(getPrintSupplyEncoder())]
    ]),
    (value) => ({ ...value, discriminator: 42, createV1Discriminator: 0 })
  );
}
function getCreateV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["createV1Discriminator", web3_js.getU8Decoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["sellerFeeBasisPoints", web3_js.getU16Decoder()],
    ["creators", web3_js.getOptionDecoder(web3_js.getArrayDecoder(getCreatorDecoder()))],
    ["primarySaleHappened", web3_js.getBooleanDecoder()],
    ["isMutable", web3_js.getBooleanDecoder()],
    ["tokenStandard", getTokenStandardDecoder()],
    ["collection", web3_js.getOptionDecoder(getCollectionDecoder())],
    ["uses", web3_js.getOptionDecoder(getUsesDecoder())],
    ["collectionDetails", web3_js.getOptionDecoder(getCollectionDetailsDecoder())],
    ["ruleSet", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
    ["decimals", web3_js.getOptionDecoder(web3_js.getU8Decoder())],
    ["printSupply", web3_js.getOptionDecoder(getPrintSupplyDecoder())]
  ]);
}
function getCreateV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateV1InstructionDataEncoder(),
    getCreateV1InstructionDataDecoder()
  );
}
async function getCreateV1InstructionAsync(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.masterEdition.value) {
    accounts.masterEdition.value = await findMasterEditionPda({
      mint: expectAddress(accounts.mint.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram)
    ],
    programAddress,
    data: getCreateV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreateV1Instruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram)
    ],
    programAddress,
    data: getCreateV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateV1Instruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      masterEdition: getNextOptionalAccount(),
      mint: getNextAccount(),
      authority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount()
    },
    data: getCreateV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getDeprecatedCreateMasterEditionInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 2 })
  );
}
function getDeprecatedCreateMasterEditionInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getDeprecatedCreateMasterEditionInstructionDataCodec() {
  return web3_js.combineCodec(
    getDeprecatedCreateMasterEditionInstructionDataEncoder(),
    getDeprecatedCreateMasterEditionInstructionDataDecoder()
  );
}
function getDeprecatedCreateMasterEditionInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    edition: { value: input.edition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    printingMint: { value: input.printingMint ?? null, isWritable: true },
    oneTimePrintingAuthorizationMint: {
      value: input.oneTimePrintingAuthorizationMint ?? null,
      isWritable: true
    },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    printingMintAuthority: {
      value: input.printingMintAuthority ?? null,
      isWritable: false
    },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    oneTimePrintingAuthorizationMintAuthority: {
      value: input.oneTimePrintingAuthorizationMintAuthority ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.printingMint),
      getAccountMeta(accounts.oneTimePrintingAuthorizationMint),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.printingMintAuthority),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.oneTimePrintingAuthorizationMintAuthority)
    ],
    programAddress,
    data: getDeprecatedCreateMasterEditionInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDeprecatedCreateMasterEditionInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      edition: getNextAccount(),
      mint: getNextAccount(),
      printingMint: getNextAccount(),
      oneTimePrintingAuthorizationMint: getNextAccount(),
      updateAuthority: getNextAccount(),
      printingMintAuthority: getNextAccount(),
      mintAuthority: getNextAccount(),
      metadata: getNextAccount(),
      payer: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount(),
      oneTimePrintingAuthorizationMintAuthority: getNextAccount()
    },
    data: getDeprecatedCreateMasterEditionInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getDeprecatedCreateReservationListInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 6 })
  );
}
function getDeprecatedCreateReservationListInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getDeprecatedCreateReservationListInstructionDataCodec() {
  return web3_js.combineCodec(
    getDeprecatedCreateReservationListInstructionDataEncoder(),
    getDeprecatedCreateReservationListInstructionDataDecoder()
  );
}
function getDeprecatedCreateReservationListInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    reservationList: { value: input.reservationList ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: false },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    masterEdition: { value: input.masterEdition ?? null, isWritable: false },
    resource: { value: input.resource ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.reservationList),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.resource),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ],
    programAddress,
    data: getDeprecatedCreateReservationListInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDeprecatedCreateReservationListInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      reservationList: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      masterEdition: getNextAccount(),
      resource: getNextAccount(),
      metadata: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount()
    },
    data: getDeprecatedCreateReservationListInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 3 })
  );
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataCodec() {
  return web3_js.combineCodec(
    getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder(),
    getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder()
  );
}
function getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false },
    printingMint: { value: input.printingMint ?? null, isWritable: true },
    masterTokenAccount: {
      value: input.masterTokenAccount ?? null,
      isWritable: true
    },
    editionMarker: { value: input.editionMarker ?? null, isWritable: true },
    burnAuthority: { value: input.burnAuthority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: false },
    masterUpdateAuthority: {
      value: input.masterUpdateAuthority ?? null,
      isWritable: false
    },
    masterMetadata: { value: input.masterMetadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    reservationList: { value: input.reservationList ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintAuthority),
      getAccountMeta(accounts.printingMint),
      getAccountMeta(accounts.masterTokenAccount),
      getAccountMeta(accounts.editionMarker),
      getAccountMeta(accounts.burnAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.masterUpdateAuthority),
      getAccountMeta(accounts.masterMetadata),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.reservationList)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder().encode(
      {}
    )
  };
  return instruction;
}
function parseDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 15;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      edition: getNextAccount(),
      masterEdition: getNextAccount(),
      mint: getNextAccount(),
      mintAuthority: getNextAccount(),
      printingMint: getNextAccount(),
      masterTokenAccount: getNextAccount(),
      editionMarker: getNextAccount(),
      burnAuthority: getNextAccount(),
      payer: getNextAccount(),
      masterUpdateAuthority: getNextAccount(),
      masterMetadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount(),
      reservationList: getNextOptionalAccount()
    },
    data: getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getDeprecatedMintPrintingTokensInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 9 })
  );
}
function getDeprecatedMintPrintingTokensInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getDeprecatedMintPrintingTokensInstructionDataCodec() {
  return web3_js.combineCodec(
    getDeprecatedMintPrintingTokensInstructionDataEncoder(),
    getDeprecatedMintPrintingTokensInstructionDataDecoder()
  );
}
function getDeprecatedMintPrintingTokensInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    destination: { value: input.destination ?? null, isWritable: true },
    printingMint: { value: input.printingMint ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    masterEdition: { value: input.masterEdition ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.printingMint),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.rent)
    ],
    programAddress,
    data: getDeprecatedMintPrintingTokensInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDeprecatedMintPrintingTokensInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      destination: getNextAccount(),
      printingMint: getNextAccount(),
      updateAuthority: getNextAccount(),
      metadata: getNextAccount(),
      masterEdition: getNextAccount(),
      tokenProgram: getNextAccount(),
      rent: getNextAccount()
    },
    data: getDeprecatedMintPrintingTokensInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getDeprecatedMintPrintingTokensViaTokenInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 8 })
  );
}
function getDeprecatedMintPrintingTokensViaTokenInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getDeprecatedMintPrintingTokensViaTokenInstructionDataCodec() {
  return web3_js.combineCodec(
    getDeprecatedMintPrintingTokensViaTokenInstructionDataEncoder(),
    getDeprecatedMintPrintingTokensViaTokenInstructionDataDecoder()
  );
}
function getDeprecatedMintPrintingTokensViaTokenInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    destination: { value: input.destination ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    oneTimePrintingAuthorizationMint: {
      value: input.oneTimePrintingAuthorizationMint ?? null,
      isWritable: true
    },
    printingMint: { value: input.printingMint ?? null, isWritable: true },
    burnAuthority: { value: input.burnAuthority ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: false },
    masterEdition: { value: input.masterEdition ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.oneTimePrintingAuthorizationMint),
      getAccountMeta(accounts.printingMint),
      getAccountMeta(accounts.burnAuthority),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.rent)
    ],
    programAddress,
    data: getDeprecatedMintPrintingTokensViaTokenInstructionDataEncoder().encode(
      {}
    )
  };
  return instruction;
}
function parseDeprecatedMintPrintingTokensViaTokenInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      destination: getNextAccount(),
      token: getNextAccount(),
      oneTimePrintingAuthorizationMint: getNextAccount(),
      printingMint: getNextAccount(),
      burnAuthority: getNextAccount(),
      metadata: getNextAccount(),
      masterEdition: getNextAccount(),
      tokenProgram: getNextAccount(),
      rent: getNextAccount()
    },
    data: getDeprecatedMintPrintingTokensViaTokenInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getDeprecatedSetReservationListInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 5 })
  );
}
function getDeprecatedSetReservationListInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getDeprecatedSetReservationListInstructionDataCodec() {
  return web3_js.combineCodec(
    getDeprecatedSetReservationListInstructionDataEncoder(),
    getDeprecatedSetReservationListInstructionDataDecoder()
  );
}
function getDeprecatedSetReservationListInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    reservationList: { value: input.reservationList ?? null, isWritable: true },
    resource: { value: input.resource ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.reservationList),
      getAccountMeta(accounts.resource)
    ],
    programAddress,
    data: getDeprecatedSetReservationListInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseDeprecatedSetReservationListInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      masterEdition: getNextAccount(),
      reservationList: getNextAccount(),
      resource: getNextAccount()
    },
    data: getDeprecatedSetReservationListInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getFreezeDelegatedAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 26 })
  );
}
function getFreezeDelegatedAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getFreezeDelegatedAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getFreezeDelegatedAccountInstructionDataEncoder(),
    getFreezeDelegatedAccountInstructionDataDecoder()
  );
}
function getFreezeDelegatedAccountInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    delegate: { value: input.delegate ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getFreezeDelegatedAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeDelegatedAccountInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      delegate: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      mint: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getFreezeDelegatedAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getLockInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["lockArgs", getLockArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 46 })
  );
}
function getLockInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["lockArgs", getLockArgsDecoder()]
  ]);
}
function getLockInstructionDataCodec() {
  return web3_js.combineCodec(
    getLockInstructionDataEncoder(),
    getLockInstructionDataDecoder()
  );
}
function getLockInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.tokenOwner),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.tokenRecord),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authorizationRules)
    ],
    programAddress,
    data: getLockInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseLockInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      tokenOwner: getNextOptionalAccount(),
      token: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getLockInstructionDataDecoder().decode(instruction.data)
  };
}
function getMigrateInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 48 })
  );
}
function getMigrateInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getMigrateInstructionDataCodec() {
  return web3_js.combineCodec(
    getMigrateInstructionDataEncoder(),
    getMigrateInstructionDataDecoder()
  );
}
function getMigrateInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: false
    },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.tokenOwner),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.collectionMetadata),
      getAccountMeta(accounts.delegateRecord),
      getAccountMeta(accounts.tokenRecord),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authorizationRules)
    ],
    programAddress,
    data: getMigrateInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseMigrateInstruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      edition: getNextAccount(),
      token: getNextAccount(),
      tokenOwner: getNextAccount(),
      mint: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextAccount(),
      collectionMetadata: getNextAccount(),
      delegateRecord: getNextAccount(),
      tokenRecord: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getMigrateInstructionDataDecoder().decode(instruction.data)
  };
}
function getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      [
        "mintNewEditionFromMasterEditionViaTokenArgs",
        getMintNewEditionFromMasterEditionViaTokenArgsEncoder()
      ]
    ]),
    (value) => ({ ...value, discriminator: 11 })
  );
}
function getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    [
      "mintNewEditionFromMasterEditionViaTokenArgs",
      getMintNewEditionFromMasterEditionViaTokenArgsDecoder()
    ]
  ]);
}
function getMintNewEditionFromMasterEditionViaTokenInstructionDataCodec() {
  return web3_js.combineCodec(
    getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder(),
    getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder()
  );
}
function getMintNewEditionFromMasterEditionViaTokenInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    newMetadata: { value: input.newMetadata ?? null, isWritable: true },
    newEdition: { value: input.newEdition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    newMint: { value: input.newMint ?? null, isWritable: true },
    editionMarkPda: { value: input.editionMarkPda ?? null, isWritable: true },
    newMintAuthority: {
      value: input.newMintAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    tokenAccountOwner: {
      value: input.tokenAccountOwner ?? null,
      isWritable: false
    },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: false },
    newMetadataUpdateAuthority: {
      value: input.newMetadataUpdateAuthority ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.newMetadata),
      getAccountMeta(accounts.newEdition),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.newMint),
      getAccountMeta(accounts.editionMarkPda),
      getAccountMeta(accounts.newMintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.tokenAccountOwner),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.newMetadataUpdateAuthority),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseMintNewEditionFromMasterEditionViaTokenInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 13;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      newMetadata: getNextAccount(),
      newEdition: getNextAccount(),
      masterEdition: getNextAccount(),
      newMint: getNextAccount(),
      editionMarkPda: getNextAccount(),
      newMintAuthority: getNextAccount(),
      payer: getNextAccount(),
      tokenAccountOwner: getNextAccount(),
      tokenAccount: getNextAccount(),
      newMetadataUpdateAuthority: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      [
        "mintNewEditionFromMasterEditionViaTokenArgs",
        getMintNewEditionFromMasterEditionViaTokenArgsEncoder()
      ]
    ]),
    (value) => ({ ...value, discriminator: 13 })
  );
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    [
      "mintNewEditionFromMasterEditionViaTokenArgs",
      getMintNewEditionFromMasterEditionViaTokenArgsDecoder()
    ]
  ]);
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataCodec() {
  return web3_js.combineCodec(
    getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder(),
    getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder()
  );
}
function getMintNewEditionFromMasterEditionViaVaultProxyInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    newMetadata: { value: input.newMetadata ?? null, isWritable: true },
    newEdition: { value: input.newEdition ?? null, isWritable: true },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    newMint: { value: input.newMint ?? null, isWritable: true },
    editionMarkPda: { value: input.editionMarkPda ?? null, isWritable: true },
    newMintAuthority: {
      value: input.newMintAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    vaultAuthority: { value: input.vaultAuthority ?? null, isWritable: false },
    safetyDepositStore: {
      value: input.safetyDepositStore ?? null,
      isWritable: false
    },
    safetyDepositBox: {
      value: input.safetyDepositBox ?? null,
      isWritable: false
    },
    vault: { value: input.vault ?? null, isWritable: false },
    newMetadataUpdateAuthority: {
      value: input.newMetadataUpdateAuthority ?? null,
      isWritable: false
    },
    metadata: { value: input.metadata ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    tokenVaultProgram: {
      value: input.tokenVaultProgram ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.newMetadata),
      getAccountMeta(accounts.newEdition),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.newMint),
      getAccountMeta(accounts.editionMarkPda),
      getAccountMeta(accounts.newMintAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.vaultAuthority),
      getAccountMeta(accounts.safetyDepositStore),
      getAccountMeta(accounts.safetyDepositBox),
      getAccountMeta(accounts.vault),
      getAccountMeta(accounts.newMetadataUpdateAuthority),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.tokenVaultProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseMintNewEditionFromMasterEditionViaVaultProxyInstruction(instruction) {
  if (instruction.accounts.length < 16) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 16;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      newMetadata: getNextAccount(),
      newEdition: getNextAccount(),
      masterEdition: getNextAccount(),
      newMint: getNextAccount(),
      editionMarkPda: getNextAccount(),
      newMintAuthority: getNextAccount(),
      payer: getNextAccount(),
      vaultAuthority: getNextAccount(),
      safetyDepositStore: getNextAccount(),
      safetyDepositBox: getNextAccount(),
      vault: getNextAccount(),
      newMetadataUpdateAuthority: getNextAccount(),
      metadata: getNextAccount(),
      tokenProgram: getNextAccount(),
      tokenVaultProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextOptionalAccount()
    },
    data: getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getMintV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["mintV1Discriminator", web3_js.getU8Encoder()],
      ["amount", web3_js.getU64Encoder()],
      ["authorizationData", web3_js.getOptionEncoder(getAuthorizationDataEncoder())]
    ]),
    (value) => ({ ...value, discriminator: 43, mintV1Discriminator: 0 })
  );
}
function getMintV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["mintV1Discriminator", web3_js.getU8Decoder()],
    ["amount", web3_js.getU64Decoder()],
    ["authorizationData", web3_js.getOptionDecoder(getAuthorizationDataDecoder())]
  ]);
}
function getMintV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getMintV1InstructionDataEncoder(),
    getMintV1InstructionDataDecoder()
  );
}
function getMintV1Instruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: false },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.tokenOwner),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.tokenRecord),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.delegateRecord),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.splAtaProgram),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authorizationRules)
    ],
    programAddress,
    data: getMintV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseMintV1Instruction(instruction) {
  if (instruction.accounts.length < 15) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      token: getNextAccount(),
      tokenOwner: getNextOptionalAccount(),
      metadata: getNextAccount(),
      masterEdition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      mint: getNextAccount(),
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount(),
      splAtaProgram: getNextAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getMintV1InstructionDataDecoder().decode(instruction.data)
  };
}
function getPrintInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["printArgs", getPrintArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 55 })
  );
}
function getPrintInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["printArgs", getPrintArgsDecoder()]
  ]);
}
function getPrintInstructionDataCodec() {
  return web3_js.combineCodec(
    getPrintInstructionDataEncoder(),
    getPrintInstructionDataDecoder()
  );
}
function getPrintInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    editionMetadata: { value: input.editionMetadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    editionMint: { value: input.editionMint ?? null, isWritable: true },
    editionTokenAccountOwner: {
      value: input.editionTokenAccountOwner ?? null,
      isWritable: false
    },
    editionTokenAccount: {
      value: input.editionTokenAccount ?? null,
      isWritable: true
    },
    editionMintAuthority: {
      value: input.editionMintAuthority ?? null,
      isWritable: false
    },
    editionTokenRecord: {
      value: input.editionTokenRecord ?? null,
      isWritable: true
    },
    masterEdition: { value: input.masterEdition ?? null, isWritable: true },
    editionMarkerPda: {
      value: input.editionMarkerPda ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    masterTokenAccountOwner: {
      value: input.masterTokenAccountOwner ?? null,
      isWritable: false
    },
    masterTokenAccount: {
      value: input.masterTokenAccount ?? null,
      isWritable: false
    },
    masterMetadata: { value: input.masterMetadata ?? null, isWritable: false },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.editionMetadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.editionMint),
      getAccountMeta(accounts.editionTokenAccountOwner),
      getAccountMeta(accounts.editionTokenAccount),
      getAccountMeta(accounts.editionMintAuthority),
      getAccountMeta(accounts.editionTokenRecord),
      getAccountMeta(accounts.masterEdition),
      getAccountMeta(accounts.editionMarkerPda),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.masterTokenAccountOwner),
      getAccountMeta(accounts.masterTokenAccount),
      getAccountMeta(accounts.masterMetadata),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.splAtaProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getPrintInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePrintInstruction(instruction) {
  if (instruction.accounts.length < 18) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      editionMetadata: getNextAccount(),
      edition: getNextAccount(),
      editionMint: getNextAccount(),
      editionTokenAccountOwner: getNextAccount(),
      editionTokenAccount: getNextAccount(),
      editionMintAuthority: getNextAccount(),
      editionTokenRecord: getNextOptionalAccount(),
      masterEdition: getNextAccount(),
      editionMarkerPda: getNextAccount(),
      payer: getNextAccount(),
      masterTokenAccountOwner: getNextAccount(),
      masterTokenAccount: getNextAccount(),
      masterMetadata: getNextAccount(),
      updateAuthority: getNextAccount(),
      splTokenProgram: getNextAccount(),
      splAtaProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getPrintInstructionDataDecoder().decode(instruction.data)
  };
}
function getPuffMetadataInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 14 })
  );
}
function getPuffMetadataInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getPuffMetadataInstructionDataCodec() {
  return web3_js.combineCodec(
    getPuffMetadataInstructionDataEncoder(),
    getPuffMetadataInstructionDataDecoder()
  );
}
function getPuffMetadataInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [getAccountMeta(accounts.metadata)],
    programAddress,
    data: getPuffMetadataInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parsePuffMetadataInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount()
    },
    data: getPuffMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getRemoveCreatorVerificationInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 28 })
  );
}
function getRemoveCreatorVerificationInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getRemoveCreatorVerificationInstructionDataCodec() {
  return web3_js.combineCodec(
    getRemoveCreatorVerificationInstructionDataEncoder(),
    getRemoveCreatorVerificationInstructionDataDecoder()
  );
}
function getRemoveCreatorVerificationInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    creator: { value: input.creator ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.creator)
    ],
    programAddress,
    data: getRemoveCreatorVerificationInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRemoveCreatorVerificationInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      creator: getNextAccount()
    },
    data: getRemoveCreatorVerificationInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSetAndVerifyCollectionInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 25 })
  );
}
function getSetAndVerifyCollectionInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getSetAndVerifyCollectionInstructionDataCodec() {
  return web3_js.combineCodec(
    getSetAndVerifyCollectionInstructionDataEncoder(),
    getSetAndVerifyCollectionInstructionDataDecoder()
  );
}
function getSetAndVerifyCollectionInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: false },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.collectionMasterEditionAccount),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getSetAndVerifyCollectionInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseSetAndVerifyCollectionInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 7;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getSetAndVerifyCollectionInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSetAndVerifySizedCollectionItemInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 32 })
  );
}
function getSetAndVerifySizedCollectionItemInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getSetAndVerifySizedCollectionItemInstructionDataCodec() {
  return web3_js.combineCodec(
    getSetAndVerifySizedCollectionItemInstructionDataEncoder(),
    getSetAndVerifySizedCollectionItemInstructionDataDecoder()
  );
}
function getSetAndVerifySizedCollectionItemInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: true },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.collectionMasterEditionAccount),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getSetAndVerifySizedCollectionItemInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseSetAndVerifySizedCollectionItemInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 7;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getSetAndVerifySizedCollectionItemInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSetCollectionSizeInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["setCollectionSizeArgs", getSetCollectionSizeArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 34 })
  );
}
function getSetCollectionSizeInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["setCollectionSizeArgs", getSetCollectionSizeArgsDecoder()]
  ]);
}
function getSetCollectionSizeInstructionDataCodec() {
  return web3_js.combineCodec(
    getSetCollectionSizeInstructionDataEncoder(),
    getSetCollectionSizeInstructionDataDecoder()
  );
}
function getSetCollectionSizeInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collectionMetadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getSetCollectionSizeInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSetCollectionSizeInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 3;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collectionMetadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getSetCollectionSizeInstructionDataDecoder().decode(instruction.data)
  };
}
function getSetTokenStandardInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 35 })
  );
}
function getSetTokenStandardInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getSetTokenStandardInstructionDataCodec() {
  return web3_js.combineCodec(
    getSetTokenStandardInstructionDataEncoder(),
    getSetTokenStandardInstructionDataDecoder()
  );
}
function getSetTokenStandardInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    mint: { value: input.mint ?? null, isWritable: false },
    edition: { value: input.edition ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.edition)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getSetTokenStandardInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseSetTokenStandardInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 3;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      updateAuthority: getNextAccount(),
      mint: getNextAccount(),
      edition: getNextOptionalAccount()
    },
    data: getSetTokenStandardInstructionDataDecoder().decode(instruction.data)
  };
}
function getSignMetadataInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 7 })
  );
}
function getSignMetadataInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getSignMetadataInstructionDataCodec() {
  return web3_js.combineCodec(
    getSignMetadataInstructionDataEncoder(),
    getSignMetadataInstructionDataDecoder()
  );
}
function getSignMetadataInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    creator: { value: input.creator ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.creator)
    ],
    programAddress,
    data: getSignMetadataInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseSignMetadataInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      creator: getNextAccount()
    },
    data: getSignMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getThawDelegatedAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 27 })
  );
}
function getThawDelegatedAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getThawDelegatedAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getThawDelegatedAccountInstructionDataEncoder(),
    getThawDelegatedAccountInstructionDataDecoder()
  );
}
function getThawDelegatedAccountInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    delegate: { value: input.delegate ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.delegate),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getThawDelegatedAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseThawDelegatedAccountInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      delegate: getNextAccount(),
      tokenAccount: getNextAccount(),
      edition: getNextAccount(),
      mint: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getThawDelegatedAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getTransferInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["transferArgs", getTransferArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 49 })
  );
}
function getTransferInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["transferArgs", getTransferArgsDecoder()]
  ]);
}
function getTransferInstructionDataCodec() {
  return web3_js.combineCodec(
    getTransferInstructionDataEncoder(),
    getTransferInstructionDataDecoder()
  );
}
function getTransferInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    token: { value: input.token ?? null, isWritable: true },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    destination: { value: input.destination ?? null, isWritable: true },
    destinationOwner: {
      value: input.destinationOwner ?? null,
      isWritable: false
    },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    ownerTokenRecord: {
      value: input.ownerTokenRecord ?? null,
      isWritable: true
    },
    destinationTokenRecord: {
      value: input.destinationTokenRecord ?? null,
      isWritable: true
    },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    splAtaProgram: { value: input.splAtaProgram ?? null, isWritable: false },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  if (!accounts.splTokenProgram.value) {
    accounts.splTokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.splAtaProgram.value) {
    accounts.splAtaProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.tokenOwner),
      getAccountMeta(accounts.destination),
      getAccountMeta(accounts.destinationOwner),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.ownerTokenRecord),
      getAccountMeta(accounts.destinationTokenRecord),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.splAtaProgram),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authorizationRules)
    ],
    programAddress,
    data: getTransferInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTransferInstruction(instruction) {
  if (instruction.accounts.length < 17) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      token: getNextAccount(),
      tokenOwner: getNextAccount(),
      destination: getNextAccount(),
      destinationOwner: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      ownerTokenRecord: getNextOptionalAccount(),
      destinationTokenRecord: getNextOptionalAccount(),
      authority: getNextAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextAccount(),
      splAtaProgram: getNextAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getTransferInstructionDataDecoder().decode(instruction.data)
  };
}
function getTransferOutOfEscrowInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["amount", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 40 })
  );
}
function getTransferOutOfEscrowInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["amount", web3_js.getU64Decoder()]
  ]);
}
function getTransferOutOfEscrowInstructionDataCodec() {
  return web3_js.combineCodec(
    getTransferOutOfEscrowInstructionDataEncoder(),
    getTransferOutOfEscrowInstructionDataDecoder()
  );
}
function getTransferOutOfEscrowInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    escrow: { value: input.escrow ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    attributeMint: { value: input.attributeMint ?? null, isWritable: false },
    attributeSrc: { value: input.attributeSrc ?? null, isWritable: true },
    attributeDst: { value: input.attributeDst ?? null, isWritable: true },
    escrowMint: { value: input.escrowMint ?? null, isWritable: false },
    escrowAccount: { value: input.escrowAccount ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    ataProgram: { value: input.ataProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    authority: { value: input.authority ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.ataProgram.value) {
    accounts.ataProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.escrow),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.attributeMint),
      getAccountMeta(accounts.attributeSrc),
      getAccountMeta(accounts.attributeDst),
      getAccountMeta(accounts.escrowMint),
      getAccountMeta(accounts.escrowAccount),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.ataProgram),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.authority)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getTransferOutOfEscrowInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTransferOutOfEscrowInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 12;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      escrow: getNextAccount(),
      metadata: getNextAccount(),
      payer: getNextAccount(),
      attributeMint: getNextAccount(),
      attributeSrc: getNextAccount(),
      attributeDst: getNextAccount(),
      escrowMint: getNextAccount(),
      escrowAccount: getNextAccount(),
      systemProgram: getNextAccount(),
      ataProgram: getNextAccount(),
      tokenProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      authority: getNextOptionalAccount()
    },
    data: getTransferOutOfEscrowInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUnlockInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["unlockArgs", getUnlockArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 47 })
  );
}
function getUnlockInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["unlockArgs", getUnlockArgsDecoder()]
  ]);
}
function getUnlockInstructionDataCodec() {
  return web3_js.combineCodec(
    getUnlockInstructionDataEncoder(),
    getUnlockInstructionDataDecoder()
  );
}
function getUnlockInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    tokenOwner: { value: input.tokenOwner ?? null, isWritable: false },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: false },
    tokenRecord: { value: input.tokenRecord ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.tokenOwner),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.tokenRecord),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authorizationRules)
    ],
    programAddress,
    data: getUnlockInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUnlockInstruction(instruction) {
  if (instruction.accounts.length < 13) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      tokenOwner: getNextOptionalAccount(),
      token: getNextAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      tokenRecord: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getUnlockInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnverifyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["verificationArgs", getVerificationArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 53 })
  );
}
function getUnverifyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["verificationArgs", getVerificationArgsDecoder()]
  ]);
}
function getUnverifyInstructionDataCodec() {
  return web3_js.combineCodec(
    getUnverifyInstructionDataEncoder(),
    getUnverifyInstructionDataDecoder()
  );
}
function getUnverifyInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.delegateRecord),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collectionMetadata),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getUnverifyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUnverifyInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      metadata: getNextAccount(),
      collectionMint: getNextOptionalAccount(),
      collectionMetadata: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getUnverifyInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnverifyCollectionInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 22 })
  );
}
function getUnverifyCollectionInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getUnverifyCollectionInstructionDataCodec() {
  return web3_js.combineCodec(
    getUnverifyCollectionInstructionDataEncoder(),
    getUnverifyCollectionInstructionDataDecoder()
  );
}
function getUnverifyCollectionInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: false },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.collectionMasterEditionAccount),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getUnverifyCollectionInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnverifyCollectionInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 5;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getUnverifyCollectionInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUnverifySizedCollectionItemInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 31 })
  );
}
function getUnverifySizedCollectionItemInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getUnverifySizedCollectionItemInstructionDataCodec() {
  return web3_js.combineCodec(
    getUnverifySizedCollectionItemInstructionDataEncoder(),
    getUnverifySizedCollectionItemInstructionDataDecoder()
  );
}
function getUnverifySizedCollectionItemInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: true },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.collectionMasterEditionAccount),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getUnverifySizedCollectionItemInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnverifySizedCollectionItemInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getUnverifySizedCollectionItemInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUseInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["useArgs", getUseArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 51 })
  );
}
function getUseInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["useArgs", getUseArgsDecoder()]
  ]);
}
function getUseInstructionDataCodec() {
  return web3_js.combineCodec(
    getUseInstructionDataEncoder(),
    getUseInstructionDataDecoder()
  );
}
function getUseInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    edition: { value: input.edition ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    },
    splTokenProgram: {
      value: input.splTokenProgram ?? null,
      isWritable: false
    },
    authorizationRulesProgram: {
      value: input.authorizationRulesProgram ?? null,
      isWritable: false
    },
    authorizationRules: {
      value: input.authorizationRules ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.delegateRecord),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.edition),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions),
      getAccountMeta(accounts.splTokenProgram),
      getAccountMeta(accounts.authorizationRulesProgram),
      getAccountMeta(accounts.authorizationRules)
    ],
    programAddress,
    data: getUseInstructionDataEncoder().encode(args)
  };
  return instruction;
}
function parseUseInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      token: getNextOptionalAccount(),
      mint: getNextAccount(),
      metadata: getNextAccount(),
      edition: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount(),
      splTokenProgram: getNextOptionalAccount(),
      authorizationRulesProgram: getNextOptionalAccount(),
      authorizationRules: getNextOptionalAccount()
    },
    data: getUseInstructionDataDecoder().decode(instruction.data)
  };
}
function getUtilizeInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["numberOfUses", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 19 })
  );
}
function getUtilizeInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["numberOfUses", web3_js.getU64Decoder()]
  ]);
}
function getUtilizeInstructionDataCodec() {
  return web3_js.combineCodec(
    getUtilizeInstructionDataEncoder(),
    getUtilizeInstructionDataDecoder()
  );
}
function getUtilizeInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    tokenAccount: { value: input.tokenAccount ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    useAuthority: { value: input.useAuthority ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    ataProgram: { value: input.ataProgram ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    rent: { value: input.rent ?? null, isWritable: false },
    useAuthorityRecord: {
      value: input.useAuthorityRecord ?? null,
      isWritable: true
    },
    burner: { value: input.burner ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  if (!accounts.ataProgram.value) {
    accounts.ataProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.rent.value) {
    accounts.rent.value = "SysvarRent111111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.tokenAccount),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.useAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.ataProgram),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.rent),
      getAccountMeta(accounts.useAuthorityRecord),
      getAccountMeta(accounts.burner)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getUtilizeInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUtilizeInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 9;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      tokenAccount: getNextAccount(),
      mint: getNextAccount(),
      useAuthority: getNextAccount(),
      owner: getNextAccount(),
      tokenProgram: getNextAccount(),
      ataProgram: getNextAccount(),
      systemProgram: getNextAccount(),
      rent: getNextAccount(),
      useAuthorityRecord: getNextOptionalAccount(),
      burner: getNextOptionalAccount()
    },
    data: getUtilizeInstructionDataDecoder().decode(instruction.data)
  };
}
function getVerifyInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["verificationArgs", getVerificationArgsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 52 })
  );
}
function getVerifyInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["verificationArgs", getVerificationArgsDecoder()]
  ]);
}
function getVerifyInstructionDataCodec() {
  return web3_js.combineCodec(
    getVerifyInstructionDataEncoder(),
    getVerifyInstructionDataDecoder()
  );
}
function getVerifyInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    authority: { value: input.authority ?? null, isWritable: false },
    delegateRecord: { value: input.delegateRecord ?? null, isWritable: false },
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collectionMetadata: {
      value: input.collectionMetadata ?? null,
      isWritable: true
    },
    collectionMasterEdition: {
      value: input.collectionMasterEdition ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    sysvarInstructions: {
      value: input.sysvarInstructions ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.sysvarInstructions.value) {
    accounts.sysvarInstructions.value = "Sysvar1nstructions1111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress, "programId");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.delegateRecord),
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collectionMetadata),
      getAccountMeta(accounts.collectionMasterEdition),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.sysvarInstructions)
    ],
    programAddress,
    data: getVerifyInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseVerifyInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TOKEN_METADATA_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      authority: getNextAccount(),
      delegateRecord: getNextOptionalAccount(),
      metadata: getNextAccount(),
      collectionMint: getNextOptionalAccount(),
      collectionMetadata: getNextOptionalAccount(),
      collectionMasterEdition: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      sysvarInstructions: getNextAccount()
    },
    data: getVerifyInstructionDataDecoder().decode(instruction.data)
  };
}
function getVerifyCollectionInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 18 })
  );
}
function getVerifyCollectionInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getVerifyCollectionInstructionDataCodec() {
  return web3_js.combineCodec(
    getVerifyCollectionInstructionDataEncoder(),
    getVerifyCollectionInstructionDataDecoder()
  );
}
function getVerifyCollectionInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: true
    },
    payer: { value: input.payer ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: false },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.collectionMasterEditionAccount),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getVerifyCollectionInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseVerifyCollectionInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getVerifyCollectionInstructionDataDecoder().decode(instruction.data)
  };
}
function getVerifySizedCollectionItemInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 30 })
  );
}
function getVerifySizedCollectionItemInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getVerifySizedCollectionItemInstructionDataCodec() {
  return web3_js.combineCodec(
    getVerifySizedCollectionItemInstructionDataEncoder(),
    getVerifySizedCollectionItemInstructionDataDecoder()
  );
}
function getVerifySizedCollectionItemInstruction(input) {
  const programAddress = TOKEN_METADATA_PROGRAM_ADDRESS;
  const originalAccounts = {
    metadata: { value: input.metadata ?? null, isWritable: true },
    collectionAuthority: {
      value: input.collectionAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    collectionMint: { value: input.collectionMint ?? null, isWritable: false },
    collection: { value: input.collection ?? null, isWritable: true },
    collectionMasterEditionAccount: {
      value: input.collectionMasterEditionAccount ?? null,
      isWritable: false
    },
    collectionAuthorityRecord: {
      value: input.collectionAuthorityRecord ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress, "omitted");
  const instruction = {
    accounts: [
      getAccountMeta(accounts.metadata),
      getAccountMeta(accounts.collectionAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.collectionMint),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.collectionMasterEditionAccount),
      getAccountMeta(accounts.collectionAuthorityRecord)
    ].filter((x) => x !== void 0),
    programAddress,
    data: getVerifySizedCollectionItemInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseVerifySizedCollectionItemInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  let optionalAccountsRemaining = instruction.accounts.length - 6;
  const getNextOptionalAccount = () => {
    if (optionalAccountsRemaining === 0) return void 0;
    optionalAccountsRemaining -= 1;
    return getNextAccount();
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      metadata: getNextAccount(),
      collectionAuthority: getNextAccount(),
      payer: getNextAccount(),
      collectionMint: getNextAccount(),
      collection: getNextAccount(),
      collectionMasterEditionAccount: getNextAccount(),
      collectionAuthorityRecord: getNextOptionalAccount()
    },
    data: getVerifySizedCollectionItemInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var TOKEN_PROGRAM_ADDRESS = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
function expectAddress2(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory2(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress2(account.value),
      role: isTransactionSigner2(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner2(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner2(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}
function getMintToInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["amount", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 7 })
  );
}
function getMintToInstruction(input) {
  const programAddress = TOKEN_PROGRAM_ADDRESS;
  const originalAccounts = {
    mint: { value: input.mint ?? null, isWritable: true },
    token: { value: input.token ?? null, isWritable: true },
    mintAuthority: { value: input.mintAuthority ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const remainingAccounts = (args.multiSigners ?? []).map(
    (signer) => ({
      address: signer.address,
      role: web3_js.AccountRole.READONLY_SIGNER,
      signer
    })
  );
  const getAccountMeta = getAccountMetaFactory2(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.token),
      getAccountMeta(accounts.mintAuthority),
      ...remainingAccounts
    ],
    programAddress,
    data: getMintToInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
var findAtaPda = async (seeds) => {
  return await web3_js.getProgramDerivedAddress({
    seeds: [
      web3_js.getAddressEncoder().encode(seeds.owner),
      web3_js.getAddressEncoder().encode(seeds.tokenProgramId ?? testHelpers.TOKEN_PROGRAM_ID),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ],
    programAddress: testHelpers.ASSOCIATED_TOKEN_ACCOUNTS_PROGRAM_ID
  });
};

// src/nft/mint.ts
var createDefaultNft = async (args) => {
  const {
    client,
    payer,
    authority,
    owner,
    creators,
    collectionMint,
    standard = 0 /* NonFungible */,
    tokenProgram = testHelpers.TOKEN_PROGRAM_ID
  } = args;
  let { data } = args;
  if (!data) {
    data = {
      name: "Example NFT",
      symbol: "EXNFT",
      uri: "https://example.com/nft",
      sellerFeeBasisPoints: 500,
      creators: creators ? creators : [
        {
          address: authority.address,
          verified: true,
          share: 100
        }
      ],
      printSupply: printSupply("Zero"),
      tokenStandard: standard,
      collection: collectionMint ? { verified: false, key: collectionMint } : void 0
    };
  }
  if (data.tokenStandard != standard) {
    throw new Error("Token standard mismatch");
  }
  const accounts = {
    authority,
    owner,
    payer,
    tokenProgramId: tokenProgram
  };
  return await mintNft(client, accounts, data);
};
var createDefaultNftInCollection = async (args) => {
  const { client, payer, authority } = args;
  const collectionNft = await createDefaultNft(args);
  const { mint: collectionMint, metadata: collectionMetadata } = collectionNft;
  const nft = await createDefaultNft({ ...args, collectionMint });
  const { metadata } = nft;
  const verifyCollectionIx = getVerifyInstruction({
    authority,
    metadata,
    collectionMint,
    collectionMetadata,
    collectionMasterEdition: (await findMasterEditionPda({
      mint: collectionMint
    }))[0],
    verificationArgs: 1 /* CollectionV1 */
  });
  await web3_js.pipe(
    await testHelpers.createDefaultTransaction(client, payer),
    (tx) => web3_js.appendTransactionMessageInstruction(verifyCollectionIx, tx),
    (tx) => testHelpers.signAndSendTransaction(client, tx)
  );
  return { collection: collectionNft, item: nft };
};
var mintNft = async (client, accounts, data) => {
  const {
    name,
    symbol,
    uri,
    sellerFeeBasisPoints,
    creators,
    primarySaleHappened = false,
    isMutable = true,
    tokenStandard = 0 /* NonFungible */,
    collection,
    uses = null,
    collectionDetails: collectionDetails2 = null,
    ruleSet = null,
    decimals = null,
    printSupply: printSupply2
  } = data;
  const { authority, owner, tokenProgramId } = accounts;
  let { payer, mint } = accounts;
  if (payer === null) {
    payer = authority;
  }
  if (mint === void 0) {
    mint = await web3_js.generateKeyPairSigner();
  }
  const [metadata] = await findMetadataPda({ mint: mint.address });
  const [masterEdition] = await findMasterEditionPda({ mint: mint.address });
  const [token] = await findAtaPda({
    owner: owner.address,
    mint: mint.address,
    tokenProgramId
  });
  let tokenRecord = void 0;
  if (tokenStandard === 4 /* ProgrammableNonFungible */) {
    [tokenRecord] = await findTokenRecordPda({ mint: mint.address, token });
  }
  const createIx = getCreateV1Instruction({
    metadata,
    masterEdition,
    mint,
    payer,
    authority,
    updateAuthority: authority,
    name,
    symbol,
    uri,
    sellerFeeBasisPoints,
    creators,
    primarySaleHappened,
    isMutable,
    tokenStandard,
    collection: collection ? web3_js.some(collection) : web3_js.none(),
    uses,
    collectionDetails: collectionDetails2,
    ruleSet,
    decimals,
    printSupply: printSupply2 ?? web3_js.none(),
    splTokenProgram: tokenProgramId
  });
  const mintIx = getMintV1Instruction({
    token,
    tokenOwner: owner.address,
    metadata,
    masterEdition,
    mint: mint.address,
    authority,
    payer,
    tokenRecord,
    splTokenProgram: tokenProgramId,
    amount: 1,
    authorizationData: null
  });
  await web3_js.pipe(
    await testHelpers.createDefaultTransaction(client, payer),
    (tx) => web3_js.appendTransactionMessageInstruction(createIx, tx),
    (tx) => web3_js.appendTransactionMessageInstruction(mintIx, tx),
    (tx) => testHelpers.signAndSendTransaction(client, tx)
  );
  return {
    mint: mint.address,
    metadata,
    masterEdition,
    token,
    tokenRecord
  };
};
var initializeCollection = async ({
  client,
  payer,
  mintAuthority,
  owner,
  creators
}) => {
  const collectionMint = await testHelpers.createMint({
    client,
    payer,
    mintAuthority: mintAuthority.address,
    freezeAuthority: mintAuthority.address
  });
  const collectionTokenAccount = await testHelpers.createAta({
    client,
    payer,
    mint: collectionMint,
    owner
  });
  const mintToIx = getMintToInstruction({
    mint: collectionMint,
    token: collectionTokenAccount,
    mintAuthority,
    amount: 1
  });
  await web3_js.pipe(
    await testHelpers.createDefaultTransaction(client, payer),
    (tx) => web3_js.appendTransactionMessageInstruction(mintToIx, tx),
    (tx) => testHelpers.signAndSendTransaction(client, tx)
  );
  const meta = {
    name: "Compressed NFT",
    symbol: "COMP",
    uri: "https://v6nul6vaqrzhjm7qkcpbtbqcxmhwuzvcw2coxx2wali6sbxu634a.arweave.net/r5tF-qCEcnSz8FCeGYYCuw9qZqK2hOvfVgLR6Qb09vg",
    creators,
    editionNonce: web3_js.some(0),
    tokenStandard: web3_js.some(0 /* NonFungible */),
    uses: null,
    // Will be set to true during mint by bubblegum
    collection: null,
    primarySaleHappened: true,
    sellerFeeBasisPoints: 500,
    isMutable: false,
    collectionDetails: null,
    key: 2 /* MasterEditionV1 */,
    updateAuthority: mintAuthority.address,
    mint: collectionMint,
    programmableConfig: web3_js.none()
  };
  const [collectionMetadataAccount] = await web3_js.getProgramDerivedAddress({
    seeds: [
      Buffer.from("metadata", "utf8"),
      new Uint8Array(web3_js.getAddressEncoder().encode(testHelpers.MPL_TOKEN_METADATA_PROGRAM_ID)),
      new Uint8Array(web3_js.getAddressEncoder().encode(collectionMint))
    ],
    programAddress: testHelpers.MPL_TOKEN_METADATA_PROGRAM_ID
  });
  const data = {
    name: meta.name,
    symbol: meta.symbol,
    uri: meta.uri,
    sellerFeeBasisPoints: meta.sellerFeeBasisPoints,
    creators: meta.creators,
    collection: meta.collection,
    uses: meta.uses
  };
  const collectionMetadataIx = getCreateMetadataAccountV3Instruction({
    metadata: collectionMetadataAccount,
    mint: collectionMint,
    mintAuthority,
    payer,
    updateAuthority: mintAuthority,
    data,
    isMutable: meta.isMutable,
    collectionDetails: meta.collectionDetails
  });
  const [collectionMasterEditionAccount] = await web3_js.getProgramDerivedAddress({
    seeds: [
      Buffer.from("metadata", "utf8"),
      new Uint8Array(web3_js.getAddressEncoder().encode(testHelpers.MPL_TOKEN_METADATA_PROGRAM_ID)),
      new Uint8Array(web3_js.getAddressEncoder().encode(collectionMint)),
      Buffer.from("edition", "utf8")
    ],
    programAddress: testHelpers.MPL_TOKEN_METADATA_PROGRAM_ID
  });
  const collectionMasterEditionIx = getCreateMasterEditionV3Instruction({
    edition: collectionMasterEditionAccount,
    mint: collectionMint,
    mintAuthority,
    payer,
    updateAuthority: mintAuthority,
    metadata: collectionMetadataAccount,
    maxSupply: 0
  });
  const sizeCollectionIx = getSetCollectionSizeInstruction({
    collectionMetadata: collectionMetadataAccount,
    collectionAuthority: mintAuthority,
    collectionMint,
    setCollectionSizeArgs: { size: 50 }
  });
  const { value: latestBlockhash } = await client.rpc.getLatestBlockhash().send();
  await web3_js.pipe(
    web3_js.createTransactionMessage({ version: 0 }),
    (tx) => web3_js.setTransactionMessageFeePayerSigner(mintAuthority, tx),
    (tx) => web3_js.setTransactionMessageFeePayerSigner(payer, tx),
    (tx) => web3_js.setTransactionMessageLifetimeUsingBlockhash(latestBlockhash, tx),
    (tx) => web3_js.appendTransactionMessageInstruction(collectionMetadataIx, tx),
    (tx) => web3_js.appendTransactionMessageInstruction(collectionMasterEditionIx, tx),
    (tx) => web3_js.appendTransactionMessageInstruction(sizeCollectionIx, tx),
    (tx) => testHelpers.signAndSendTransaction(client, tx)
  );
  return {
    collectionMint,
    collectionMetadataAccount,
    collectionMasterEditionAccount,
    metadata: meta
  };
};

exports.AuthorityType = AuthorityType;
exports.HolderDelegateRole = HolderDelegateRole;
exports.Key = Key;
exports.MetadataDelegateRole = MetadataDelegateRole;
exports.MigrationType = MigrationType;
exports.PayloadKey = PayloadKey;
exports.RevokeArgs = RevokeArgs;
exports.TOKEN_METADATA_ERROR__ADDRESS_NOT_IN_RESERVATION = TOKEN_METADATA_ERROR__ADDRESS_NOT_IN_RESERVATION;
exports.TOKEN_METADATA_ERROR__ALREADY_INITIALIZED = TOKEN_METADATA_ERROR__ALREADY_INITIALIZED;
exports.TOKEN_METADATA_ERROR__ALREADY_UNVERIFIED = TOKEN_METADATA_ERROR__ALREADY_UNVERIFIED;
exports.TOKEN_METADATA_ERROR__ALREADY_VERIFIED = TOKEN_METADATA_ERROR__ALREADY_VERIFIED;
exports.TOKEN_METADATA_ERROR__AMOUNT_MUST_BE_GREATER_THAN_ZERO = TOKEN_METADATA_ERROR__AMOUNT_MUST_BE_GREATER_THAN_ZERO;
exports.TOKEN_METADATA_ERROR__AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH = TOKEN_METADATA_ERROR__AUTHORIZATION_TOKEN_ACCOUNT_OWNER_MISMATCH;
exports.TOKEN_METADATA_ERROR__BEYOND_ALOTTED_ADDRESS_SIZE = TOKEN_METADATA_ERROR__BEYOND_ALOTTED_ADDRESS_SIZE;
exports.TOKEN_METADATA_ERROR__BEYOND_MAX_ADDRESS_SIZE = TOKEN_METADATA_ERROR__BEYOND_MAX_ADDRESS_SIZE;
exports.TOKEN_METADATA_ERROR__BORSH_DESERIALIZATION_ERROR = TOKEN_METADATA_ERROR__BORSH_DESERIALIZATION_ERROR;
exports.TOKEN_METADATA_ERROR__BORSH_SERIALIZATION_ERROR = TOKEN_METADATA_ERROR__BORSH_SERIALIZATION_ERROR;
exports.TOKEN_METADATA_ERROR__CANNOT_ADJUST_VERIFIED_CREATOR = TOKEN_METADATA_ERROR__CANNOT_ADJUST_VERIFIED_CREATOR;
exports.TOKEN_METADATA_ERROR__CANNOT_BURN_WITH_DELEGATE = TOKEN_METADATA_ERROR__CANNOT_BURN_WITH_DELEGATE;
exports.TOKEN_METADATA_ERROR__CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE = TOKEN_METADATA_ERROR__CANNOT_CHANGE_UPDATE_AUTHORITY_WITH_DELEGATE;
exports.TOKEN_METADATA_ERROR__CANNOT_CHANGE_USES_AFTER_FIRST_USE = TOKEN_METADATA_ERROR__CANNOT_CHANGE_USES_AFTER_FIRST_USE;
exports.TOKEN_METADATA_ERROR__CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE = TOKEN_METADATA_ERROR__CANNOT_CHANGE_USE_METHOD_AFTER_FIRST_USE;
exports.TOKEN_METADATA_ERROR__CANNOT_REMOVE_VERIFIED_CREATOR = TOKEN_METADATA_ERROR__CANNOT_REMOVE_VERIFIED_CREATOR;
exports.TOKEN_METADATA_ERROR__CANNOT_UNVERIFY_ANOTHER_CREATOR = TOKEN_METADATA_ERROR__CANNOT_UNVERIFY_ANOTHER_CREATOR;
exports.TOKEN_METADATA_ERROR__CANNOT_UPDATE_ASSET_WITH_DELEGATE = TOKEN_METADATA_ERROR__CANNOT_UPDATE_ASSET_WITH_DELEGATE;
exports.TOKEN_METADATA_ERROR__CANNOT_UPDATE_VERIFIED_COLLECTION = TOKEN_METADATA_ERROR__CANNOT_UPDATE_VERIFIED_COLLECTION;
exports.TOKEN_METADATA_ERROR__CANNOT_VERIFY_ANOTHER_CREATOR = TOKEN_METADATA_ERROR__CANNOT_VERIFY_ANOTHER_CREATOR;
exports.TOKEN_METADATA_ERROR__CANNOT_WIPE_VERIFIED_CREATORS = TOKEN_METADATA_ERROR__CANNOT_WIPE_VERIFIED_CREATORS;
exports.TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_DOES_NOT_EXIST = TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_DOES_NOT_EXIST;
exports.TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS = TOKEN_METADATA_ERROR__COLLECTION_AUTHORITY_RECORD_ALREADY_EXISTS;
exports.TOKEN_METADATA_ERROR__COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION = TOKEN_METADATA_ERROR__COLLECTION_CANNOT_BE_VERIFIED_IN_THIS_INSTRUCTION;
exports.TOKEN_METADATA_ERROR__COLLECTION_MASTER_EDITION_ACCOUNT_INVALID = TOKEN_METADATA_ERROR__COLLECTION_MASTER_EDITION_ACCOUNT_INVALID;
exports.TOKEN_METADATA_ERROR__COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION = TOKEN_METADATA_ERROR__COLLECTION_MUST_BE_A_UNIQUE_MASTER_EDITION;
exports.TOKEN_METADATA_ERROR__COLLECTION_NOT_FOUND = TOKEN_METADATA_ERROR__COLLECTION_NOT_FOUND;
exports.TOKEN_METADATA_ERROR__COULD_NOT_DETERMINE_TOKEN_STANDARD = TOKEN_METADATA_ERROR__COULD_NOT_DETERMINE_TOKEN_STANDARD;
exports.TOKEN_METADATA_ERROR__CREATORS_MUST_BE_ATLEAST_ONE = TOKEN_METADATA_ERROR__CREATORS_MUST_BE_ATLEAST_ONE;
exports.TOKEN_METADATA_ERROR__CREATORS_TOO_LONG = TOKEN_METADATA_ERROR__CREATORS_TOO_LONG;
exports.TOKEN_METADATA_ERROR__CREATOR_NOT_FOUND = TOKEN_METADATA_ERROR__CREATOR_NOT_FOUND;
exports.TOKEN_METADATA_ERROR__DATA_INCREMENT_LIMIT_EXCEEDED = TOKEN_METADATA_ERROR__DATA_INCREMENT_LIMIT_EXCEEDED;
exports.TOKEN_METADATA_ERROR__DATA_IS_EMPTY_OR_ZEROED = TOKEN_METADATA_ERROR__DATA_IS_EMPTY_OR_ZEROED;
exports.TOKEN_METADATA_ERROR__DATA_IS_IMMUTABLE = TOKEN_METADATA_ERROR__DATA_IS_IMMUTABLE;
exports.TOKEN_METADATA_ERROR__DATA_TYPE_MISMATCH = TOKEN_METADATA_ERROR__DATA_TYPE_MISMATCH;
exports.TOKEN_METADATA_ERROR__DELEGATE_ALREADY_EXISTS = TOKEN_METADATA_ERROR__DELEGATE_ALREADY_EXISTS;
exports.TOKEN_METADATA_ERROR__DELEGATE_NOT_FOUND = TOKEN_METADATA_ERROR__DELEGATE_NOT_FOUND;
exports.TOKEN_METADATA_ERROR__DERIVED_KEY_INVALID = TOKEN_METADATA_ERROR__DERIVED_KEY_INVALID;
exports.TOKEN_METADATA_ERROR__DESTINATION_MINT_MISMATCH = TOKEN_METADATA_ERROR__DESTINATION_MINT_MISMATCH;
exports.TOKEN_METADATA_ERROR__DISABLED = TOKEN_METADATA_ERROR__DISABLED;
exports.TOKEN_METADATA_ERROR__DUPLICATE_CREATOR_ADDRESS = TOKEN_METADATA_ERROR__DUPLICATE_CREATOR_ADDRESS;
exports.TOKEN_METADATA_ERROR__EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN = TOKEN_METADATA_ERROR__EDITIONS_MUST_HAVE_EXACTLY_ONE_TOKEN;
exports.TOKEN_METADATA_ERROR__EDITION_ALREADY_MINTED = TOKEN_METADATA_ERROR__EDITION_ALREADY_MINTED;
exports.TOKEN_METADATA_ERROR__EDITION_MINT_DECIMALS_SHOULD_BE_ZERO = TOKEN_METADATA_ERROR__EDITION_MINT_DECIMALS_SHOULD_BE_ZERO;
exports.TOKEN_METADATA_ERROR__EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY = TOKEN_METADATA_ERROR__EDITION_NUMBER_GREATER_THAN_MAX_SUPPLY;
exports.TOKEN_METADATA_ERROR__EDITION_OVERRIDE_CANNOT_BE_ZERO = TOKEN_METADATA_ERROR__EDITION_OVERRIDE_CANNOT_BE_ZERO;
exports.TOKEN_METADATA_ERROR__ESCROW_PARENT_HAS_DELEGATE = TOKEN_METADATA_ERROR__ESCROW_PARENT_HAS_DELEGATE;
exports.TOKEN_METADATA_ERROR__FEATURE_NOT_SUPPORTED = TOKEN_METADATA_ERROR__FEATURE_NOT_SUPPORTED;
exports.TOKEN_METADATA_ERROR__INCORRECT_OWNER = TOKEN_METADATA_ERROR__INCORRECT_OWNER;
exports.TOKEN_METADATA_ERROR__INCORRECT_TOKEN_STATE = TOKEN_METADATA_ERROR__INCORRECT_TOKEN_STATE;
exports.TOKEN_METADATA_ERROR__INSTRUCTION_NOT_SUPPORTED = TOKEN_METADATA_ERROR__INSTRUCTION_NOT_SUPPORTED;
exports.TOKEN_METADATA_ERROR__INSTRUCTION_PACK_ERROR = TOKEN_METADATA_ERROR__INSTRUCTION_PACK_ERROR;
exports.TOKEN_METADATA_ERROR__INSTRUCTION_UNPACK_ERROR = TOKEN_METADATA_ERROR__INSTRUCTION_UNPACK_ERROR;
exports.TOKEN_METADATA_ERROR__INSUFFICIENT_TOKENS = TOKEN_METADATA_ERROR__INSUFFICIENT_TOKENS;
exports.TOKEN_METADATA_ERROR__INSUFFICIENT_TOKEN_BALANCE = TOKEN_METADATA_ERROR__INSUFFICIENT_TOKEN_BALANCE;
exports.TOKEN_METADATA_ERROR__INVALID_AMOUNT = TOKEN_METADATA_ERROR__INVALID_AMOUNT;
exports.TOKEN_METADATA_ERROR__INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM = TOKEN_METADATA_ERROR__INVALID_ASSOCIATED_TOKEN_ACCOUNT_PROGRAM;
exports.TOKEN_METADATA_ERROR__INVALID_AUTHORITY_TYPE = TOKEN_METADATA_ERROR__INVALID_AUTHORITY_TYPE;
exports.TOKEN_METADATA_ERROR__INVALID_AUTHORIZATION_RULES = TOKEN_METADATA_ERROR__INVALID_AUTHORIZATION_RULES;
exports.TOKEN_METADATA_ERROR__INVALID_BASIS_POINTS = TOKEN_METADATA_ERROR__INVALID_BASIS_POINTS;
exports.TOKEN_METADATA_ERROR__INVALID_BUBBLEGUM_SIGNER = TOKEN_METADATA_ERROR__INVALID_BUBBLEGUM_SIGNER;
exports.TOKEN_METADATA_ERROR__INVALID_CLOSE_AUTHORITY = TOKEN_METADATA_ERROR__INVALID_CLOSE_AUTHORITY;
exports.TOKEN_METADATA_ERROR__INVALID_COLLECTION_AUTHORITY_RECORD = TOKEN_METADATA_ERROR__INVALID_COLLECTION_AUTHORITY_RECORD;
exports.TOKEN_METADATA_ERROR__INVALID_COLLECTION_SIZE_CHANGE = TOKEN_METADATA_ERROR__INVALID_COLLECTION_SIZE_CHANGE;
exports.TOKEN_METADATA_ERROR__INVALID_COLLECTION_UPDATE_AUTHORITY = TOKEN_METADATA_ERROR__INVALID_COLLECTION_UPDATE_AUTHORITY;
exports.TOKEN_METADATA_ERROR__INVALID_DELEGATE = TOKEN_METADATA_ERROR__INVALID_DELEGATE;
exports.TOKEN_METADATA_ERROR__INVALID_DELEGATE_ARGS = TOKEN_METADATA_ERROR__INVALID_DELEGATE_ARGS;
exports.TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE = TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE;
exports.TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE_FOR_TRANSFER = TOKEN_METADATA_ERROR__INVALID_DELEGATE_ROLE_FOR_TRANSFER;
exports.TOKEN_METADATA_ERROR__INVALID_EDITION_INDEX = TOKEN_METADATA_ERROR__INVALID_EDITION_INDEX;
exports.TOKEN_METADATA_ERROR__INVALID_EDITION_KEY = TOKEN_METADATA_ERROR__INVALID_EDITION_KEY;
exports.TOKEN_METADATA_ERROR__INVALID_EDITION_MARKER = TOKEN_METADATA_ERROR__INVALID_EDITION_MARKER;
exports.TOKEN_METADATA_ERROR__INVALID_ESCROW_BUMP_SEED = TOKEN_METADATA_ERROR__INVALID_ESCROW_BUMP_SEED;
exports.TOKEN_METADATA_ERROR__INVALID_FEE_ACCOUNT = TOKEN_METADATA_ERROR__INVALID_FEE_ACCOUNT;
exports.TOKEN_METADATA_ERROR__INVALID_FREEZE_AUTHORITY = TOKEN_METADATA_ERROR__INVALID_FREEZE_AUTHORITY;
exports.TOKEN_METADATA_ERROR__INVALID_INSTRUCTION = TOKEN_METADATA_ERROR__INVALID_INSTRUCTION;
exports.TOKEN_METADATA_ERROR__INVALID_INSTRUCTIONS_SYSVAR = TOKEN_METADATA_ERROR__INVALID_INSTRUCTIONS_SYSVAR;
exports.TOKEN_METADATA_ERROR__INVALID_LOCKED_TRANSFER_ADDRESS = TOKEN_METADATA_ERROR__INVALID_LOCKED_TRANSFER_ADDRESS;
exports.TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION = TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION;
exports.TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION_ACCOUNT_LENGTH = TOKEN_METADATA_ERROR__INVALID_MASTER_EDITION_ACCOUNT_LENGTH;
exports.TOKEN_METADATA_ERROR__INVALID_METADATA_FLAGS = TOKEN_METADATA_ERROR__INVALID_METADATA_FLAGS;
exports.TOKEN_METADATA_ERROR__INVALID_METADATA_KEY = TOKEN_METADATA_ERROR__INVALID_METADATA_KEY;
exports.TOKEN_METADATA_ERROR__INVALID_METADATA_POINTER = TOKEN_METADATA_ERROR__INVALID_METADATA_POINTER;
exports.TOKEN_METADATA_ERROR__INVALID_MINT_AUTHORITY = TOKEN_METADATA_ERROR__INVALID_MINT_AUTHORITY;
exports.TOKEN_METADATA_ERROR__INVALID_MINT_CLOSE_AUTHORITY = TOKEN_METADATA_ERROR__INVALID_MINT_CLOSE_AUTHORITY;
exports.TOKEN_METADATA_ERROR__INVALID_MINT_EXTENSION_TYPE = TOKEN_METADATA_ERROR__INVALID_MINT_EXTENSION_TYPE;
exports.TOKEN_METADATA_ERROR__INVALID_MINT_FOR_TOKEN_STANDARD = TOKEN_METADATA_ERROR__INVALID_MINT_FOR_TOKEN_STANDARD;
exports.TOKEN_METADATA_ERROR__INVALID_OPERATION = TOKEN_METADATA_ERROR__INVALID_OPERATION;
exports.TOKEN_METADATA_ERROR__INVALID_OWNER = TOKEN_METADATA_ERROR__INVALID_OWNER;
exports.TOKEN_METADATA_ERROR__INVALID_PARENT_ACCOUNTS = TOKEN_METADATA_ERROR__INVALID_PARENT_ACCOUNTS;
exports.TOKEN_METADATA_ERROR__INVALID_PRINT_EDITION = TOKEN_METADATA_ERROR__INVALID_PRINT_EDITION;
exports.TOKEN_METADATA_ERROR__INVALID_PROGRAMMABLE_CONFIG = TOKEN_METADATA_ERROR__INVALID_PROGRAMMABLE_CONFIG;
exports.TOKEN_METADATA_ERROR__INVALID_SYSTEM_PROGRAM = TOKEN_METADATA_ERROR__INVALID_SYSTEM_PROGRAM;
exports.TOKEN_METADATA_ERROR__INVALID_SYSTEM_WALLET = TOKEN_METADATA_ERROR__INVALID_SYSTEM_WALLET;
exports.TOKEN_METADATA_ERROR__INVALID_TOKEN_EXTENSION_TYPE = TOKEN_METADATA_ERROR__INVALID_TOKEN_EXTENSION_TYPE;
exports.TOKEN_METADATA_ERROR__INVALID_TOKEN_PROGRAM = TOKEN_METADATA_ERROR__INVALID_TOKEN_PROGRAM;
exports.TOKEN_METADATA_ERROR__INVALID_TOKEN_RECORD = TOKEN_METADATA_ERROR__INVALID_TOKEN_RECORD;
exports.TOKEN_METADATA_ERROR__INVALID_TOKEN_STANDARD = TOKEN_METADATA_ERROR__INVALID_TOKEN_STANDARD;
exports.TOKEN_METADATA_ERROR__INVALID_TRANSFER_AUTHORITY = TOKEN_METADATA_ERROR__INVALID_TRANSFER_AUTHORITY;
exports.TOKEN_METADATA_ERROR__INVALID_UPDATE_ARGS = TOKEN_METADATA_ERROR__INVALID_UPDATE_ARGS;
exports.TOKEN_METADATA_ERROR__INVALID_USER = TOKEN_METADATA_ERROR__INVALID_USER;
exports.TOKEN_METADATA_ERROR__INVALID_USE_AUTHORITY_RECORD = TOKEN_METADATA_ERROR__INVALID_USE_AUTHORITY_RECORD;
exports.TOKEN_METADATA_ERROR__INVALID_USE_METHOD = TOKEN_METADATA_ERROR__INVALID_USE_METHOD;
exports.TOKEN_METADATA_ERROR__IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE = TOKEN_METADATA_ERROR__IS_MUTABLE_CAN_ONLY_BE_FLIPPED_TO_FALSE;
exports.TOKEN_METADATA_ERROR__KEY_MISMATCH = TOKEN_METADATA_ERROR__KEY_MISMATCH;
exports.TOKEN_METADATA_ERROR__LOCKED_TOKEN = TOKEN_METADATA_ERROR__LOCKED_TOKEN;
exports.TOKEN_METADATA_ERROR__MASTER_EDITION_HAS_PRINTS = TOKEN_METADATA_ERROR__MASTER_EDITION_HAS_PRINTS;
exports.TOKEN_METADATA_ERROR__MASTER_RECORD_MISMATCH = TOKEN_METADATA_ERROR__MASTER_RECORD_MISMATCH;
exports.TOKEN_METADATA_ERROR__MAX_EDITIONS_MINTED_ALREADY = TOKEN_METADATA_ERROR__MAX_EDITIONS_MINTED_ALREADY;
exports.TOKEN_METADATA_ERROR__MINT_IS_NOT_SIGNER = TOKEN_METADATA_ERROR__MINT_IS_NOT_SIGNER;
exports.TOKEN_METADATA_ERROR__MINT_MISMATCH = TOKEN_METADATA_ERROR__MINT_MISMATCH;
exports.TOKEN_METADATA_ERROR__MINT_SUPPLY_MUST_BE_ZERO = TOKEN_METADATA_ERROR__MINT_SUPPLY_MUST_BE_ZERO;
exports.TOKEN_METADATA_ERROR__MISSING_ACCOUNT_IN_BUILDER = TOKEN_METADATA_ERROR__MISSING_ACCOUNT_IN_BUILDER;
exports.TOKEN_METADATA_ERROR__MISSING_ARGUMENT_IN_BUILDER = TOKEN_METADATA_ERROR__MISSING_ARGUMENT_IN_BUILDER;
exports.TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES = TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES;
exports.TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES_PROGRAM = TOKEN_METADATA_ERROR__MISSING_AUTHORIZATION_RULES_PROGRAM;
exports.TOKEN_METADATA_ERROR__MISSING_COLLECTION_MASTER_EDITION = TOKEN_METADATA_ERROR__MISSING_COLLECTION_MASTER_EDITION;
exports.TOKEN_METADATA_ERROR__MISSING_COLLECTION_METADATA = TOKEN_METADATA_ERROR__MISSING_COLLECTION_METADATA;
exports.TOKEN_METADATA_ERROR__MISSING_COLLECTION_MINT = TOKEN_METADATA_ERROR__MISSING_COLLECTION_MINT;
exports.TOKEN_METADATA_ERROR__MISSING_DELEGATE_RECORD = TOKEN_METADATA_ERROR__MISSING_DELEGATE_RECORD;
exports.TOKEN_METADATA_ERROR__MISSING_DELEGATE_ROLE = TOKEN_METADATA_ERROR__MISSING_DELEGATE_ROLE;
exports.TOKEN_METADATA_ERROR__MISSING_EDITION = TOKEN_METADATA_ERROR__MISSING_EDITION;
exports.TOKEN_METADATA_ERROR__MISSING_EDITION_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_EDITION_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_EDITION_MARKER_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_EDITION_MARKER_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_IMMUTABLE_OWNER_EXTENSION = TOKEN_METADATA_ERROR__MISSING_IMMUTABLE_OWNER_EXTENSION;
exports.TOKEN_METADATA_ERROR__MISSING_LOCKED_TRANSFER_ADDRESS = TOKEN_METADATA_ERROR__MISSING_LOCKED_TRANSFER_ADDRESS;
exports.TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_MINT_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_MINT_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_TOKEN_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_MASTER_EDITION_TOKEN_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_PRINT_SUPPLY = TOKEN_METADATA_ERROR__MISSING_PRINT_SUPPLY;
exports.TOKEN_METADATA_ERROR__MISSING_PROGRAMMABLE_CONFIG = TOKEN_METADATA_ERROR__MISSING_PROGRAMMABLE_CONFIG;
exports.TOKEN_METADATA_ERROR__MISSING_SPL_TOKEN_PROGRAM = TOKEN_METADATA_ERROR__MISSING_SPL_TOKEN_PROGRAM;
exports.TOKEN_METADATA_ERROR__MISSING_TOKEN_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_TOKEN_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_TOKEN_OWNER_ACCOUNT = TOKEN_METADATA_ERROR__MISSING_TOKEN_OWNER_ACCOUNT;
exports.TOKEN_METADATA_ERROR__MISSING_TOKEN_RECORD = TOKEN_METADATA_ERROR__MISSING_TOKEN_RECORD;
exports.TOKEN_METADATA_ERROR__MUST_BE_BURNED = TOKEN_METADATA_ERROR__MUST_BE_BURNED;
exports.TOKEN_METADATA_ERROR__MUST_BE_ESCROW_AUTHORITY = TOKEN_METADATA_ERROR__MUST_BE_ESCROW_AUTHORITY;
exports.TOKEN_METADATA_ERROR__MUST_BE_NON_FUNGIBLE = TOKEN_METADATA_ERROR__MUST_BE_NON_FUNGIBLE;
exports.TOKEN_METADATA_ERROR__MUST_BE_ONE_OF_CREATORS = TOKEN_METADATA_ERROR__MUST_BE_ONE_OF_CREATORS;
exports.TOKEN_METADATA_ERROR__MUST_UNVERIFY = TOKEN_METADATA_ERROR__MUST_UNVERIFY;
exports.TOKEN_METADATA_ERROR__NAME_TOO_LONG = TOKEN_METADATA_ERROR__NAME_TOO_LONG;
exports.TOKEN_METADATA_ERROR__NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS = TOKEN_METADATA_ERROR__NOT_ALLOWED_TO_CHANGE_SELLER_FEE_BASIS_POINTS;
exports.TOKEN_METADATA_ERROR__NOT_A_COLLECTION_PARENT = TOKEN_METADATA_ERROR__NOT_A_COLLECTION_PARENT;
exports.TOKEN_METADATA_ERROR__NOT_A_MASTER_EDITION = TOKEN_METADATA_ERROR__NOT_A_MASTER_EDITION;
exports.TOKEN_METADATA_ERROR__NOT_A_MEMBER_OF_COLLECTION = TOKEN_METADATA_ERROR__NOT_A_MEMBER_OF_COLLECTION;
exports.TOKEN_METADATA_ERROR__NOT_A_PRINT_EDITION = TOKEN_METADATA_ERROR__NOT_A_PRINT_EDITION;
exports.TOKEN_METADATA_ERROR__NOT_ENOUGH_TOKENS = TOKEN_METADATA_ERROR__NOT_ENOUGH_TOKENS;
exports.TOKEN_METADATA_ERROR__NOT_ENOUGH_USES = TOKEN_METADATA_ERROR__NOT_ENOUGH_USES;
exports.TOKEN_METADATA_ERROR__NOT_MINT_AUTHORITY = TOKEN_METADATA_ERROR__NOT_MINT_AUTHORITY;
exports.TOKEN_METADATA_ERROR__NOT_RENT_EXEMPT = TOKEN_METADATA_ERROR__NOT_RENT_EXEMPT;
exports.TOKEN_METADATA_ERROR__NOT_VERIFIED_MEMBER_OF_COLLECTION = TOKEN_METADATA_ERROR__NOT_VERIFIED_MEMBER_OF_COLLECTION;
exports.TOKEN_METADATA_ERROR__NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION = TOKEN_METADATA_ERROR__NO_BALANCE_IN_ACCOUNT_FOR_AUTHORIZATION;
exports.TOKEN_METADATA_ERROR__NO_CREATORS_PRESENT_ON_METADATA = TOKEN_METADATA_ERROR__NO_CREATORS_PRESENT_ON_METADATA;
exports.TOKEN_METADATA_ERROR__NO_FREEZE_AUTHORITY_SET = TOKEN_METADATA_ERROR__NO_FREEZE_AUTHORITY_SET;
exports.TOKEN_METADATA_ERROR__NUMERICAL_OVERFLOW_ERROR = TOKEN_METADATA_ERROR__NUMERICAL_OVERFLOW_ERROR;
exports.TOKEN_METADATA_ERROR__ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION = TOKEN_METADATA_ERROR__ONE_TIME_AUTH_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION;
exports.TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO = TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTHORIZATION_MINT_DECIMALS_SHOULD_BE_ZERO;
exports.TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTH_MINT_MISMATCH = TOKEN_METADATA_ERROR__ONE_TIME_PRINTING_AUTH_MINT_MISMATCH;
exports.TOKEN_METADATA_ERROR__ONLY_SALE_DELEGATE_CAN_TRANSFER = TOKEN_METADATA_ERROR__ONLY_SALE_DELEGATE_CAN_TRANSFER;
exports.TOKEN_METADATA_ERROR__OWNER_MISMATCH = TOKEN_METADATA_ERROR__OWNER_MISMATCH;
exports.TOKEN_METADATA_ERROR__PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE = TOKEN_METADATA_ERROR__PRIMARY_SALE_CAN_ONLY_BE_FLIPPED_TO_TRUE;
exports.TOKEN_METADATA_ERROR__PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH = TOKEN_METADATA_ERROR__PRINTING_MINT_AUTHORIZATION_ACCOUNT_MISMATCH;
exports.TOKEN_METADATA_ERROR__PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO = TOKEN_METADATA_ERROR__PRINTING_MINT_DECIMALS_SHOULD_BE_ZERO;
exports.TOKEN_METADATA_ERROR__PRINTING_MINT_MISMATCH = TOKEN_METADATA_ERROR__PRINTING_MINT_MISMATCH;
exports.TOKEN_METADATA_ERROR__PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION = TOKEN_METADATA_ERROR__PRINTING_MINT_SUPPLY_MUST_BE_ZERO_FOR_CONVERSION;
exports.TOKEN_METADATA_ERROR__PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY = TOKEN_METADATA_ERROR__PRINTING_WOULD_BREACH_MAXIMUM_SUPPLY;
exports.TOKEN_METADATA_ERROR__PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION = TOKEN_METADATA_ERROR__PRINT_EDITION_DOES_NOT_MATCH_MASTER_EDITION;
exports.TOKEN_METADATA_ERROR__REMOVED = TOKEN_METADATA_ERROR__REMOVED;
exports.TOKEN_METADATA_ERROR__RESERVATION_ALREADY_MADE = TOKEN_METADATA_ERROR__RESERVATION_ALREADY_MADE;
exports.TOKEN_METADATA_ERROR__RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE = TOKEN_METADATA_ERROR__RESERVATION_ARRAY_SHOULD_BE_SIZE_ONE;
exports.TOKEN_METADATA_ERROR__RESERVATION_BREACHES_MAXIMUM_SUPPLY = TOKEN_METADATA_ERROR__RESERVATION_BREACHES_MAXIMUM_SUPPLY;
exports.TOKEN_METADATA_ERROR__RESERVATION_DOES_NOT_EXIST = TOKEN_METADATA_ERROR__RESERVATION_DOES_NOT_EXIST;
exports.TOKEN_METADATA_ERROR__RESERVATION_EXISTS = TOKEN_METADATA_ERROR__RESERVATION_EXISTS;
exports.TOKEN_METADATA_ERROR__RESERVATION_LIST_DEPRECATED = TOKEN_METADATA_ERROR__RESERVATION_LIST_DEPRECATED;
exports.TOKEN_METADATA_ERROR__RESERVATION_NOT_COMPLETE = TOKEN_METADATA_ERROR__RESERVATION_NOT_COMPLETE;
exports.TOKEN_METADATA_ERROR__RESERVATION_NOT_SET = TOKEN_METADATA_ERROR__RESERVATION_NOT_SET;
exports.TOKEN_METADATA_ERROR__RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START = TOKEN_METADATA_ERROR__RESERVATION_SPOTS_REMAINING_SHOULD_MATCH_TOTAL_SPOTS_AT_START;
exports.TOKEN_METADATA_ERROR__REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT = TOKEN_METADATA_ERROR__REVOKE_COLLECTION_AUTHORITY_SIGNER_INCORRECT;
exports.TOKEN_METADATA_ERROR__SHARE_TOTAL_MUST_BE100 = TOKEN_METADATA_ERROR__SHARE_TOTAL_MUST_BE100;
exports.TOKEN_METADATA_ERROR__SIZED_COLLECTION = TOKEN_METADATA_ERROR__SIZED_COLLECTION;
exports.TOKEN_METADATA_ERROR__SPOT_MISMATCH = TOKEN_METADATA_ERROR__SPOT_MISMATCH;
exports.TOKEN_METADATA_ERROR__SYMBOL_TOO_LONG = TOKEN_METADATA_ERROR__SYMBOL_TOO_LONG;
exports.TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH = TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH;
exports.TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH_V2 = TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_MINT_MISMATCH_V2;
exports.TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH = TOKEN_METADATA_ERROR__TOKEN_ACCOUNT_ONE_TIME_AUTH_MINT_MISMATCH;
exports.TOKEN_METADATA_ERROR__TOKEN_BURN_FAILED = TOKEN_METADATA_ERROR__TOKEN_BURN_FAILED;
exports.TOKEN_METADATA_ERROR__TOKEN_CLOSE_FAILED = TOKEN_METADATA_ERROR__TOKEN_CLOSE_FAILED;
exports.TOKEN_METADATA_ERROR__TOKEN_MINT_TO_FAILED = TOKEN_METADATA_ERROR__TOKEN_MINT_TO_FAILED;
exports.TOKEN_METADATA_ERROR__TRIED_TO_REPLACE_AN_EXISTING_RESERVATION = TOKEN_METADATA_ERROR__TRIED_TO_REPLACE_AN_EXISTING_RESERVATION;
exports.TOKEN_METADATA_ERROR__UNINITIALIZED = TOKEN_METADATA_ERROR__UNINITIALIZED;
exports.TOKEN_METADATA_ERROR__UNLOCKED_TOKEN = TOKEN_METADATA_ERROR__UNLOCKED_TOKEN;
exports.TOKEN_METADATA_ERROR__UNSIZED_COLLECTION = TOKEN_METADATA_ERROR__UNSIZED_COLLECTION;
exports.TOKEN_METADATA_ERROR__UNUSABLE = TOKEN_METADATA_ERROR__UNUSABLE;
exports.TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_INCORRECT = TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_INCORRECT;
exports.TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_IS_NOT_SIGNER = TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_IS_NOT_SIGNER;
exports.TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER = TOKEN_METADATA_ERROR__UPDATE_AUTHORITY_MUST_BE_EQUAL_TO_METADATA_AUTHORITY_AND_SIGNER;
exports.TOKEN_METADATA_ERROR__URI_TOO_LONG = TOKEN_METADATA_ERROR__URI_TOO_LONG;
exports.TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_EXISTS = TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_EXISTS;
exports.TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_REVOKED = TOKEN_METADATA_ERROR__USE_AUTHORITY_RECORD_ALREADY_REVOKED;
exports.TOKEN_METADATA_PROGRAM_ADDRESS = TOKEN_METADATA_PROGRAM_ADDRESS;
exports.TokenDelegateRole = TokenDelegateRole;
exports.TokenMetadataAccount = TokenMetadataAccount;
exports.TokenMetadataInstruction = TokenMetadataInstruction;
exports.TokenStandard = TokenStandard2;
exports.TokenState = TokenState;
exports.UseMethod = UseMethod;
exports.VerificationArgs = VerificationArgs;
exports.burnArgs = burnArgs;
exports.collectionDetails = collectionDetails;
exports.collectionDetailsToggle = collectionDetailsToggle;
exports.collectionToggle = collectionToggle;
exports.createArgs = createArgs;
exports.createDefaultNft = createDefaultNft;
exports.createDefaultNftInCollection = createDefaultNftInCollection;
exports.decodeCollectionAuthorityRecord = decodeCollectionAuthorityRecord;
exports.decodeEdition = decodeEdition;
exports.decodeEditionMarker = decodeEditionMarker;
exports.decodeEditionMarkerV2 = decodeEditionMarkerV2;
exports.decodeHolderDelegateRecord = decodeHolderDelegateRecord;
exports.decodeMasterEdition = decodeMasterEdition;
exports.decodeMasterEditionV1 = decodeMasterEditionV1;
exports.decodeMetadata = decodeMetadata;
exports.decodeMetadataDelegateRecord = decodeMetadataDelegateRecord;
exports.decodeReservationListV1 = decodeReservationListV1;
exports.decodeReservationListV2 = decodeReservationListV2;
exports.decodeTokenOwnedEscrow = decodeTokenOwnedEscrow;
exports.decodeTokenRecord = decodeTokenRecord;
exports.decodeUseAuthorityRecord = decodeUseAuthorityRecord;
exports.delegateArgs = delegateArgs;
exports.escrowAuthority = escrowAuthority;
exports.fetchAllCollectionAuthorityRecord = fetchAllCollectionAuthorityRecord;
exports.fetchAllEdition = fetchAllEdition;
exports.fetchAllEditionMarker = fetchAllEditionMarker;
exports.fetchAllEditionMarkerV2 = fetchAllEditionMarkerV2;
exports.fetchAllHolderDelegateRecord = fetchAllHolderDelegateRecord;
exports.fetchAllMasterEdition = fetchAllMasterEdition;
exports.fetchAllMasterEditionV1 = fetchAllMasterEditionV1;
exports.fetchAllMaybeCollectionAuthorityRecord = fetchAllMaybeCollectionAuthorityRecord;
exports.fetchAllMaybeEdition = fetchAllMaybeEdition;
exports.fetchAllMaybeEditionMarker = fetchAllMaybeEditionMarker;
exports.fetchAllMaybeEditionMarkerV2 = fetchAllMaybeEditionMarkerV2;
exports.fetchAllMaybeHolderDelegateRecord = fetchAllMaybeHolderDelegateRecord;
exports.fetchAllMaybeMasterEdition = fetchAllMaybeMasterEdition;
exports.fetchAllMaybeMasterEditionV1 = fetchAllMaybeMasterEditionV1;
exports.fetchAllMaybeMetadata = fetchAllMaybeMetadata;
exports.fetchAllMaybeMetadataDelegateRecord = fetchAllMaybeMetadataDelegateRecord;
exports.fetchAllMaybeReservationListV1 = fetchAllMaybeReservationListV1;
exports.fetchAllMaybeReservationListV2 = fetchAllMaybeReservationListV2;
exports.fetchAllMaybeTokenOwnedEscrow = fetchAllMaybeTokenOwnedEscrow;
exports.fetchAllMaybeTokenRecord = fetchAllMaybeTokenRecord;
exports.fetchAllMaybeUseAuthorityRecord = fetchAllMaybeUseAuthorityRecord;
exports.fetchAllMetadata = fetchAllMetadata;
exports.fetchAllMetadataDelegateRecord = fetchAllMetadataDelegateRecord;
exports.fetchAllReservationListV1 = fetchAllReservationListV1;
exports.fetchAllReservationListV2 = fetchAllReservationListV2;
exports.fetchAllTokenOwnedEscrow = fetchAllTokenOwnedEscrow;
exports.fetchAllTokenRecord = fetchAllTokenRecord;
exports.fetchAllUseAuthorityRecord = fetchAllUseAuthorityRecord;
exports.fetchCollectionAuthorityRecord = fetchCollectionAuthorityRecord;
exports.fetchEdition = fetchEdition;
exports.fetchEditionMarker = fetchEditionMarker;
exports.fetchEditionMarkerV2 = fetchEditionMarkerV2;
exports.fetchHolderDelegateRecord = fetchHolderDelegateRecord;
exports.fetchMasterEdition = fetchMasterEdition;
exports.fetchMasterEditionFromSeeds = fetchMasterEditionFromSeeds;
exports.fetchMasterEditionV1 = fetchMasterEditionV1;
exports.fetchMaybeCollectionAuthorityRecord = fetchMaybeCollectionAuthorityRecord;
exports.fetchMaybeEdition = fetchMaybeEdition;
exports.fetchMaybeEditionMarker = fetchMaybeEditionMarker;
exports.fetchMaybeEditionMarkerV2 = fetchMaybeEditionMarkerV2;
exports.fetchMaybeHolderDelegateRecord = fetchMaybeHolderDelegateRecord;
exports.fetchMaybeMasterEdition = fetchMaybeMasterEdition;
exports.fetchMaybeMasterEditionFromSeeds = fetchMaybeMasterEditionFromSeeds;
exports.fetchMaybeMasterEditionV1 = fetchMaybeMasterEditionV1;
exports.fetchMaybeMetadata = fetchMaybeMetadata;
exports.fetchMaybeMetadataDelegateRecord = fetchMaybeMetadataDelegateRecord;
exports.fetchMaybeMetadataFromSeeds = fetchMaybeMetadataFromSeeds;
exports.fetchMaybeReservationListV1 = fetchMaybeReservationListV1;
exports.fetchMaybeReservationListV2 = fetchMaybeReservationListV2;
exports.fetchMaybeTokenOwnedEscrow = fetchMaybeTokenOwnedEscrow;
exports.fetchMaybeTokenRecord = fetchMaybeTokenRecord;
exports.fetchMaybeTokenRecordFromSeeds = fetchMaybeTokenRecordFromSeeds;
exports.fetchMaybeUseAuthorityRecord = fetchMaybeUseAuthorityRecord;
exports.fetchMetadata = fetchMetadata;
exports.fetchMetadataDelegateRecord = fetchMetadataDelegateRecord;
exports.fetchMetadataFromSeeds = fetchMetadataFromSeeds;
exports.fetchReservationListV1 = fetchReservationListV1;
exports.fetchReservationListV2 = fetchReservationListV2;
exports.fetchTokenOwnedEscrow = fetchTokenOwnedEscrow;
exports.fetchTokenRecord = fetchTokenRecord;
exports.fetchTokenRecordFromSeeds = fetchTokenRecordFromSeeds;
exports.fetchUseAuthorityRecord = fetchUseAuthorityRecord;
exports.findAtaPda = findAtaPda;
exports.findMasterEditionPda = findMasterEditionPda;
exports.findMetadataPda = findMetadataPda;
exports.findTokenRecordPda = findTokenRecordPda;
exports.getApproveCollectionAuthorityInstruction = getApproveCollectionAuthorityInstruction;
exports.getApproveCollectionAuthorityInstructionDataCodec = getApproveCollectionAuthorityInstructionDataCodec;
exports.getApproveCollectionAuthorityInstructionDataDecoder = getApproveCollectionAuthorityInstructionDataDecoder;
exports.getApproveCollectionAuthorityInstructionDataEncoder = getApproveCollectionAuthorityInstructionDataEncoder;
exports.getApproveUseAuthorityInstruction = getApproveUseAuthorityInstruction;
exports.getApproveUseAuthorityInstructionDataCodec = getApproveUseAuthorityInstructionDataCodec;
exports.getApproveUseAuthorityInstructionDataDecoder = getApproveUseAuthorityInstructionDataDecoder;
exports.getApproveUseAuthorityInstructionDataEncoder = getApproveUseAuthorityInstructionDataEncoder;
exports.getAuthorityTypeCodec = getAuthorityTypeCodec;
exports.getAuthorityTypeDecoder = getAuthorityTypeDecoder;
exports.getAuthorityTypeEncoder = getAuthorityTypeEncoder;
exports.getAuthorizationDataCodec = getAuthorizationDataCodec;
exports.getAuthorizationDataDecoder = getAuthorizationDataDecoder;
exports.getAuthorizationDataEncoder = getAuthorizationDataEncoder;
exports.getBubblegumSetCollectionSizeInstruction = getBubblegumSetCollectionSizeInstruction;
exports.getBubblegumSetCollectionSizeInstructionDataCodec = getBubblegumSetCollectionSizeInstructionDataCodec;
exports.getBubblegumSetCollectionSizeInstructionDataDecoder = getBubblegumSetCollectionSizeInstructionDataDecoder;
exports.getBubblegumSetCollectionSizeInstructionDataEncoder = getBubblegumSetCollectionSizeInstructionDataEncoder;
exports.getBurnArgsCodec = getBurnArgsCodec;
exports.getBurnArgsDecoder = getBurnArgsDecoder;
exports.getBurnArgsEncoder = getBurnArgsEncoder;
exports.getBurnEditionNftInstruction = getBurnEditionNftInstruction;
exports.getBurnEditionNftInstructionDataCodec = getBurnEditionNftInstructionDataCodec;
exports.getBurnEditionNftInstructionDataDecoder = getBurnEditionNftInstructionDataDecoder;
exports.getBurnEditionNftInstructionDataEncoder = getBurnEditionNftInstructionDataEncoder;
exports.getBurnInstruction = getBurnInstruction;
exports.getBurnInstructionDataCodec = getBurnInstructionDataCodec;
exports.getBurnInstructionDataDecoder = getBurnInstructionDataDecoder;
exports.getBurnInstructionDataEncoder = getBurnInstructionDataEncoder;
exports.getBurnNftInstruction = getBurnNftInstruction;
exports.getBurnNftInstructionDataCodec = getBurnNftInstructionDataCodec;
exports.getBurnNftInstructionDataDecoder = getBurnNftInstructionDataDecoder;
exports.getBurnNftInstructionDataEncoder = getBurnNftInstructionDataEncoder;
exports.getCloseEscrowAccountInstruction = getCloseEscrowAccountInstruction;
exports.getCloseEscrowAccountInstructionDataCodec = getCloseEscrowAccountInstructionDataCodec;
exports.getCloseEscrowAccountInstructionDataDecoder = getCloseEscrowAccountInstructionDataDecoder;
exports.getCloseEscrowAccountInstructionDataEncoder = getCloseEscrowAccountInstructionDataEncoder;
exports.getCollectInstruction = getCollectInstruction;
exports.getCollectInstructionDataCodec = getCollectInstructionDataCodec;
exports.getCollectInstructionDataDecoder = getCollectInstructionDataDecoder;
exports.getCollectInstructionDataEncoder = getCollectInstructionDataEncoder;
exports.getCollectionAuthorityRecordCodec = getCollectionAuthorityRecordCodec;
exports.getCollectionAuthorityRecordDecoder = getCollectionAuthorityRecordDecoder;
exports.getCollectionAuthorityRecordEncoder = getCollectionAuthorityRecordEncoder;
exports.getCollectionCodec = getCollectionCodec;
exports.getCollectionDecoder = getCollectionDecoder;
exports.getCollectionDetailsCodec = getCollectionDetailsCodec;
exports.getCollectionDetailsDecoder = getCollectionDetailsDecoder;
exports.getCollectionDetailsEncoder = getCollectionDetailsEncoder;
exports.getCollectionDetailsToggleCodec = getCollectionDetailsToggleCodec;
exports.getCollectionDetailsToggleDecoder = getCollectionDetailsToggleDecoder;
exports.getCollectionDetailsToggleEncoder = getCollectionDetailsToggleEncoder;
exports.getCollectionEncoder = getCollectionEncoder;
exports.getCollectionToggleCodec = getCollectionToggleCodec;
exports.getCollectionToggleDecoder = getCollectionToggleDecoder;
exports.getCollectionToggleEncoder = getCollectionToggleEncoder;
exports.getConvertMasterEditionV1ToV2Instruction = getConvertMasterEditionV1ToV2Instruction;
exports.getConvertMasterEditionV1ToV2InstructionDataCodec = getConvertMasterEditionV1ToV2InstructionDataCodec;
exports.getConvertMasterEditionV1ToV2InstructionDataDecoder = getConvertMasterEditionV1ToV2InstructionDataDecoder;
exports.getConvertMasterEditionV1ToV2InstructionDataEncoder = getConvertMasterEditionV1ToV2InstructionDataEncoder;
exports.getCreateArgsCodec = getCreateArgsCodec;
exports.getCreateArgsDecoder = getCreateArgsDecoder;
exports.getCreateArgsEncoder = getCreateArgsEncoder;
exports.getCreateEscrowAccountInstruction = getCreateEscrowAccountInstruction;
exports.getCreateEscrowAccountInstructionDataCodec = getCreateEscrowAccountInstructionDataCodec;
exports.getCreateEscrowAccountInstructionDataDecoder = getCreateEscrowAccountInstructionDataDecoder;
exports.getCreateEscrowAccountInstructionDataEncoder = getCreateEscrowAccountInstructionDataEncoder;
exports.getCreateMasterEditionInstruction = getCreateMasterEditionInstruction;
exports.getCreateMasterEditionInstructionDataCodec = getCreateMasterEditionInstructionDataCodec;
exports.getCreateMasterEditionInstructionDataDecoder = getCreateMasterEditionInstructionDataDecoder;
exports.getCreateMasterEditionInstructionDataEncoder = getCreateMasterEditionInstructionDataEncoder;
exports.getCreateMasterEditionV3Instruction = getCreateMasterEditionV3Instruction;
exports.getCreateMasterEditionV3InstructionDataCodec = getCreateMasterEditionV3InstructionDataCodec;
exports.getCreateMasterEditionV3InstructionDataDecoder = getCreateMasterEditionV3InstructionDataDecoder;
exports.getCreateMasterEditionV3InstructionDataEncoder = getCreateMasterEditionV3InstructionDataEncoder;
exports.getCreateMetadataAccountInstruction = getCreateMetadataAccountInstruction;
exports.getCreateMetadataAccountInstructionDataCodec = getCreateMetadataAccountInstructionDataCodec;
exports.getCreateMetadataAccountInstructionDataDecoder = getCreateMetadataAccountInstructionDataDecoder;
exports.getCreateMetadataAccountInstructionDataEncoder = getCreateMetadataAccountInstructionDataEncoder;
exports.getCreateMetadataAccountV2Instruction = getCreateMetadataAccountV2Instruction;
exports.getCreateMetadataAccountV2InstructionDataCodec = getCreateMetadataAccountV2InstructionDataCodec;
exports.getCreateMetadataAccountV2InstructionDataDecoder = getCreateMetadataAccountV2InstructionDataDecoder;
exports.getCreateMetadataAccountV2InstructionDataEncoder = getCreateMetadataAccountV2InstructionDataEncoder;
exports.getCreateMetadataAccountV3Instruction = getCreateMetadataAccountV3Instruction;
exports.getCreateMetadataAccountV3InstructionDataCodec = getCreateMetadataAccountV3InstructionDataCodec;
exports.getCreateMetadataAccountV3InstructionDataDecoder = getCreateMetadataAccountV3InstructionDataDecoder;
exports.getCreateMetadataAccountV3InstructionDataEncoder = getCreateMetadataAccountV3InstructionDataEncoder;
exports.getCreateV1Instruction = getCreateV1Instruction;
exports.getCreateV1InstructionAsync = getCreateV1InstructionAsync;
exports.getCreateV1InstructionDataCodec = getCreateV1InstructionDataCodec;
exports.getCreateV1InstructionDataDecoder = getCreateV1InstructionDataDecoder;
exports.getCreateV1InstructionDataEncoder = getCreateV1InstructionDataEncoder;
exports.getCreatorCodec = getCreatorCodec;
exports.getCreatorDecoder = getCreatorDecoder;
exports.getCreatorEncoder = getCreatorEncoder;
exports.getDataCodec = getDataCodec;
exports.getDataDecoder = getDataDecoder;
exports.getDataEncoder = getDataEncoder;
exports.getDataV2Codec = getDataV2Codec;
exports.getDataV2Decoder = getDataV2Decoder;
exports.getDataV2Encoder = getDataV2Encoder;
exports.getDelegateArgsCodec = getDelegateArgsCodec;
exports.getDelegateArgsDecoder = getDelegateArgsDecoder;
exports.getDelegateArgsEncoder = getDelegateArgsEncoder;
exports.getDeprecatedCreateMasterEditionInstruction = getDeprecatedCreateMasterEditionInstruction;
exports.getDeprecatedCreateMasterEditionInstructionDataCodec = getDeprecatedCreateMasterEditionInstructionDataCodec;
exports.getDeprecatedCreateMasterEditionInstructionDataDecoder = getDeprecatedCreateMasterEditionInstructionDataDecoder;
exports.getDeprecatedCreateMasterEditionInstructionDataEncoder = getDeprecatedCreateMasterEditionInstructionDataEncoder;
exports.getDeprecatedCreateReservationListInstruction = getDeprecatedCreateReservationListInstruction;
exports.getDeprecatedCreateReservationListInstructionDataCodec = getDeprecatedCreateReservationListInstructionDataCodec;
exports.getDeprecatedCreateReservationListInstructionDataDecoder = getDeprecatedCreateReservationListInstructionDataDecoder;
exports.getDeprecatedCreateReservationListInstructionDataEncoder = getDeprecatedCreateReservationListInstructionDataEncoder;
exports.getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction = getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction;
exports.getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataCodec = getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataCodec;
exports.getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder = getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataDecoder;
exports.getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder = getDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstructionDataEncoder;
exports.getDeprecatedMintPrintingTokensInstruction = getDeprecatedMintPrintingTokensInstruction;
exports.getDeprecatedMintPrintingTokensInstructionDataCodec = getDeprecatedMintPrintingTokensInstructionDataCodec;
exports.getDeprecatedMintPrintingTokensInstructionDataDecoder = getDeprecatedMintPrintingTokensInstructionDataDecoder;
exports.getDeprecatedMintPrintingTokensInstructionDataEncoder = getDeprecatedMintPrintingTokensInstructionDataEncoder;
exports.getDeprecatedMintPrintingTokensViaTokenInstruction = getDeprecatedMintPrintingTokensViaTokenInstruction;
exports.getDeprecatedMintPrintingTokensViaTokenInstructionDataCodec = getDeprecatedMintPrintingTokensViaTokenInstructionDataCodec;
exports.getDeprecatedMintPrintingTokensViaTokenInstructionDataDecoder = getDeprecatedMintPrintingTokensViaTokenInstructionDataDecoder;
exports.getDeprecatedMintPrintingTokensViaTokenInstructionDataEncoder = getDeprecatedMintPrintingTokensViaTokenInstructionDataEncoder;
exports.getDeprecatedSetReservationListInstruction = getDeprecatedSetReservationListInstruction;
exports.getDeprecatedSetReservationListInstructionDataCodec = getDeprecatedSetReservationListInstructionDataCodec;
exports.getDeprecatedSetReservationListInstructionDataDecoder = getDeprecatedSetReservationListInstructionDataDecoder;
exports.getDeprecatedSetReservationListInstructionDataEncoder = getDeprecatedSetReservationListInstructionDataEncoder;
exports.getEditionCodec = getEditionCodec;
exports.getEditionDecoder = getEditionDecoder;
exports.getEditionEncoder = getEditionEncoder;
exports.getEditionMarkerCodec = getEditionMarkerCodec;
exports.getEditionMarkerDecoder = getEditionMarkerDecoder;
exports.getEditionMarkerEncoder = getEditionMarkerEncoder;
exports.getEditionMarkerSize = getEditionMarkerSize;
exports.getEditionMarkerV2Codec = getEditionMarkerV2Codec;
exports.getEditionMarkerV2Decoder = getEditionMarkerV2Decoder;
exports.getEditionMarkerV2Encoder = getEditionMarkerV2Encoder;
exports.getEditionSize = getEditionSize;
exports.getEscrowAuthorityCodec = getEscrowAuthorityCodec;
exports.getEscrowAuthorityDecoder = getEscrowAuthorityDecoder;
exports.getEscrowAuthorityEncoder = getEscrowAuthorityEncoder;
exports.getFreezeDelegatedAccountInstruction = getFreezeDelegatedAccountInstruction;
exports.getFreezeDelegatedAccountInstructionDataCodec = getFreezeDelegatedAccountInstructionDataCodec;
exports.getFreezeDelegatedAccountInstructionDataDecoder = getFreezeDelegatedAccountInstructionDataDecoder;
exports.getFreezeDelegatedAccountInstructionDataEncoder = getFreezeDelegatedAccountInstructionDataEncoder;
exports.getHolderDelegateRecordCodec = getHolderDelegateRecordCodec;
exports.getHolderDelegateRecordDecoder = getHolderDelegateRecordDecoder;
exports.getHolderDelegateRecordEncoder = getHolderDelegateRecordEncoder;
exports.getHolderDelegateRecordSize = getHolderDelegateRecordSize;
exports.getHolderDelegateRoleCodec = getHolderDelegateRoleCodec;
exports.getHolderDelegateRoleDecoder = getHolderDelegateRoleDecoder;
exports.getHolderDelegateRoleEncoder = getHolderDelegateRoleEncoder;
exports.getKeyCodec = getKeyCodec;
exports.getKeyDecoder = getKeyDecoder;
exports.getKeyEncoder = getKeyEncoder;
exports.getLockArgsCodec = getLockArgsCodec;
exports.getLockArgsDecoder = getLockArgsDecoder;
exports.getLockArgsEncoder = getLockArgsEncoder;
exports.getLockInstruction = getLockInstruction;
exports.getLockInstructionDataCodec = getLockInstructionDataCodec;
exports.getLockInstructionDataDecoder = getLockInstructionDataDecoder;
exports.getLockInstructionDataEncoder = getLockInstructionDataEncoder;
exports.getMasterEditionCodec = getMasterEditionCodec;
exports.getMasterEditionDecoder = getMasterEditionDecoder;
exports.getMasterEditionEncoder = getMasterEditionEncoder;
exports.getMasterEditionV1Codec = getMasterEditionV1Codec;
exports.getMasterEditionV1Decoder = getMasterEditionV1Decoder;
exports.getMasterEditionV1Encoder = getMasterEditionV1Encoder;
exports.getMetadataCodec = getMetadataCodec;
exports.getMetadataDecoder = getMetadataDecoder;
exports.getMetadataDelegateRecordCodec = getMetadataDelegateRecordCodec;
exports.getMetadataDelegateRecordDecoder = getMetadataDelegateRecordDecoder;
exports.getMetadataDelegateRecordEncoder = getMetadataDelegateRecordEncoder;
exports.getMetadataDelegateRecordSize = getMetadataDelegateRecordSize;
exports.getMetadataDelegateRoleCodec = getMetadataDelegateRoleCodec;
exports.getMetadataDelegateRoleDecoder = getMetadataDelegateRoleDecoder;
exports.getMetadataDelegateRoleEncoder = getMetadataDelegateRoleEncoder;
exports.getMetadataEncoder = getMetadataEncoder;
exports.getMigrateInstruction = getMigrateInstruction;
exports.getMigrateInstructionDataCodec = getMigrateInstructionDataCodec;
exports.getMigrateInstructionDataDecoder = getMigrateInstructionDataDecoder;
exports.getMigrateInstructionDataEncoder = getMigrateInstructionDataEncoder;
exports.getMigrationTypeCodec = getMigrationTypeCodec;
exports.getMigrationTypeDecoder = getMigrationTypeDecoder;
exports.getMigrationTypeEncoder = getMigrationTypeEncoder;
exports.getMintArgsCodec = getMintArgsCodec;
exports.getMintArgsDecoder = getMintArgsDecoder;
exports.getMintArgsEncoder = getMintArgsEncoder;
exports.getMintNewEditionFromMasterEditionViaTokenArgsCodec = getMintNewEditionFromMasterEditionViaTokenArgsCodec;
exports.getMintNewEditionFromMasterEditionViaTokenArgsDecoder = getMintNewEditionFromMasterEditionViaTokenArgsDecoder;
exports.getMintNewEditionFromMasterEditionViaTokenArgsEncoder = getMintNewEditionFromMasterEditionViaTokenArgsEncoder;
exports.getMintNewEditionFromMasterEditionViaTokenInstruction = getMintNewEditionFromMasterEditionViaTokenInstruction;
exports.getMintNewEditionFromMasterEditionViaTokenInstructionDataCodec = getMintNewEditionFromMasterEditionViaTokenInstructionDataCodec;
exports.getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder = getMintNewEditionFromMasterEditionViaTokenInstructionDataDecoder;
exports.getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder = getMintNewEditionFromMasterEditionViaTokenInstructionDataEncoder;
exports.getMintNewEditionFromMasterEditionViaVaultProxyInstruction = getMintNewEditionFromMasterEditionViaVaultProxyInstruction;
exports.getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataCodec = getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataCodec;
exports.getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder = getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataDecoder;
exports.getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder = getMintNewEditionFromMasterEditionViaVaultProxyInstructionDataEncoder;
exports.getMintV1Instruction = getMintV1Instruction;
exports.getMintV1InstructionDataCodec = getMintV1InstructionDataCodec;
exports.getMintV1InstructionDataDecoder = getMintV1InstructionDataDecoder;
exports.getMintV1InstructionDataEncoder = getMintV1InstructionDataEncoder;
exports.getPayloadCodec = getPayloadCodec;
exports.getPayloadDecoder = getPayloadDecoder;
exports.getPayloadEncoder = getPayloadEncoder;
exports.getPayloadKeyCodec = getPayloadKeyCodec;
exports.getPayloadKeyDecoder = getPayloadKeyDecoder;
exports.getPayloadKeyEncoder = getPayloadKeyEncoder;
exports.getPayloadTypeCodec = getPayloadTypeCodec;
exports.getPayloadTypeDecoder = getPayloadTypeDecoder;
exports.getPayloadTypeEncoder = getPayloadTypeEncoder;
exports.getPrintArgsCodec = getPrintArgsCodec;
exports.getPrintArgsDecoder = getPrintArgsDecoder;
exports.getPrintArgsEncoder = getPrintArgsEncoder;
exports.getPrintInstruction = getPrintInstruction;
exports.getPrintInstructionDataCodec = getPrintInstructionDataCodec;
exports.getPrintInstructionDataDecoder = getPrintInstructionDataDecoder;
exports.getPrintInstructionDataEncoder = getPrintInstructionDataEncoder;
exports.getPrintSupplyCodec = getPrintSupplyCodec;
exports.getPrintSupplyDecoder = getPrintSupplyDecoder;
exports.getPrintSupplyEncoder = getPrintSupplyEncoder;
exports.getProgrammableConfigCodec = getProgrammableConfigCodec;
exports.getProgrammableConfigDecoder = getProgrammableConfigDecoder;
exports.getProgrammableConfigEncoder = getProgrammableConfigEncoder;
exports.getProofInfoCodec = getProofInfoCodec;
exports.getProofInfoDecoder = getProofInfoDecoder;
exports.getProofInfoEncoder = getProofInfoEncoder;
exports.getPuffMetadataInstruction = getPuffMetadataInstruction;
exports.getPuffMetadataInstructionDataCodec = getPuffMetadataInstructionDataCodec;
exports.getPuffMetadataInstructionDataDecoder = getPuffMetadataInstructionDataDecoder;
exports.getPuffMetadataInstructionDataEncoder = getPuffMetadataInstructionDataEncoder;
exports.getRemoveCreatorVerificationInstruction = getRemoveCreatorVerificationInstruction;
exports.getRemoveCreatorVerificationInstructionDataCodec = getRemoveCreatorVerificationInstructionDataCodec;
exports.getRemoveCreatorVerificationInstructionDataDecoder = getRemoveCreatorVerificationInstructionDataDecoder;
exports.getRemoveCreatorVerificationInstructionDataEncoder = getRemoveCreatorVerificationInstructionDataEncoder;
exports.getReservationCodec = getReservationCodec;
exports.getReservationDecoder = getReservationDecoder;
exports.getReservationEncoder = getReservationEncoder;
exports.getReservationListV1Codec = getReservationListV1Codec;
exports.getReservationListV1Decoder = getReservationListV1Decoder;
exports.getReservationListV1Encoder = getReservationListV1Encoder;
exports.getReservationListV2Codec = getReservationListV2Codec;
exports.getReservationListV2Decoder = getReservationListV2Decoder;
exports.getReservationListV2Encoder = getReservationListV2Encoder;
exports.getReservationV1Codec = getReservationV1Codec;
exports.getReservationV1Decoder = getReservationV1Decoder;
exports.getReservationV1Encoder = getReservationV1Encoder;
exports.getRevokeArgsCodec = getRevokeArgsCodec;
exports.getRevokeArgsDecoder = getRevokeArgsDecoder;
exports.getRevokeArgsEncoder = getRevokeArgsEncoder;
exports.getRuleSetToggleCodec = getRuleSetToggleCodec;
exports.getRuleSetToggleDecoder = getRuleSetToggleDecoder;
exports.getRuleSetToggleEncoder = getRuleSetToggleEncoder;
exports.getSeedsVecCodec = getSeedsVecCodec;
exports.getSeedsVecDecoder = getSeedsVecDecoder;
exports.getSeedsVecEncoder = getSeedsVecEncoder;
exports.getSetAndVerifyCollectionInstruction = getSetAndVerifyCollectionInstruction;
exports.getSetAndVerifyCollectionInstructionDataCodec = getSetAndVerifyCollectionInstructionDataCodec;
exports.getSetAndVerifyCollectionInstructionDataDecoder = getSetAndVerifyCollectionInstructionDataDecoder;
exports.getSetAndVerifyCollectionInstructionDataEncoder = getSetAndVerifyCollectionInstructionDataEncoder;
exports.getSetAndVerifySizedCollectionItemInstruction = getSetAndVerifySizedCollectionItemInstruction;
exports.getSetAndVerifySizedCollectionItemInstructionDataCodec = getSetAndVerifySizedCollectionItemInstructionDataCodec;
exports.getSetAndVerifySizedCollectionItemInstructionDataDecoder = getSetAndVerifySizedCollectionItemInstructionDataDecoder;
exports.getSetAndVerifySizedCollectionItemInstructionDataEncoder = getSetAndVerifySizedCollectionItemInstructionDataEncoder;
exports.getSetCollectionSizeArgsCodec = getSetCollectionSizeArgsCodec;
exports.getSetCollectionSizeArgsDecoder = getSetCollectionSizeArgsDecoder;
exports.getSetCollectionSizeArgsEncoder = getSetCollectionSizeArgsEncoder;
exports.getSetCollectionSizeInstruction = getSetCollectionSizeInstruction;
exports.getSetCollectionSizeInstructionDataCodec = getSetCollectionSizeInstructionDataCodec;
exports.getSetCollectionSizeInstructionDataDecoder = getSetCollectionSizeInstructionDataDecoder;
exports.getSetCollectionSizeInstructionDataEncoder = getSetCollectionSizeInstructionDataEncoder;
exports.getSetTokenStandardInstruction = getSetTokenStandardInstruction;
exports.getSetTokenStandardInstructionDataCodec = getSetTokenStandardInstructionDataCodec;
exports.getSetTokenStandardInstructionDataDecoder = getSetTokenStandardInstructionDataDecoder;
exports.getSetTokenStandardInstructionDataEncoder = getSetTokenStandardInstructionDataEncoder;
exports.getSignMetadataInstruction = getSignMetadataInstruction;
exports.getSignMetadataInstructionDataCodec = getSignMetadataInstructionDataCodec;
exports.getSignMetadataInstructionDataDecoder = getSignMetadataInstructionDataDecoder;
exports.getSignMetadataInstructionDataEncoder = getSignMetadataInstructionDataEncoder;
exports.getThawDelegatedAccountInstruction = getThawDelegatedAccountInstruction;
exports.getThawDelegatedAccountInstructionDataCodec = getThawDelegatedAccountInstructionDataCodec;
exports.getThawDelegatedAccountInstructionDataDecoder = getThawDelegatedAccountInstructionDataDecoder;
exports.getThawDelegatedAccountInstructionDataEncoder = getThawDelegatedAccountInstructionDataEncoder;
exports.getTokenDelegateRoleCodec = getTokenDelegateRoleCodec;
exports.getTokenDelegateRoleDecoder = getTokenDelegateRoleDecoder;
exports.getTokenDelegateRoleEncoder = getTokenDelegateRoleEncoder;
exports.getTokenMetadataErrorMessage = getTokenMetadataErrorMessage;
exports.getTokenOwnedEscrowCodec = getTokenOwnedEscrowCodec;
exports.getTokenOwnedEscrowDecoder = getTokenOwnedEscrowDecoder;
exports.getTokenOwnedEscrowEncoder = getTokenOwnedEscrowEncoder;
exports.getTokenRecordCodec = getTokenRecordCodec;
exports.getTokenRecordDecoder = getTokenRecordDecoder;
exports.getTokenRecordEncoder = getTokenRecordEncoder;
exports.getTokenStandardCodec = getTokenStandardCodec;
exports.getTokenStandardDecoder = getTokenStandardDecoder;
exports.getTokenStandardEncoder = getTokenStandardEncoder;
exports.getTokenStateCodec = getTokenStateCodec;
exports.getTokenStateDecoder = getTokenStateDecoder;
exports.getTokenStateEncoder = getTokenStateEncoder;
exports.getTransferArgsCodec = getTransferArgsCodec;
exports.getTransferArgsDecoder = getTransferArgsDecoder;
exports.getTransferArgsEncoder = getTransferArgsEncoder;
exports.getTransferInstruction = getTransferInstruction;
exports.getTransferInstructionDataCodec = getTransferInstructionDataCodec;
exports.getTransferInstructionDataDecoder = getTransferInstructionDataDecoder;
exports.getTransferInstructionDataEncoder = getTransferInstructionDataEncoder;
exports.getTransferOutOfEscrowInstruction = getTransferOutOfEscrowInstruction;
exports.getTransferOutOfEscrowInstructionDataCodec = getTransferOutOfEscrowInstructionDataCodec;
exports.getTransferOutOfEscrowInstructionDataDecoder = getTransferOutOfEscrowInstructionDataDecoder;
exports.getTransferOutOfEscrowInstructionDataEncoder = getTransferOutOfEscrowInstructionDataEncoder;
exports.getUnlockArgsCodec = getUnlockArgsCodec;
exports.getUnlockArgsDecoder = getUnlockArgsDecoder;
exports.getUnlockArgsEncoder = getUnlockArgsEncoder;
exports.getUnlockInstruction = getUnlockInstruction;
exports.getUnlockInstructionDataCodec = getUnlockInstructionDataCodec;
exports.getUnlockInstructionDataDecoder = getUnlockInstructionDataDecoder;
exports.getUnlockInstructionDataEncoder = getUnlockInstructionDataEncoder;
exports.getUnverifyCollectionInstruction = getUnverifyCollectionInstruction;
exports.getUnverifyCollectionInstructionDataCodec = getUnverifyCollectionInstructionDataCodec;
exports.getUnverifyCollectionInstructionDataDecoder = getUnverifyCollectionInstructionDataDecoder;
exports.getUnverifyCollectionInstructionDataEncoder = getUnverifyCollectionInstructionDataEncoder;
exports.getUnverifyInstruction = getUnverifyInstruction;
exports.getUnverifyInstructionDataCodec = getUnverifyInstructionDataCodec;
exports.getUnverifyInstructionDataDecoder = getUnverifyInstructionDataDecoder;
exports.getUnverifyInstructionDataEncoder = getUnverifyInstructionDataEncoder;
exports.getUnverifySizedCollectionItemInstruction = getUnverifySizedCollectionItemInstruction;
exports.getUnverifySizedCollectionItemInstructionDataCodec = getUnverifySizedCollectionItemInstructionDataCodec;
exports.getUnverifySizedCollectionItemInstructionDataDecoder = getUnverifySizedCollectionItemInstructionDataDecoder;
exports.getUnverifySizedCollectionItemInstructionDataEncoder = getUnverifySizedCollectionItemInstructionDataEncoder;
exports.getUpdateArgsCodec = getUpdateArgsCodec;
exports.getUpdateArgsDecoder = getUpdateArgsDecoder;
exports.getUpdateArgsEncoder = getUpdateArgsEncoder;
exports.getUseArgsCodec = getUseArgsCodec;
exports.getUseArgsDecoder = getUseArgsDecoder;
exports.getUseArgsEncoder = getUseArgsEncoder;
exports.getUseAuthorityRecordCodec = getUseAuthorityRecordCodec;
exports.getUseAuthorityRecordDecoder = getUseAuthorityRecordDecoder;
exports.getUseAuthorityRecordEncoder = getUseAuthorityRecordEncoder;
exports.getUseAuthorityRecordSize = getUseAuthorityRecordSize;
exports.getUseInstruction = getUseInstruction;
exports.getUseInstructionDataCodec = getUseInstructionDataCodec;
exports.getUseInstructionDataDecoder = getUseInstructionDataDecoder;
exports.getUseInstructionDataEncoder = getUseInstructionDataEncoder;
exports.getUseMethodCodec = getUseMethodCodec;
exports.getUseMethodDecoder = getUseMethodDecoder;
exports.getUseMethodEncoder = getUseMethodEncoder;
exports.getUsesCodec = getUsesCodec;
exports.getUsesDecoder = getUsesDecoder;
exports.getUsesEncoder = getUsesEncoder;
exports.getUsesToggleCodec = getUsesToggleCodec;
exports.getUsesToggleDecoder = getUsesToggleDecoder;
exports.getUsesToggleEncoder = getUsesToggleEncoder;
exports.getUtilizeInstruction = getUtilizeInstruction;
exports.getUtilizeInstructionDataCodec = getUtilizeInstructionDataCodec;
exports.getUtilizeInstructionDataDecoder = getUtilizeInstructionDataDecoder;
exports.getUtilizeInstructionDataEncoder = getUtilizeInstructionDataEncoder;
exports.getVerificationArgsCodec = getVerificationArgsCodec;
exports.getVerificationArgsDecoder = getVerificationArgsDecoder;
exports.getVerificationArgsEncoder = getVerificationArgsEncoder;
exports.getVerifyCollectionInstruction = getVerifyCollectionInstruction;
exports.getVerifyCollectionInstructionDataCodec = getVerifyCollectionInstructionDataCodec;
exports.getVerifyCollectionInstructionDataDecoder = getVerifyCollectionInstructionDataDecoder;
exports.getVerifyCollectionInstructionDataEncoder = getVerifyCollectionInstructionDataEncoder;
exports.getVerifyInstruction = getVerifyInstruction;
exports.getVerifyInstructionDataCodec = getVerifyInstructionDataCodec;
exports.getVerifyInstructionDataDecoder = getVerifyInstructionDataDecoder;
exports.getVerifyInstructionDataEncoder = getVerifyInstructionDataEncoder;
exports.getVerifySizedCollectionItemInstruction = getVerifySizedCollectionItemInstruction;
exports.getVerifySizedCollectionItemInstructionDataCodec = getVerifySizedCollectionItemInstructionDataCodec;
exports.getVerifySizedCollectionItemInstructionDataDecoder = getVerifySizedCollectionItemInstructionDataDecoder;
exports.getVerifySizedCollectionItemInstructionDataEncoder = getVerifySizedCollectionItemInstructionDataEncoder;
exports.identifyTokenMetadataInstruction = identifyTokenMetadataInstruction;
exports.initializeCollection = initializeCollection;
exports.isBurnArgs = isBurnArgs;
exports.isCollectionDetails = isCollectionDetails;
exports.isCollectionDetailsToggle = isCollectionDetailsToggle;
exports.isCollectionToggle = isCollectionToggle;
exports.isCreateArgs = isCreateArgs;
exports.isDelegateArgs = isDelegateArgs;
exports.isEscrowAuthority = isEscrowAuthority;
exports.isLockArgs = isLockArgs;
exports.isMintArgs = isMintArgs;
exports.isPayloadType = isPayloadType;
exports.isPrintArgs = isPrintArgs;
exports.isPrintSupply = isPrintSupply;
exports.isProgrammableConfig = isProgrammableConfig;
exports.isRuleSetToggle = isRuleSetToggle;
exports.isTransferArgs = isTransferArgs;
exports.isUnlockArgs = isUnlockArgs;
exports.isUpdateArgs = isUpdateArgs;
exports.isUseArgs = isUseArgs;
exports.isUsesToggle = isUsesToggle;
exports.lockArgs = lockArgs;
exports.mintArgs = mintArgs;
exports.mintNft = mintNft;
exports.parseApproveCollectionAuthorityInstruction = parseApproveCollectionAuthorityInstruction;
exports.parseApproveUseAuthorityInstruction = parseApproveUseAuthorityInstruction;
exports.parseBubblegumSetCollectionSizeInstruction = parseBubblegumSetCollectionSizeInstruction;
exports.parseBurnEditionNftInstruction = parseBurnEditionNftInstruction;
exports.parseBurnInstruction = parseBurnInstruction;
exports.parseBurnNftInstruction = parseBurnNftInstruction;
exports.parseCloseEscrowAccountInstruction = parseCloseEscrowAccountInstruction;
exports.parseCollectInstruction = parseCollectInstruction;
exports.parseConvertMasterEditionV1ToV2Instruction = parseConvertMasterEditionV1ToV2Instruction;
exports.parseCreateEscrowAccountInstruction = parseCreateEscrowAccountInstruction;
exports.parseCreateMasterEditionInstruction = parseCreateMasterEditionInstruction;
exports.parseCreateMasterEditionV3Instruction = parseCreateMasterEditionV3Instruction;
exports.parseCreateMetadataAccountInstruction = parseCreateMetadataAccountInstruction;
exports.parseCreateMetadataAccountV2Instruction = parseCreateMetadataAccountV2Instruction;
exports.parseCreateMetadataAccountV3Instruction = parseCreateMetadataAccountV3Instruction;
exports.parseCreateV1Instruction = parseCreateV1Instruction;
exports.parseDeprecatedCreateMasterEditionInstruction = parseDeprecatedCreateMasterEditionInstruction;
exports.parseDeprecatedCreateReservationListInstruction = parseDeprecatedCreateReservationListInstruction;
exports.parseDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction = parseDeprecatedMintNewEditionFromMasterEditionViaPrintingTokenInstruction;
exports.parseDeprecatedMintPrintingTokensInstruction = parseDeprecatedMintPrintingTokensInstruction;
exports.parseDeprecatedMintPrintingTokensViaTokenInstruction = parseDeprecatedMintPrintingTokensViaTokenInstruction;
exports.parseDeprecatedSetReservationListInstruction = parseDeprecatedSetReservationListInstruction;
exports.parseFreezeDelegatedAccountInstruction = parseFreezeDelegatedAccountInstruction;
exports.parseLockInstruction = parseLockInstruction;
exports.parseMigrateInstruction = parseMigrateInstruction;
exports.parseMintNewEditionFromMasterEditionViaTokenInstruction = parseMintNewEditionFromMasterEditionViaTokenInstruction;
exports.parseMintNewEditionFromMasterEditionViaVaultProxyInstruction = parseMintNewEditionFromMasterEditionViaVaultProxyInstruction;
exports.parseMintV1Instruction = parseMintV1Instruction;
exports.parsePrintInstruction = parsePrintInstruction;
exports.parsePuffMetadataInstruction = parsePuffMetadataInstruction;
exports.parseRemoveCreatorVerificationInstruction = parseRemoveCreatorVerificationInstruction;
exports.parseSetAndVerifyCollectionInstruction = parseSetAndVerifyCollectionInstruction;
exports.parseSetAndVerifySizedCollectionItemInstruction = parseSetAndVerifySizedCollectionItemInstruction;
exports.parseSetCollectionSizeInstruction = parseSetCollectionSizeInstruction;
exports.parseSetTokenStandardInstruction = parseSetTokenStandardInstruction;
exports.parseSignMetadataInstruction = parseSignMetadataInstruction;
exports.parseThawDelegatedAccountInstruction = parseThawDelegatedAccountInstruction;
exports.parseTransferInstruction = parseTransferInstruction;
exports.parseTransferOutOfEscrowInstruction = parseTransferOutOfEscrowInstruction;
exports.parseUnlockInstruction = parseUnlockInstruction;
exports.parseUnverifyCollectionInstruction = parseUnverifyCollectionInstruction;
exports.parseUnverifyInstruction = parseUnverifyInstruction;
exports.parseUnverifySizedCollectionItemInstruction = parseUnverifySizedCollectionItemInstruction;
exports.parseUseInstruction = parseUseInstruction;
exports.parseUtilizeInstruction = parseUtilizeInstruction;
exports.parseVerifyCollectionInstruction = parseVerifyCollectionInstruction;
exports.parseVerifyInstruction = parseVerifyInstruction;
exports.parseVerifySizedCollectionItemInstruction = parseVerifySizedCollectionItemInstruction;
exports.payloadType = payloadType;
exports.printArgs = printArgs;
exports.printSupply = printSupply;
exports.programmableConfig = programmableConfig;
exports.ruleSetToggle = ruleSetToggle;
exports.transferArgs = transferArgs;
exports.unlockArgs = unlockArgs;
exports.updateArgs = updateArgs;
exports.useArgs = useArgs;
exports.usesToggle = usesToggle;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map